@@ -1,6 +1,6 @@
 /* acontainer.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004 Ralf Hoffmann.
+ * Copyright (C) 2004-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: acontainer.cc,v 1.5 2004/10/27 20:34:35 ralf Exp $ */
+/* $Id: acontainer.cc,v 1.7 2005/05/15 13:44:10 ralf Exp $ */
 
 #include "acontainer.h"
 #include "awindow.h"
@@ -27,9 +27,8 @@
 
 AContainer::AContElem::AContElem()
 {
-  Guielem = NULL;
+  _widelem = NULL;
   Cont = NULL;
-  Win = NULL;
   Width = Height = 0;
   MinWidth = MaxWidth = MinHeight = MaxHeight = -1;
   AutosizeMode = ACONT_NONE;
@@ -37,9 +36,9 @@ AContainer::AContElem::AContElem()
   NoResize = false;
 }
 
-GUIElement *AContainer::AContElem::guielem() const
+Widget *AContainer::AContElem::widelem() const
 {
-  return Guielem;
+  return _widelem;
 }
 
 AContainer *AContainer::AContElem::cont() const
@@ -47,30 +46,16 @@ AContainer *AContainer::AContElem::cont() const
   return Cont;
 }
 
-AWindow *AContainer::AContElem::win() const
+void AContainer::AContElem::widelem( Widget *newelem )
 {
-  return Win;
-}
-
-void AContainer::AContElem::guielem( GUIElement *newelem )
-{
-  Guielem = newelem;
+  _widelem = newelem;
   Cont = NULL;
-  Win = NULL;
 }
 
 void AContainer::AContElem::cont( AContainer *newcont )
 {
-  Guielem = NULL;
+  _widelem = NULL;
   Cont = newcont;
-  Win = NULL;
-}
-
-void AContainer::AContElem::win( AWindow *newwin )
-{
-  Guielem = NULL;
-  Cont = NULL;
-  Win = newwin;
 }
 
 int AContainer::AContElem::width() const
@@ -216,11 +201,11 @@ AContainer::~AContainer()
   if ( ergHeights != NULL ) delete [] ergHeights;
 }
 
-GUIElement *AContainer::add( GUIElement *newelement, int tx, int ty, int tautosizeMode )
+Widget *AContainer::add( Widget *newelement, int tx, int ty, int tautosizeMode )
 {
   if ( ( tx < 0 ) || ( tx >= xelems ) ) tx = 0;
   if ( ( ty < 0 ) || ( ty >= yelems ) ) ty = 0;
-  elements[tx + xelems * ty].guielem( newelement );
+  elements[tx + xelems * ty].widelem( newelement );
   elements[tx + xelems * ty].autosizeMode( tautosizeMode );
   elements[tx + xelems * ty].noResize( ( ( tautosizeMode & ACONT_NORESIZE ) != 0 ) ? true : false );
   if ( win != NULL ) win->add( newelement );
@@ -261,29 +246,7 @@ AContainer *AContainer::add( AContainer *newcont, int tx, int ty )
   return newcont;
 }
 
-AWindow *AContainer::add( AWindow *newwin, int tx, int ty, int tautosizeMode )
-{
-  if ( ( tx < 0 ) || ( tx >= xelems ) ) tx = 0;
-  if ( ( ty < 0 ) || ( ty >= yelems ) ) ty = 0;
-  elements[tx + xelems * ty].win( newwin );
-  elements[tx + xelems * ty].autosizeMode( tautosizeMode );
-
-  if ( ( tautosizeMode & ACONT_MINW ) != 0 ) {
-    elements[tx + xelems * ty].minWidth( newwin->getWidth() );
-  }
-  if ( ( tautosizeMode & ACONT_MINH ) != 0 ) {
-    elements[tx + xelems * ty].minHeight( newwin->getHeight() );
-  }
-  if ( ( tautosizeMode & ACONT_MAXW ) != 0 ) {
-    elements[tx + xelems * ty].maxWidth( newwin->getWidth() );
-  }
-  if ( ( tautosizeMode & ACONT_MAXH ) != 0 ) {
-    elements[tx + xelems * ty].maxHeight( newwin->getHeight() );
-  }
-
-  return newwin;
-}
-
+//TODO setParent private machen und kein callback machen?
 void AContainer::setParent( AContainer *newparent )
 {
   AContainer *tc;
@@ -332,14 +295,14 @@ int AContainer::remove( const AContainer *v )
   return 0;
 }
 
-int AContainer::remove( const GUIElement *v )
+int AContainer::remove( const Widget *v )
 {
   int pos;
 
   if ( v == NULL ) return 1;
 
   for ( pos = 0; pos < ( xelems * yelems ); pos++ ) {
-    if ( elements[pos].guielem() == v ) break;
+    if ( elements[pos].widelem() == v ) break;
   }
   if ( ( pos < 0 ) || ( pos >= ( xelems * yelems ) ) ) {
     // we don't own it call it for all subcontainers
@@ -351,30 +314,7 @@ int AContainer::remove( const GUIElement *v )
     return 1;
   }
 
-  elements[pos].guielem( NULL );
-  return 0;
-}
-
-int AContainer::remove( const AWindow *v )
-{
-  int pos;
-
-  if ( v == NULL ) return 1;
-
-  for ( pos = 0; pos < ( xelems * yelems ); pos++ ) {
-    if ( elements[pos].win() == v ) break;
-  }
-  if ( ( pos < 0 ) || ( pos >= ( xelems * yelems ) ) ) {
-    // we don't own it call it for all subcontainers
-    for ( pos = 0; pos < ( xelems * yelems ); pos++ ) {
-      if ( elements[pos].cont() != NULL ) {
-	elements[pos].cont()->remove( v );
-      }
-    }
-    return 1;
-  }
-
-  elements[pos].win( NULL );
+  elements[pos].widelem( NULL );
   return 0;
 }
 
@@ -654,26 +594,18 @@ int AContainer::rearrange( int vhmode )
 	  uy = cy;
 	  uw = tw;
 	  uh = th;
-	  if ( elements[ind].guielem() != NULL ) {
+	  elements[ind].width( uw );
+	  elements[ind].height( uh );
+	  if ( elements[ind].widelem() != NULL ) {
 	    if ( vhmode == ACONT_ONLYH ) {
-	      uy = elements[ind].guielem()->getY();
-	      uh = elements[ind].guielem()->getHeight();
+	      uy = elements[ind].widelem()->getY();
+	      uh = elements[ind].widelem()->getHeight();
 	    } else if ( vhmode == ACONT_ONLYV ) {
-	      ux = elements[ind].guielem()->getX();
-	      uw = elements[ind].guielem()->getWidth();
+	      ux = elements[ind].widelem()->getX();
+	      uw = elements[ind].widelem()->getWidth();
 	    }
-	    elements[ind].guielem()->move( ux, uy );
-	    if ( elements[ind].noResize() == false ) elements[ind].guielem()->resize( uw, uh );
-	  } else if ( elements[ind].win() != NULL ) {
-	    if ( vhmode == ACONT_ONLYH ) {
-	      uy = elements[ind].win()->getY();
-	      uh = elements[ind].win()->getHeight();
-	    } else if ( vhmode == ACONT_ONLYV ) {
-	      ux = elements[ind].win()->getX();
-	      uw = elements[ind].win()->getWidth();
-	    }
-	    elements[ind].win()->move( ux, uy );
-	    if ( elements[ind].noResize() == false ) elements[ind].win()->resize( uw, uh );
+	    elements[ind].widelem()->move( ux, uy );
+	    if ( elements[ind].noResize() == false ) elements[ind].widelem()->resize( uw, uh );
 	  } else if ( elements[ind].cont() != NULL ) {
 	    if ( vhmode == ACONT_ONLYH ) {
 	      uy = elements[ind].cont()->getY();
@@ -821,27 +753,12 @@ int AContainer::getY() const
 
 void AContainer::readLimits()
 {
-  GUIElement *elem;
-  AWindow *win;
+  Widget *elem;
   int pos;
 
   for ( pos = 0; pos < ( xelems * yelems ); pos++ ) {
-    if ( elements[pos].win() != NULL ) {
-      win = elements[pos].win();
-      if ( ( elements[pos].autosizeMode() & ACONT_MINW ) != 0 ) {
-	elements[pos].minWidth( win->getWidth() );
-      }
-      if ( ( elements[pos].autosizeMode() & ACONT_MINH ) != 0 ) {
-	elements[pos].minHeight( win->getHeight() );
-      }
-      if ( ( elements[pos].autosizeMode() & ACONT_MAXW ) != 0 ) {
-	elements[pos].maxWidth( win->getWidth() );
-      }
-      if ( ( elements[pos].autosizeMode() & ACONT_MAXH ) != 0 ) {
-	elements[pos].maxHeight( win->getHeight() );
-      }
-    } else if ( elements[pos].guielem() != NULL ) {
-      elem = elements[pos].guielem();
+    if ( elements[pos].widelem() != NULL ) {
+      elem = elements[pos].widelem();
       if ( ( elements[pos].autosizeMode() & ACONT_MINW ) != 0 ) {
 	elements[pos].minWidth( elem->getWidth() );
       }
@@ -867,3 +784,17 @@ int AContainer::getHeight() const
 {
   return height;
 }
+
+int AContainer::getWidth( int tx, int ty ) const
+{
+  if ( ( tx < 0 ) || ( tx >= xelems ) ) tx = 0;
+  if ( ( ty < 0 ) || ( ty >= yelems ) ) ty = 0;
+  return elements[tx + xelems * ty].width();
+}
+
+int AContainer::getHeight( int tx, int ty ) const
+{
+  if ( ( tx < 0 ) || ( tx >= xelems ) ) tx = 0;
+  if ( ( ty < 0 ) || ( ty >= yelems ) ) ty = 0;
+  return elements[tx + xelems * ty].height();
+}
