@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: acontainer.h,v 1.6 2005/05/15 13:44:28 ralf Exp $ */
+/* $Id: acontainer.h,v 1.7 2005/12/05 06:38:41 ralf Exp $ */
 
 #ifndef ACONTAINER_H
 #define ACONTAINER_H
@@ -39,6 +39,14 @@ public:
 	 ACONT_MINW = 4,
 	 ACONT_MINH = 8,
 	 ACONT_NORESIZE = 16 };
+
+  static const int CINCW = ACONT_MINH + ACONT_MINW + ACONT_MAXH;
+  static const int CINCWNR = CINCW + ACONT_NORESIZE;
+  static const int CFIX = ACONT_MINH + ACONT_MINW + ACONT_MAXH + ACONT_MAXW;
+  static const int CFIXNR = CFIX + ACONT_NORESIZE;
+  static const int CMIN = ACONT_MINH + ACONT_MINW;
+  static const int CINCH = ACONT_MINH + ACONT_MINW + ACONT_MAXW;
+
   class Widget *add( class Widget *newelement, int tx = 0, int ty = 0, int tautosizeMode = ACONT_NONE );
   AContainer *add( AContainer *newcont, int tx = 0, int ty = 0 );
 
