@@ -1,6 +1,6 @@
 /* acontainerbb.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004 Ralf Hoffmann.
+ * Copyright (C) 2004-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: acontainerbb.cc,v 1.2 2004/10/27 20:34:25 ralf Exp $ */
+/* $Id: acontainerbb.cc,v 1.3 2005/05/15 13:44:36 ralf Exp $ */
 
 #include "acontainerbb.h"
 #include "bevelbox.h"
@@ -64,7 +64,7 @@ int AContainerBB::rearrange( int vhmode )
   return 0;
 }
 
-int AContainerBB::remove( const GUIElement *v )
+int AContainerBB::remove( const Widget *v )
 {
   if ( v == bb ) bb = NULL;
   return AContainer::remove( v );
