@@ -1,6 +1,6 @@
 /* acontainerbb.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004 Ralf Hoffmann.
+ * Copyright (C) 2004-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: acontainerbb.h,v 1.3 2004/10/27 20:34:20 ralf Exp $ */
+/* $Id: acontainerbb.h,v 1.4 2005/05/15 13:44:42 ralf Exp $ */
 
 #ifndef ACONTAINERBB_H
 #define ACONTAINERBB_H
@@ -35,7 +35,7 @@ public:
   AContainerBB &operator=( const AContainerBB &other );
   
   int rearrange( int vhmode = 0 );
-  int remove( const GUIElement *v );
+  int remove( const Widget *v );
   bool getBBState() const;
   void setBBState( bool nv );
 private:
