@@ -1,6 +1,6 @@
 /* aguix.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: aguix.cc,v 1.72 2005/05/23 18:44:44 ralf Exp $ */
+/* $Id: aguix.cc,v 1.77 2005/12/06 20:59:42 ralf Exp $ */
 
 #include "aguix.h"
 #include "awindow.h"
@@ -256,6 +256,7 @@ int AGUIX::initX( int targc, char **targv, const char *tclassname )
 #ifdef USE_XIM
   openIM();
 #endif
+
   initOK=True;
   return 0;
 }
@@ -311,6 +312,7 @@ void AGUIX::closeX()
 #ifdef USE_XIM
   closeIM();
 #endif
+
 #ifdef DEBUG
   printf("Closing display\n");
 #endif
@@ -444,6 +446,9 @@ int AGUIX::AddColor(int red,int green,int blue)
       }
     }
     ColBuf[colors++]=col.pixel;
+    if ( colors == 1 ) {
+      prepareExtColors( red, green, blue );
+    }
   }
   return colors-1;
 }
@@ -602,6 +607,7 @@ Message *AGUIX::wait4mess( int mode )
     case ButtonPress:
     case ButtonRelease:
       newmsg->button = LastEvent.xbutton.button;
+      newmsg->keystate = LastEvent.xbutton.state;
       newmsg->mousex = LastEvent.xbutton.x;
       newmsg->mousey = LastEvent.xbutton.y;
       newmsg->window = LastEvent.xbutton.window;
@@ -616,6 +622,7 @@ Message *AGUIX::wait4mess( int mode )
       newmsg->mouserx = LastEvent.xmotion.x_root;
       newmsg->mousery = LastEvent.xmotion.y_root;
       newmsg->window = LastEvent.xmotion.window;
+      newmsg->keystate = LastEvent.xmotion.state;
       break;
     case Expose:
       newmsg->window = LastEvent.xexpose.window;
@@ -1065,6 +1072,10 @@ int AGUIX::changeColor(int index2,int red,int green,int blue)
   col.blue=blue*256;
   if(!XAllocColor(dsp,cmap,&col)) return -1;
   ColBuf[index2]=col.pixel;
+
+  if ( index2 == 0 ) {
+    prepareExtColors( red, green, blue );
+  }
   return 0;
 }
 
@@ -1461,7 +1472,7 @@ void AGUIX::DrawTriangleFilled(Drawable buffer, int px1, int py1, int px2, int p
 void AGUIX::DrawTriangleFilled(Drawable buffer, GC tgc, int px1, int py1, int px2, int py2, int px3, int py3)
 {
   GC usegc;
-  XPoint points[3];
+  XPoint points[4];
 
   if( tgc == 0 )
     usegc = gc;
@@ -1474,9 +1485,11 @@ void AGUIX::DrawTriangleFilled(Drawable buffer, GC tgc, int px1, int py1, int px
   points[1].y = py2;
   points[2].x = px3;
   points[2].y = py3;
+  points[3].x = px1;
+  points[3].y = py1;
 
-  XFillPolygon( dsp, buffer, usegc, points, 3, Convex, CoordModeOrigin );
-  XDrawLines( dsp, buffer, usegc, points ,3, CoordModeOrigin );
+  XFillPolygon( dsp, buffer, usegc, points, 4, Convex, CoordModeOrigin );
+  XDrawLines( dsp, buffer, usegc, points ,4, CoordModeOrigin );
 }
 
 void AGUIX::cancelCutPaste(GUIElement *elem)
@@ -2272,3 +2285,270 @@ void AGUIX::disableTimer()
   }
   timerEnabled = false;
 }
+
+int AGUIX::getTextWidth( const char *str, AGUIXFont *font )
+{
+  return getTextWidth( str, font, -1 );
+}
+
+int AGUIX::getTextWidth( const char *str, AGUIXFont *font, int len )
+{
+  XFontStruct *fs;
+  int slen;
+
+  if ( str == NULL ) return 0;
+
+  if ( font != NULL ) {
+    fs = font->getFontStruct();
+  } else if ( mainfont != NULL ) {
+    fs = mainfont->getFontStruct();
+  } else {
+    fs = myfont;
+  }
+
+  slen = strlen( str );
+  if ( ( len < 0 ) || ( len > slen ) )
+    len = slen;
+
+  return XTextWidth( fs, str, len );
+}
+
+int AGUIX::getStrlen4Width( const char *str, int width, int *return_width, AGUIXFont *font )
+{
+  int maxlen, leftlen, leftw, rightlen, rightw, erglen, ergw, midlen, midw;
+  XFontStruct *fs;
+
+  if ( str == NULL ) {
+    if ( return_width != NULL ) *return_width = 0;
+    return 0;
+  }
+
+  if ( font != NULL ) {
+    fs = font->getFontStruct();
+  } else if ( mainfont != NULL ) {
+    fs = mainfont->getFontStruct();
+  } else {
+    fs = myfont;
+  }
+
+  maxlen = strlen( str );
+  leftlen = leftw = 0;
+  rightlen = maxlen;
+  rightw = XTextWidth( fs, str, rightlen );
+
+  if ( leftw >= width ) {
+    erglen = leftlen;
+    ergw = leftw;
+  } else if ( rightw <= width ) {
+    erglen = rightlen;
+    ergw = rightw;
+  } else {
+    // from now on leftw is always less than width
+    // and rightw always more than width
+
+    for (;;) {
+      midlen = ( leftlen + rightlen ) / 2;
+      if ( ( midlen == leftlen ) || ( midlen == rightlen ) ) {
+	erglen = leftlen;
+	ergw = leftw;
+	break;
+      }
+
+      midw = XTextWidth( fs, str, midlen );
+      if ( midw == width ) {
+	erglen = midlen;
+	ergw = midw;
+	break;
+      }
+      
+      if ( midw < width ) {
+	leftlen = midlen;
+	leftw = midw;
+      } else {
+	rightlen = midlen;
+	rightw = midw;
+      }
+    }
+  }
+
+  if ( return_width != NULL ) *return_width = ergw;
+  return erglen;
+}
+
+void AGUIX::SetClipRectangles( AGUIXFont *font, int origin_x, int origin_y, XRectangle *rect, int rect_n, int ordering )
+{
+  if ( font != NULL ) {
+    XSetClipRectangles( dsp, font->getGC(), origin_x, origin_y, rect, rect_n, ordering );
+  } else {
+    XSetClipRectangles( dsp, gc, origin_x, origin_y, rect, rect_n, ordering );
+  }
+}
+
+void AGUIX::UnsetClipMask( AGUIXFont *font )
+{
+  if ( font != NULL ) {
+    XSetClipMask( dsp, font->getGC(), None );
+  } else {
+    XSetClipMask( dsp, gc, None );
+  }
+}
+
+void AGUIX::setFG( GC tgc, extcolor_t col )
+{
+  if ( tgc == 0) setFG( col );
+  else {
+    unsigned long pixel = _extcolors[col];
+    XSetForeground( dsp, tgc, pixel );
+  }
+}
+
+void AGUIX::setFG( extcolor_t col )
+{
+  unsigned long pixel = _extcolors[col];
+  XSetForeground( dsp, gc, pixel );
+}
+
+void AGUIX::setBG( GC tgc, extcolor_t col )
+{
+  if ( tgc == 0) setFG( col );
+  else {
+    unsigned long pixel = _extcolors[col];
+    XSetBackground( dsp, tgc, pixel );
+  }
+}
+
+void AGUIX::setBG( extcolor_t col )
+{
+  unsigned long pixel = _extcolors[col];
+  XSetBackground( dsp, gc, pixel );
+}
+
+void AGUIX::prepareExtColors( int gray_r, int gray_g, int gray_b )
+{
+  XColor col;
+  Visual *vis;
+
+  _extcolors[EXTCOLOR_BLACK] = black;
+  _extcolors[EXTCOLOR_WHITE] = white;
+  if ( colors > 0 ) {
+    _extcolors[EXTCOLOR_LIGHTGRAY] = ColBuf[0];
+    _extcolors[EXTCOLOR_DARKGRAY] = ColBuf[0];
+  } else {
+    _extcolors[EXTCOLOR_LIGHTGRAY] = white;
+    _extcolors[EXTCOLOR_DARKGRAY] = black;
+  }
+  
+  vis = DefaultVisual( dsp, scr);
+
+  if ( vis->c_class == TrueColor ) {
+    col.flags = DoRed | DoGreen | DoBlue;
+    col.red = gray_r * 256;
+    col.green = gray_g * 256;
+    col.blue = gray_b * 256;
+    if ( XAllocColor( dsp, cmap, &col ) ) {
+      _extcolors[EXTCOLOR_LIGHTGRAY] = col.pixel;
+    }
+    
+    col.flags = DoRed | DoGreen | DoBlue;
+    col.red = ( gray_r * 9 / 10 ) * 256;
+    col.green = ( gray_g * 9 / 10 ) * 256;
+    col.blue = ( gray_b * 9 / 10 ) * 256;
+    if ( XAllocColor( dsp, cmap, &col ) ) {
+      _extcolors[EXTCOLOR_DARKGRAY] = col.pixel;
+    }
+  }
+}
+
+void AGUIX::drawBorder( Drawable buffer, bool pressed, int x, int y, int w, int h, int topright_space )
+{
+  drawBorder( buffer, gc, pressed, x, y, w, h, topright_space );
+}
+
+void AGUIX::drawBorder( Drawable buffer, GC usegc, bool pressed, int x, int y, int w, int h, int topright_space )
+{
+  XPoint wp[3], bp[3], gp[3];
+
+  if ( w < 4 ) w = 4;
+  if ( h < 4 ) h = 4;
+
+  if ( topright_space > ( w - 2 ) ) topright_space = w - 2;
+  if ( topright_space > ( h - 2 ) ) topright_space = h - 2;
+  if ( topright_space < 0 ) topright_space = 0;
+
+  if ( pressed == true ) {
+    wp[0].x = x + 1;
+    wp[0].y = y + h - 1;
+    wp[1].x = x + w - 1;
+    wp[1].y = y + h - 1;
+    wp[2].x = x + w - 1;
+    wp[2].y = y + topright_space + 1;
+    
+    bp[0].x = x;
+    bp[0].y = y + h - 1;
+    bp[1].x = x;
+    bp[1].y = y;
+    bp[2].x = x + w - 1 - topright_space;
+    bp[2].y = y;
+    
+    gp[0].x = x + 1;
+    gp[0].y = y + h - 2;
+    gp[1].x = x + 1;
+    gp[1].y = y + 1;
+    gp[2].x = x + w - 2 - topright_space;
+    gp[2].y = y + 1;
+  } else {
+    wp[0].x = x;
+    wp[0].y = y + h - 2;
+    wp[1].x = x;
+    wp[1].y = y;
+    wp[2].x = x + w - 2 - topright_space;
+    wp[2].y = y;
+    
+    bp[0].x = x;
+    bp[0].y = y + h - 1;
+    bp[1].x = x + w - 1;
+    bp[1].y = y + h - 1;
+    bp[2].x = x + w - 1;
+    bp[2].y = y + topright_space;
+    
+    gp[0].x = x + 1;
+    gp[0].y = y + h - 2;
+    gp[1].x = x + w - 2;
+    gp[1].y = y + h - 2;
+    gp[2].x = x + w - 2;
+    gp[2].y = y + topright_space + 1;
+  }
+  
+  setFG( usegc, 2 );
+  DrawLine( buffer, usegc, wp[0].x, wp[0].y, wp[1].x, wp[1].y );
+  DrawLine( buffer, usegc, wp[1].x, wp[1].y, wp[2].x, wp[2].y );
+
+  setFG( usegc, 1 );
+  DrawLine( buffer, usegc, bp[0].x, bp[0].y, bp[1].x, bp[1].y );
+  DrawLine( buffer, usegc, bp[1].x, bp[1].y, bp[2].x, bp[2].y );
+
+  if ( extColorsAvail() == true ) {
+    setFG( usegc, EXTCOLOR_DARKGRAY );
+    DrawLine( buffer, usegc, gp[0].x, gp[0].y, gp[1].x, gp[1].y );
+    DrawLine( buffer, usegc, gp[1].x, gp[1].y, gp[2].x, gp[2].y );
+  }
+}
+
+bool AGUIX::extColorsAvail()
+{
+  Visual *vis;
+  vis = DefaultVisual( dsp, scr);
+
+  if ( vis->c_class == TrueColor ) {
+    return true;
+  } else {
+    return false;
+  }
+}
+
+void AGUIX::freeExtColors()
+{
+  //TODO nothing to do currently
+  // as I only support extended colors in true color
+  // mode where there are now color cells
+}
