@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: aguix.h,v 1.47 2004/10/27 20:33:57 ralf Exp $ */
+/* $Id: aguix.h,v 1.51 2005/10/13 19:35:47 ralf Exp $ */
 
 #ifndef AGUIX_H
 #define AGUIX_H
@@ -37,6 +37,8 @@
 #include <X11/cursorfont.h>
 #include <X11/Xatom.h>
 
+#include <map>
+
 class AWindow;
 class AGUIXFont;
 
@@ -75,6 +77,8 @@ public:
 
   void DrawTriangleFilled(Drawable buffer, int px1, int py1, int px2, int py2, int px3, int py3);
   void DrawTriangleFilled(Drawable buffer, GC tgc, int px1, int py1, int px2, int py2, int px3, int py3);
+  void SetClipRectangles( AGUIXFont *, int origin_x, int origin_y, XRectangle *rect, int rect_n, int ordering );
+  void UnsetClipMask( AGUIXFont *font );
 
   void ClearWin(Window win);
   void SetWindowBG(Window win,int color);
@@ -176,7 +180,21 @@ public:
   void enableTimer();
   void disableTimer();
 
+  int getTextWidth( const char *str, AGUIXFont *font = NULL );
+  int getTextWidth( const char *str, AGUIXFont *font, int len );
+  int getStrlen4Width( const char *str, int width, int *return_width, AGUIXFont *font = NULL );
+
   static long timerEvent;
+
+  typedef enum { EXTCOLOR_BLACK, EXTCOLOR_DARKGRAY, EXTCOLOR_LIGHTGRAY, EXTCOLOR_WHITE } extcolor_t;
+  void setFG( GC tgc, extcolor_t col );
+  void setFG( extcolor_t col );
+  void setBG( GC tgc, extcolor_t col );
+  void setBG( extcolor_t col );
+
+  void drawBorder( Drawable buffer, GC usegc, bool pressed, int x, int y, int w, int h, int topright_space );
+  void drawBorder( Drawable buffer, bool pressed, int x, int y, int w, int h, int topright_space );
+  bool extColorsAvail();
 private:
   Display *dsp;
   int scr;
@@ -236,6 +254,10 @@ private:
   int msgHandler( int mode, AWindow *parent, bool onlyExpose );
   enum { TIMER_TICKS = 25 }; //HARDCODED
   long lastTimerEventNr;
+
+  std::map<extcolor_t,unsigned long> _extcolors;
+  void prepareExtColors( int gray_r, int gray_g, int gray_b );
+  void freeExtColors();
 };
 
 class AGUIXFont
