@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: aguixdefs.h,v 1.21 2004/10/27 20:34:49 ralf Exp $ */
+/* $Id: aguixdefs.h,v 1.22 2005/10/17 19:22:54 ralf Exp $ */
 
 #ifndef AGUIXDEFS_H
 #define AGUIXDEFS_H
@@ -53,8 +53,11 @@
  * from:
  * http://www.opensource.apple.com/bugs/X/Libraries/2753843.html
  */
+/* This is no longer needed for newer Mac OS X versions (>=10.4?)
+ * Uncomment the line if you want to compile it on older versions
+ */
 #ifdef __APPLE__ // missing - why?
-extern "C" void nanosleep(struct timespec *, struct timespec *);
+//extern "C" void nanosleep(struct timespec *, struct timespec *);
 #endif
 
 #if defined( HAVE_SIGACTION ) && defined( HAVE_NANOSLEEP )
