@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: awindow.cc,v 1.60 2005/06/23 18:13:12 ralf Exp $ */
+/* $Id: awindow.cc,v 1.61 2005/12/01 21:13:43 ralf Exp $ */
 
 #include "awindow.h"
 #include "text.h"
@@ -1193,3 +1193,15 @@ Widget *AWindow::searchPrevFocus( const Widget *current )
   // it it is NULL it just means there is no focus element
   return prev_element;
 }
+
+int AWindow::addWindowEvent( Window subwin, long mask )
+{
+  XWindowAttributes curattr;
+ 
+  if ( hasSubWin( subwin ) == false )
+    return 1;
+
+  XGetWindowAttributes( _aguix->getDisplay(), subwin, &curattr );
+  XSelectInput( _aguix->getDisplay(), subwin, curattr.your_event_mask | mask );
+  return 0;
+}
