@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: bevelbox.cc,v 1.12 2005/05/15 13:45:00 ralf Exp $ */
+/* $Id: bevelbox.cc,v 1.13 2005/10/05 19:37:34 ralf Exp $ */
 
 #include "bevelbox.h"
 #include "lowlevelfunc.h"
@@ -33,7 +33,6 @@ BevelBox::~BevelBox()
 BevelBox::BevelBox(AGUIX *taguix):GUIElement(taguix)
 {
   this->state=0;
-  bgset=false;
 }
 
 BevelBox::BevelBox(AGUIX *taguix,int tx,int ty,int width,int height,
@@ -44,7 +43,6 @@ BevelBox::BevelBox(AGUIX *taguix,int tx,int ty,int width,int height,
   if ( width > 0 ) _w = width;
   if ( height > 0 ) _h = height;
   this->state=tstate;
-  bgset=false;
 }
 
 int BevelBox::getState() const
@@ -56,6 +54,7 @@ void BevelBox::setState(int tstate)
 {
   if(tstate==1) this->state=tstate;
   else this->state=0;
+
   redraw();
 }
 
@@ -63,10 +62,8 @@ void BevelBox::redraw()
 {
   if ( isCreated() == false ) return;
 
-  if(bgset==false) {
-    _aguix->SetWindowBG( win, _parent->getBG() );
-    bgset=true;
-  }
+  prepareBG();
+
   _aguix->ClearWin(win);
   if(state==0) {
     _aguix->setFG(2);
@@ -108,3 +105,11 @@ bool BevelBox::isType(const char *qtype) const
   if(strcmp(type,qtype)==0) return true;
   return false;
 }
+
+void BevelBox::prepareBG( bool force )
+{
+  if ( isCreated() == false ) return;
+  if ( win == 0 ) return;
+
+  _aguix->SetWindowBG( win, _parent->getBG() );
+}
