@@ -1,6 +1,6 @@
 /* bevelbox.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: bevelbox.h,v 1.7 2004/10/27 20:37:07 ralf Exp $ */
+/* $Id: bevelbox.h,v 1.8 2005/10/05 19:37:23 ralf Exp $ */
 
 #ifndef BEVELBOX_H
 #define BEVELBOX_H
@@ -46,8 +46,9 @@ public:
   virtual bool isType(const char *type) const;
 private:
   int state;
-  bool bgset;
   static const char *type;
+
+  void prepareBG( bool force = false );
 };
 
 #endif
