@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: choosebutton.cc,v 1.24 2005/05/21 12:16:23 ralf Exp $ */
+/* $Id: choosebutton.cc,v 1.27 2005/10/06 20:03:28 ralf Exp $ */
 
 #include "choosebutton.h"
 #include "awindow.h"
@@ -45,9 +45,9 @@ ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,int width,int height,bool
   this->label=dupstring(tlabel);
   this->labelpos=tlabelpos;
   this->labelcolor=tlabelcolor;
-  bgset=false;
   cross=false;
   font=NULL;
+
   calcLabelGeometry();
   calcRealPos(tx,ty);
   laststate=tstate;
@@ -73,9 +73,9 @@ ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,bool tstate,
   this->label=dupstring(tlabel);
   this->labelpos=tlabelpos;
   this->labelcolor=tlabelcolor;
-  bgset=false;
   cross=false;
   font=NULL;
+
   calcLabelGeometry();
   calcRealPos(tx,ty);
   laststate=tstate;
@@ -142,20 +142,16 @@ void ChooseButton::cbredraw()
 {
   if ( isCreated() == false ) return;
   if ( win == 0 ) return;
-  if(bgset==false) {
-    _aguix->SetWindowBG(win,_parent->getBG());
-    _aguix->SetWindowBG(lwin,_parent->getBG());
-    bgset=true;
-  }
+
+  prepareBG();
+  
   _aguix->ClearWin(win);
-  _aguix->setFG(2);
-  _aguix->DrawLine(win,0,_h-1,0,0);
-  _aguix->DrawLine(win,0,0,_w-1,0);
-  _aguix->setFG(1);
-  _aguix->DrawLine(win,0,_h-1,_w-1,_h-1);
-  _aguix->DrawLine(win,_w-1,_h-1,_w-1,1);
+
+  _aguix->drawBorder( win, false, 0, 0, _w, _h, 0 );
+
   int dx1,dy1;
   if(state==true) {
+    _aguix->setFG(1);
     dy1=_h/2;
     dx1=_w/4;
     int dy2=_h*3/4;
@@ -165,7 +161,7 @@ void ChooseButton::cbredraw()
     dx1=_w*3/4;
     _aguix->DrawLine(win,dx2,dy2,dx1,dy1);
   }
-
+  
   if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
     if ( strlen( label ) < 1 ) {
       _aguix->setDottedFG( 1 );
@@ -182,11 +178,7 @@ void ChooseButton::lredraw()
   if ( isCreated() == false ) return;
   if ( lwin == 0 ) return;
   if(font==NULL) usegc=0; else usegc=font->getGC();
-  if(bgset==false) {
-    _aguix->SetWindowBG(lwin,_parent->getBG());
-    _aguix->SetWindowBG(win,_parent->getBG());
-    bgset=true;
-  }
+  _aguix->SetWindowBG(lwin,_parent->getBG());
   _aguix->ClearWin(lwin);
   _aguix->setFG(usegc,labelcolor);
   if(font==NULL) _aguix->DrawText(lwin,label,0,0);
@@ -331,8 +323,7 @@ int ChooseButton::getLabelWidth() const
 {
   if(label!=NULL) {
     int l;
-    if(font==NULL) l=strlen(label)*_aguix->getCharWidth();
-    else l=strlen(label)*font->getCharWidth();
+    l= _aguix->getTextWidth( label, font );
     l += 2;
     return l;
   } else return 0;
@@ -517,3 +508,12 @@ void ChooseButton::doDestroyStuff()
   }
   GUIElement::doDestroyStuff();
 }
+
+void ChooseButton::prepareBG( bool force )
+{
+  if ( isCreated() == false ) return;
+  if ( win == 0 ) return;
+
+  _aguix->SetWindowBG( win, _parent->getBG() );
+  _aguix->SetWindowBG( lwin, _parent->getBG() );
+}
