@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: cyclebutton.h,v 1.9 2005/05/15 13:45:37 ralf Exp $ */
+/* $Id: cyclebutton.h,v 1.10 2005/10/05 19:39:15 ralf Exp $ */
 
 #ifndef CYCLEBUTTON_H
 #define CYCLEBUTTON_H
@@ -66,12 +66,13 @@ protected:
   int act_opt;
   int fg;
   int bg;
-  int lastbg;
   int data;
   int state;
   int instate;
   AGUIXFont *font;
   static const char *type;
+  
+  void prepareBG( bool force = false );
 };
 
 #endif
