@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: dndtext.cc,v 1.8 2004/10/27 20:39:33 ralf Exp $ */
+/* $Id: dndtext.cc,v 1.9 2005/08/16 20:48:50 ralf Exp $ */
 
 #include "dndtext.h"
 #include "aguix.h"
@@ -33,11 +33,11 @@ DNDText::DNDText( AGUIX *parent, char *ttext, int tfg, int tbg, AGUIXFont *tfont
   this->font=tfont;
   if(tfont!=NULL) {
     dely=-(tfont->getCharHeight());
-    delx=-(tfont->getCharWidth()*strlen(ttext));
   } else {
     dely=-(aguix->getCharHeight());
-    delx=-(aguix->getCharWidth()*strlen(ttext));
   }
+  delx =- aguix->getTextWidth( ttext );
+
   dely/=2;
   delx/=2;
 }
@@ -71,10 +71,10 @@ void DNDText::create()
   Display *dsp=aguix->getDisplay();
   if(font!=NULL) h=font->getCharHeight();
   else h=aguix->getCharHeight();
-  if(font!=NULL) w=font->getCharWidth();
-  else w=aguix->getCharWidth();
-  w*=strlen(text);
+
+  w = aguix->getTextWidth( text, font );
   w+=1;
+
   aguix->SetWindowBG(win,bg);
   XResizeWindow(dsp,win,w,h);
 
