@@ -1,6 +1,6 @@
 /* fieldlistview.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2004 Ralf Hoffmann.
+ * Copyright (C) 2002-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: fieldlistview.h,v 1.24 2004/10/27 20:39:08 ralf Exp $ */
+/* $Id: fieldlistview.h,v 1.33 2005/12/06 21:00:13 ralf Exp $ */
 
 #ifndef NEWLISTVIEW_H
 #define NEWLISTVIEW_H
@@ -71,6 +71,7 @@ public:
   // true to merge with following field text
   void setFieldTextMergedQ( int field, bool nv );
   void setFieldTextMerged( int field, bool nv );
+  void setFieldTextResizeable( int field, bool nv );
 
   virtual void redraw();
   void redraw( int element );
@@ -99,9 +100,7 @@ public:
   int getXOffset() const;
   int getYOffset() const;
   int getElements() const;
-  int getMaxLen();
   int getMaxDisplayV() const;
-  int getMaxDisplayH() const;
   void setHBarState( int state );
   void setVBarState( int state );
   int getHBarState() const;
@@ -151,6 +150,20 @@ public:
   void setHeaderBG( int col );
   int getHeaderFG() const;
   int getHeaderBG() const;
+  int getHScrollStep() const;
+
+  int getFieldWidth( int field ) const;
+  int getUsedFieldWidth( int field );
+
+  typedef enum {
+    SELECT_BUTTON,
+    ACTIVATE_BUTTON,
+    SCROLL_BUTTON
+  } buttonfunction_t;
+  static int changeButtonFunction( buttonfunction_t bf, int button );
+
+  typedef enum { MOUSE_SELECT_NORMAL, MOUSE_SELECT_ALT } mouse_select_t;
+  static int changeSelectMode( mouse_select_t nm );
 protected:
   int fields;
   int *fieldwidth;
@@ -160,6 +173,7 @@ protected:
   align_t *fieldalign;
   std::string *fieldtext;
   bool *fieldtextmerged;
+  bool *fieldtextResizeable;
   int fieldtextclicked;
 
   class Content
@@ -172,7 +186,6 @@ protected:
     void setText( int field, std::string text );
     void trim( int newfields );
     std::string getText( int field ) const;
-    int getLength( int field ) const;
     void setFG( colorclass_t cc, int col );
     int getFG( colorclass_t cc ) const;
     void setBG( colorclass_t cc, int col );
@@ -202,14 +215,13 @@ protected:
   void increaseArray( int newsize );
   void checkShrink();
 
-  int xoffset, yoffset, maxdisplayh, maxdisplayv;
+  int xoffset, yoffset, maxdisplayv;
 
-  void redraw( int element, char *line );
+  void redrawLine( int element );
   int activerow;
 
   int data;
   static const char *type;
-  bool bgset;
   int hbar;
   int hbar_height;
   int hbar_dir;
@@ -230,7 +242,7 @@ protected:
   void handleHBar( Message *msg );
   void handleVBar( Message *msg );
   bool handleKeys( Message *msg );
-  void handleHeader( Message *msg, int f );
+  void handleHeader( Message *msg );
 
   void (*selecthandler)( FieldListView*,int element );
   void setupBars();
@@ -261,7 +273,7 @@ protected:
   bool showHeader;
   int headerCols[2];
 
-  int getFieldForPoint( int mx, int my);
+  int getFieldForPoint( int mx, int my, int *start_x = NULL, int *end_x = NULL );
 
   typedef enum { VBAR_IDLE, VBAR_SCROLL, VBAR_SCROLL_UP, VBAR_SCROLL_DOWN } vbarMode_t;
   vbarMode_t vbarMode;
@@ -274,6 +286,8 @@ protected:
   int scrollXDir, scrollYDir;
   void updateScrollValues( int mx, int my );
   int selectRowsRange( int startRow, int endRow, bool state );
+  int singleSelectRow( int row, bool state );
+
   typedef enum { SELECT_IDLE, SELECT_HOLD, SELECT_SCROLL_UP, SELECT_SCROLL_DOWN, SELECT_IGNORE } selectMode_t;
   selectMode_t selectMode;
   int clickLastSelectedRow, clickFirstSelectedRow;
@@ -282,8 +296,34 @@ protected:
   typedef enum { MIDDLE_IDLE, MIDDLE_HOLD, MIDDLE_SCROLL_UP, MIDDLE_SCROLL_DOWN, MIDDLE_IGNORE } middleMode_t;
   middleMode_t middleMode;
 
+  typedef enum { HEADER_IDLE, HEADER_CLICK, HEADER_DRAG } headerMode_t;
+  headerMode_t headerMode;
+
   void selectModeIgnore();
   void middleModeIgnore();
+
+  void prepareBG( bool force = false );
+
+  Pixmap _header_pixmap;
+  int _header_pixmap_w, _header_pixmap_h;
+  void freeHeaderPixmap();
+  int checkHeaderPixmap( int pw, int ph );
+  int getBorderWidth() const;
+  int drag_base_x;
+  int drag_base_w;
+  Time last_drag_time;
+  int last_drag_clicked;
+  int drag_field;
+  bool header_cursor_set;  // true if cursor for header dragging is set
+
+  int findPreviousRealField( int f );
+  int getLastField( int *start_x, int *end_x );
+  int findResizeableField( int f );
+
+  static unsigned int _select_button, _select_buttonmask;
+  static unsigned int _activate_button, _activate_buttonmask;
+  static unsigned int _scroll_button, _scroll_buttonmask;
+  static mouse_select_t _select_mode;
 };
 
 #endif
