@@ -1,6 +1,6 @@
 /* guielement.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,71 +18,58 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: guielement.h,v 1.17 2004/10/27 20:38:27 ralf Exp $ */
+/* $Id: guielement.h,v 1.19 2005/05/23 18:43:32 ralf Exp $ */
 
 #ifndef GUIELEMENT_H
 #define GUIELEMENT_H
 
 #include "aguixdefs.h"
 #include "message.h"
+#include "widget.h"
 
 class AGUIX;
 class AWindow;
 
-class GUIElement {
+class GUIElement : public Widget {
 public:
   GUIElement(AGUIX *aguix);
   virtual ~GUIElement();
   GUIElement( const GUIElement &other );
   GUIElement &operator=( const GUIElement &other );
 
-  virtual void move(int x,int y);
-  virtual void resize(int w,int h);
+  void move( int nx, int ny );
+  void resize( int nw, int nh );
   virtual void redraw();
   virtual void flush();
   virtual const char *getType() const;
   virtual bool isType(const char *type) const;
-  virtual bool handleMessage(XEvent *E,Message *msg);
   virtual void getPos(int*,int*) const;
   virtual void getSize(int*,int*) const;
-  virtual int getWidth() const;
-  virtual int getHeight() const;
-  virtual int getX() const;
-  virtual int getY() const;
-  void setParent(AWindow *parent);
   virtual void toBack();
   virtual void toFront();
   bool hasWin(Window win) const;
   Window getWindow() const;
-  virtual bool isParent(Window) const;
+  bool isParent(Window) const;
   virtual void paste(unsigned char*);
   virtual void cancelpaste();
   virtual void cancelcut();
   virtual void takeFocus();
-  virtual void leaveFocus();
-  bool hasFocus() const;
   virtual void hide();
   virtual void show();
-  void setAcceptFocus( bool nv );
-  bool getAcceptFocus() const;
   bool isVisible() const;
-  virtual int handleMessageLock( XEvent *E, Message *msg );
+  bool handleMessage(XEvent *,Message *msg);
+  bool getAllowTimerEventBreak() const;
+  long getNrOfLastEventBreak() const;
+  void setNrOfLastEventBreak( long t );
 protected:
-  int x,y;
-  int w,h;
-  AGUIX *aguix;
-  AWindow *parent;
   Window win;
   static const char *type;
-  bool focus;
 
-  virtual void doCreateStuff();
-  virtual void doDestroyStuff();
-  bool canHandleFocus;  // indicates that this element can handle a focus
-  bool acceptFocus;  // this indicates that this element actual want to handle a focus
-  void registerFocusElement();
-  void unregisterFocusElement();
+  void doCreateStuff();
+  void doDestroyStuff();
   bool visible;
+  bool _allow_timerevent_break;
+  long _nr_of_last_event_break;
 };
 
 #endif
