@@ -1,6 +1,6 @@
 /* kartei.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004 Ralf Hoffmann.
+ * Copyright (C) 2004-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: kartei.h,v 1.2 2004/10/27 20:41:12 ralf Exp $ */
+/* $Id: kartei.h,v 1.4 2005/07/07 18:53:33 ralf Exp $ */
 
 #ifndef KARTEI_H
 #define KARTEI_H
@@ -28,24 +28,23 @@
 
 class Kartei : public AWindow {
 public:
-  Kartei( AGUIX *parent );
+  Kartei( AGUIX *parent,
+	  int x,
+	  int y,
+	  int width,
+	  int height,
+	  int bg,
+	  std::string title );
   ~Kartei();
   Kartei( const Kartei &other );
   Kartei &operator=( const Kartei &other );
-  int create( AWindow *parent,
-	      int x,
-	      int y,
-	      int width,
-	      int height,
-	      int bg,
-	      const char *title );
   void setOption( AWindow *win, unsigned int option, const char *optionname );
   void maximize();
   static void optionChangeCallback( Kartei *k1, unsigned int option );
   void optionChange( unsigned int option );
   void boxRedraw();
   bool handleMessage(XEvent *,Message *msg);
-  void close();
+  int getCurOption() const;
 protected:
   std::vector<AWindow*> options;
   class AContainer *cont;
@@ -53,6 +52,8 @@ protected:
   unsigned int curOption;
 
   void showCurOption();
+  void doCreateStuff();
+  void doDestroyStuff();
 };
 
 #endif
