@@ -18,10 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: lowlevelfunc.cc,v 1.32 2005/06/27 17:41:59 ralf Exp $ */
+/* $Id: lowlevelfunc.cc,v 1.34 2005/10/16 20:12:29 ralf Exp $ */
 
 #include "lowlevelfunc.h"
 #include <locale.h>
+#include <algorithm>
 
 #ifdef USE_MEM_SYSTEM
 typedef struct _safemem {void *ptr;
@@ -233,21 +234,50 @@ char *catstring(const char *str1,const char *str2)
   return tstr;
 }
 
-char *shrinkstring(const char *str,int maxlen)
+char *shrinkstring( const char *str, int maxlen, AWidth &lencalc )
 {
-  int len=strlen(str),llen,rlen;
+  int width, rwidth, ddd_width, real_width, rest_width, lwidth;
+  int llen;
   char *newstr;
-  if(len<=maxlen) return dupstring(str);
-  if(maxlen>4) {
-    newstr=(char*)_allocsafe(maxlen+1);
-    llen=(maxlen-3)/2;
-    rlen=maxlen-llen-3;
-    strncpy( newstr, str, llen );
-    strcpy( newstr + llen, "..." );
-    strcpy( newstr + llen + 3, str + len - rlen );
+  const char *hitstr, *trystr;
+  std::string str1;
+
+  width = lencalc.getWidth( str );
+
+  if ( width <= maxlen ) return dupstring( str );
+
+  ddd_width = lencalc.getWidth( "..." );
+  lwidth = lencalc.getWidth( str, 1 );
+
+  if ( ( lwidth + ddd_width ) <= maxlen) {
+    rest_width = maxlen - ddd_width;
+    
+    llen = lencalc.getStrlen4Width( str, rest_width / 2, &real_width );
+    str1 = "";
+    str1.append( str, llen );
+    str1 += "...";
+    
+    rest_width -= real_width;
+
+    // now find remaining character from right end
+    hitstr = NULL;
+    trystr = str + strlen( str ) - 1;
+    while ( trystr >= str ) {
+      rwidth = lencalc.getWidth( trystr );
+      if ( rwidth <= rest_width ) hitstr = trystr;
+      else break;
+      trystr--;
+    }
+    
+    if ( hitstr != NULL ) {
+      str1 += hitstr;
+    }
+    
+    newstr = dupstring( str1.c_str() );
   } else {
-    newstr=dupstring(str);
-    newstr[(maxlen>0)?maxlen:0]=0;
+    llen = lencalc.getStrlen4Width( str, maxlen, &real_width );
+    newstr = dupstring( str );
+    newstr[llen] = 0;
   }
   return newstr;
 }
