@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: lowlevelfunc.h,v 1.22 2005/06/27 17:41:20 ralf Exp $ */
+/* $Id: lowlevelfunc.h,v 1.23 2005/08/16 20:59:42 ralf Exp $ */
 
 #ifndef LOWLEVELFUNC_H
 #define LOWLEVELFUNC_H
@@ -26,6 +26,7 @@
 #include "aguixdefs.h"
 #include "time.h"
 #include <string>
+#include "awidth.h"
 
 void *_allocsafe(size_t size);
 void waittime(unsigned long msec);
@@ -37,7 +38,7 @@ void _memsystemcheck();
 #endif /* USE_MEM_SYSTEM */
 char *dupstring(const char *str);
 char *catstring(const char *str1,const char *str2);
-char *shrinkstring(const char *str,int maxlen);
+char *shrinkstring( const char *str, int maxlen, AWidth &lencalc );
 int MakeLong2NiceStr( loff_t size, std::string &buffer, bool do_nice = true );
 
 // this is the number of bytes need for a "nice" number with dots after 3 digits
