@@ -1,6 +1,6 @@
 /* message.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: message.h,v 1.18 2004/10/27 20:40:43 ralf Exp $ */
+/* $Id: message.h,v 1.20 2005/05/15 13:46:43 ralf Exp $ */
 
 #ifndef MESSAGE_H
 #define MESSAGE_H
@@ -34,6 +34,8 @@ class CycleButton;
 class AWindow;
 class FieldListView;
 class KarteiButton;
+class Slider;
+class Widget;
 
 typedef struct message
 {
@@ -65,7 +67,8 @@ enum {AG_NONE,AG_KEYPRESSED,AG_KEYRELEASED,AG_MOUSEPRESSED,AG_MOUSERELEASED,AG_M
       AG_DND_START,AG_DND_END,AG_DND_CANCEL,
       AG_CYCLEBUTTONCLICKED,
       AG_FIELDLV_ONESELECT,AG_FIELDLV_MULTISELECT,AG_FIELDLV_PRESSED,AG_FIELDLV_HEADERCLICKED,
-      AG_KARTEIBUTTONCLICKED };
+      AG_KARTEIBUTTONCLICKED,
+      AG_SLIDER_PRESSED, AG_SLIDER_CHANGED };
 
 typedef struct agkey {
   int type;
@@ -155,7 +158,7 @@ typedef struct agsizechange {
 typedef struct agdnd {
   int type;
   int relx,rely;
-  GUIElement *element;
+  Widget *element;
   AWindow *window;
   struct {
     void *voidP;
@@ -197,6 +200,17 @@ typedef struct agkarteibutton {
 
 typedef AGKarteiButton AGKarteiButtonClicked;
 
+typedef struct agslider {
+  int type;
+  Slider *slider;
+  int offset;
+  Time time;
+  bool mouse;
+} AGSlider;
+
+typedef AGSlider AGSliderChanged;
+typedef AGSlider AGSliderPressed;
+
 typedef union agmessage {
   int type;
   AGKey key;
@@ -212,6 +226,7 @@ typedef union agmessage {
   AGCycleButton cyclebutton;
   AGFieldLV fieldlv;
   AGKarteiButton karteibutton;
+  AGSlider slider;
   long direct[20];
 } AGMessage;
 
