@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: request.cc,v 1.35 2005/05/15 13:46:53 ralf Exp $ */
+/* $Id: request.cc,v 1.37 2005/12/05 06:39:44 ralf Exp $ */
 
 #include "request.h"
 #include "aguix.h"
@@ -460,20 +460,6 @@ int Requester::request_choose( const char *title,
   Button **buts;
   int nbuttons;
   char **buttonss;
-  const int cincw = AContainer::ACONT_MINH +
-                    AContainer::ACONT_MINW +
-                    AContainer::ACONT_MAXH;
-  const int cincwnr = cincw +
-                      AContainer::ACONT_NORESIZE;
-  const int cfix = AContainer::ACONT_MINH +
-                   AContainer::ACONT_MINW +
-                   AContainer::ACONT_MAXH +
-                   AContainer::ACONT_MAXW;
-  const int cfixnr = AContainer::ACONT_MINH +
-                     AContainer::ACONT_MINW +
-                     AContainer::ACONT_MAXH +
-                     AContainer::ACONT_MAXW +
-                     AContainer::ACONT_NORESIZE;
   int lines;
   char **liness;
 
@@ -502,7 +488,7 @@ int Requester::request_choose( const char *title,
 
   for ( i = 0; i < lines; i++ ) {
     ac1_1->add( new Text( aguix, 0, 0, liness[i], 1 ),
-		0, i, cincwnr );
+		0, i, AContainer::CINCWNR );
   }
   
   for ( i = 0; i < lines; i++ ) _freesafe( liness[i] );
@@ -515,7 +501,7 @@ int Requester::request_choose( const char *title,
   ChooseButton *cb1 = (ChooseButton*)ac1_2->add( new ChooseButton( aguix, 0,
 								   0, choose_var,
 								   choose_text, LABEL_RIGHT, 1, 1 ),
-						 1, 0, cfixnr );
+						 1, 0, AContainer::CFIXNR );
   AContainer *ac1_3 = ac1->add( new AContainer( win, nbuttons, 1 ), 0, 2 );
   ac1_3->setMinSpace( 5 );
   ac1_3->setMaxSpace( -1 );
@@ -524,7 +510,7 @@ int Requester::request_choose( const char *title,
   buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
   for ( i = 0; i < nbuttons; i++ ) {
     buts[i] = (Button*)ac1_3->add( new Button( aguix, 0, 0, buttonss[i], 1, 0, i ),
-				   i, 0, cfix );
+				   i, 0, AContainer::CFIX );
   }
   for ( i = 0; i < nbuttons; i++ ) {
     buts[i]->setAcceptFocus( true );
@@ -663,12 +649,6 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
   Button **buts;
   int nbuttons;
   char **buttonss;
-  const int cmin = AContainer::ACONT_MINH +
-                   AContainer::ACONT_MINW;
-  const int cfix = AContainer::ACONT_MINH +
-                   AContainer::ACONT_MINW +
-                   AContainer::ACONT_MAXH +
-                   AContainer::ACONT_MAXW;
 
   nbuttons = createLines( buttons, &buttonss );
   AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, title );
@@ -689,7 +669,7 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
 
   TextView *tv = new TextView( aguix, 0, 0, 100, 100, 0, "", ts );
   tv->setDisplayFocus( true );
-  ac1->add( tv, 0, 0, cmin );
+  ac1->add( tv, 0, 0, AContainer::CMIN );
   tv->create();
   tv->show();
   tv->maximizeX();
@@ -704,7 +684,7 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
     
     buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
     buts[0] = (Button*)ac1_3->add( new Button( aguix, 0, 0, buttonss[0], 1, 0, 0 ),
-				   1, 0, cfix );
+				   1, 0, AContainer::CFIX );
   } else {
     AContainer *ac1_3 = ac1->add( new AContainer( win, nbuttons, 1 ), 0, 1 );
     ac1_3->setMinSpace( 5 );
@@ -714,13 +694,14 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
     buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
     for ( i = 0; i < nbuttons; i++ ) {
       buts[i] = (Button*)ac1_3->add( new Button( aguix, 0, 0, buttonss[i], 1, 0, i ),
-				     i, 0, cfix );
+				     i, 0, AContainer::CFIX );
     }
   }
   for ( i = 0; i < nbuttons; i++ ) {
     buts[i]->setAcceptFocus( true );
   }
-  buts[0]->takeFocus();
+  //  buts[0]->takeFocus();
+  win->applyFocus( tv );
 
   win->setDoTabCycling( true );
   win->contMaximize( true );
@@ -814,12 +795,6 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
 	        endmode = 9;
 		if ( endmode >= nbuttons ) endmode = -1;
 	        break;
-	      case XK_Left:
-		win->prevFocus();
-		break;
-  	      case XK_Right:
-		win->nextFocus();
-		break;
 	    }
 	  }
 	  break;
