@@ -18,12 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: request.h,v 1.16 2005/03/24 07:08:54 ralf Exp $ */
+/* $Id: request.h,v 1.17 2005/05/15 13:47:10 ralf Exp $ */
 
 #ifndef AGUIX_REQUEST_H
 #define AGUIX_REQUEST_H
 
 #include "aguixdefs.h"
+#include "textstorage.h"
 
 class Requester
 {
@@ -49,6 +50,10 @@ public:
   int request_choose( const char *title, const char *text, const char *choose_text, bool &choose_var, const char *buttons );
   int request_choose( const char *title, const char *text, const char *choose_text, bool &choose_var, const char *buttons, request_flags_t flags );
   int request_choose( const char *title, const char *text, const char *choose_text, bool &choose_var, const char *buttons, AWindow *twin, request_flags_t flags );
+
+  int request( const char *title, TextStorage &ts, const char *buttons );
+  int request( const char *title, TextStorage &ts, const char *buttons, request_flags_t flags );
+  int request( const char *title, TextStorage &ts, const char *buttons, AWindow *twin, request_flags_t flags );
 private:
   class AGUIX *aguix;
   AWindow *transientawin;
