@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: slider.cc,v 1.5 2005/05/23 20:53:16 ralf Exp $ */
+/* $Id: slider.cc,v 1.7 2005/10/06 20:05:01 ralf Exp $ */
 
 #include "slider.h"
 #include <stdlib.h>
@@ -158,159 +158,22 @@ void Slider::redraw()
   int maxlen = getMaxLen();
   struct point { int x, y; };
   struct point p[3];
+  XPoint arrow1[3], arrow2[3];
+  int bw, bgbw;
 
-  tw = _w - ( ( displayFocus == true ) ? 2 : 0 );
-  th = _h - ( ( displayFocus == true ) ? 2 : 0 );
-  ty = ( displayFocus == true ) ? 1 : 0;
-  tx = ( displayFocus == true ) ? 1 : 0;
+  bgbw = 1;
+
+  tw = _w - ( ( displayFocus == true ) ? 2 * bgbw: 0 );
+  th = _h - ( ( displayFocus == true ) ? 2 * bgbw: 0 );
+  ty = ( displayFocus == true ) ? bgbw : 0;
+  tx = ( displayFocus == true ) ? bgbw : 0;
+
+  bw = 2;
 
   _aguix->SetWindowBG( win, _parent->getBG() );
   _aguix->ClearWin( win );
-  
-  if ( bar_dir == 1 ) {
-    _aguix->setFG( 1 );
-  } else {
-    _aguix->setFG( 2 );
-  }
-  p[0].x = tx;
-  p[0].y = ( vertical == true ) ? ty + tw - 1 : ty + th - 1;
-  p[1].x = tx;
-  p[1].y = ty;
-  p[2].x = ( vertical == true ) ? tx + tw - 1 : tx + th - 1;
-  p[2].y = ty;
-  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
-  _aguix->DrawLine( win, p[1].x, p[1].y, p[2].x, p[2].y );
-  
-  if ( bar_dir == 1 ) {
-    _aguix->setFG( 2 );
-  } else {
-    _aguix->setFG( 1 );
-  }
-  p[0].x = tx + 1;
-  p[0].y = ( vertical == true ) ? ty + tw - 1 : ty + th - 1;
-  p[1].x = ( vertical == true ) ? tx + tw - 1 : tx + th - 1;
-  p[1].y = ( vertical == true ) ? ty + tw - 1 : ty + th - 1;
-  p[2].x = ( vertical == true ) ? tx + tw - 1 : tx + th - 1;
-  p[2].y = ty + 1;
-  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
-  _aguix->DrawLine( win, p[1].x, p[1].y, p[2].x, p[2].y );
-
-  // Left/Up-Arrow
-  _aguix->setFG( 1 );
-  p[0].x = ( vertical == true ) ? tx + tw / 5 : tx + th * 4 / 5;
-  p[0].y = ( vertical == true ) ? ty + tw * 4 / 5 : ty + th / 5;
-  p[1].x = ( vertical == true ) ? tx + tw / 2 : tx + th / 5;
-  p[1].y = ( vertical == true ) ? ty + tw / 5 : ty + th / 2;
-  p[2].x = ( vertical == true ) ? tx + tw * 4 / 5 : tx + th * 4 / 5;
-  p[2].y = ( vertical == true ) ? ty + tw * 4 / 5 : ty + th * 4 / 5;
-  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
-  _aguix->DrawLine( win, p[1].x, p[1].y, p[2].x, p[2].y );
-
-  p[0].x = ( vertical == true ) ? tx + tw - 1: tx + th;
-  p[0].y = ( vertical == true ) ? ty + tw : ty + th - 1;
-  p[1].x = ( vertical == true ) ? tx + tw - 1: tx + tw - th - 1;
-  p[1].y = ( vertical == true ) ? ty + th - tw - 1: ty + th - 1;
-  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
-  _aguix->setFG( 2 );
-  p[0].x = ( vertical == true ) ? tx : tx + th;
-  p[0].y = ( vertical == true ) ? ty + tw : ty;
-  p[1].x = ( vertical == true ) ? tx : tx + tw - th - 1;
-  p[1].y = ( vertical == true ) ? ty + th - tw - 1 : ty;
-  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
-
-  if ( bar_dir == 2 ) {
-    _aguix->setFG( 1 );
-  } else {
-    _aguix->setFG( 2 );
-  }
-  p[0].x = ( vertical == true ) ? tx : tx + tw - th;
-  p[0].y = ( vertical == true ) ? ty + th - 1 : ty + th - 1;
-  p[1].x = ( vertical == true ) ? tx : tx + tw - th;
-  p[1].y = ( vertical == true ) ? ty + th - tw : ty;
-  p[2].x = ( vertical == true ) ? tx + tw - 1 : tx + tw - 1;
-  p[2].y = ( vertical == true ) ? ty + th - tw : ty;
-  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
-  _aguix->DrawLine( win, p[1].x, p[1].y, p[2].x, p[2].y );
-  if ( bar_dir == 2 ) {
-    _aguix->setFG( 2 );
-  } else {
-    _aguix->setFG( 1 );
-  }
-  p[0].x = ( vertical == true ) ? tx + 1 : tx + tw - th + 1;
-  p[0].y = ( vertical == true ) ? ty + th - 1 : ty + th - 1;
-  p[1].x = ( vertical == true ) ? tx + tw - 1 : tx + tw - 1;
-  p[1].y = ( vertical == true ) ? ty + th - 1 : ty + th - 1;
-  p[2].x = ( vertical == true ) ? tx + tw - 1 : tx + tw - 1;
-  p[2].y = ( vertical == true ) ? ty + th - tw : ty + 1;
-  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
-  _aguix->DrawLine( win, p[1].x, p[1].y, p[2].x, p[2].y );
-
-  // Right-Arrow
-  _aguix->setFG( 1 );
-  p[0].x = ( vertical == true ) ? tx + tw / 5 : tx + tw - th * 4 / 5;
-  p[0].y = ( vertical == true ) ? ty + th - tw * 4 / 5 : ty + th / 5;
-  p[1].x = ( vertical == true ) ? tx + tw / 2 : tx + tw - th / 5;
-  p[1].y = ( vertical == true ) ? ty + th - tw / 5 : ty + th / 2;
-  p[2].x = ( vertical == true ) ? tx + tw * 4 / 5 : tx + tw - th * 4 / 5;
-  p[2].y = ( vertical == true ) ? ty + th - tw * 4 / 5 : ty + th * 4 / 5;
-  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
-  _aguix->DrawLine( win, p[1].x, p[1].y, p[2].x, p[2].y );
-  // jetzt noch die eigentliche Leiste
-  if ( vertical == true ) {
-    tx++;
-    ty += tw;
-    th -= 2 * tw;  // Hoehe wenn alles anzeigbar ist
-    tw -= 2;
-  } else {
-    ty++;
-    tx += th;
-    tw -= 2 * th;  // Breite wenn alles anzeigbar ist
-    th -= 2;
-  }
-  if ( maxlen > maxdisplay ) {
-    int d = ( ( vertical == true ) ? th : tw ) * maxdisplay;
-    d /= maxlen;
-
-    if ( d < 10 ) d = 10;
-
-    int a = maxlen - maxdisplay;
-    double b = ( ( vertical == true ) ? th : tw ) - d;  // das was brig bleibt
-    b /= a;            // verteilt sich auch die nichtsichtbaren Zeichen
-    if ( vertical == true ) {
-      ty += (int)( offset * b );
-      th = d;
-    } else {
-      tx += (int)( offset * b );
-      tw = d;
-    }
-  }
-  if ( bar_pressed == false ) {
-    _aguix->setFG( 2 );
-  } else {
-    _aguix->setFG( 1 );
-  }
-  p[0].x = tx;
-  p[0].y = ty + th - 1;
-  p[1].x = tx;
-  p[1].y = ty;
-  p[2].x = tx + tw - 1;
-  p[2].y = ty;
-  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
-  _aguix->DrawLine( win, p[1].x, p[1].y, p[2].x, p[2].y );
-  if ( bar_pressed == false ) {
-    _aguix->setFG( 1 );
-  } else {
-    _aguix->setFG( 2 );
-  }
-  p[0].x = tx + 1;
-  p[0].y = ty + th - 1;
-  p[1].x = tx + tw - 1;
-  p[1].y = ty + th - 1;
-  p[2].x = tx + tw - 1;
-  p[2].y = ty + 1;
-  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
-  _aguix->DrawLine( win, p[1].x, p[1].y, p[2].x, p[2].y );
 
+  // draw background
   if ( displayFocus == true ) {
     if ( getHasFocus() == true ) {
       _aguix->setFG( 1 );
@@ -340,6 +203,120 @@ void Slider::redraw()
     _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
     _aguix->DrawLine( win, p[1].x, p[1].y, p[2].x, p[2].y );
   }
+
+  if ( vertical == true ) {
+    int dw = ( tw - 1 ) & ~1;
+    dw = ( dw - 2 * bw ) / 2;
+    
+    arrow1[0].x = tx + ( tw - 1 ) / 2 - dw;
+    arrow1[0].y = ty + tw - bw - 1;
+    arrow1[1].x = tx + ( tw - 1 ) / 2;
+    arrow1[1].y = ty + bw;
+    arrow1[2].x = tx + ( tw - 1 )  / 2 + dw;
+    arrow1[2].y = ty + tw - bw - 1;
+    
+    arrow2[0].x = tx + ( tw - 1 ) / 2 - dw;
+    arrow2[0].y = ty + th - tw + bw;
+    arrow2[1].x = tx + ( tw - 1 ) / 2;
+    arrow2[1].y = ty + th - bw - 1;
+    arrow2[2].x = tx + ( tw - 1 )  / 2 + dw;
+    arrow2[2].y = ty + th - tw + bw;
+  } else {
+    int dh = ( th - 1 ) & ~1;
+    dh = ( dh - 2 * bw ) / 2;
+    
+    arrow1[0].x = tx + th - bw - 1;
+    arrow1[0].y = ty + ( th - 1 ) / 2 - dh;
+    arrow1[1].x = tx + bw;
+    arrow1[1].y = ty + ( th - 1 )  / 2;
+    arrow1[2].x = tx + th - bw - 1;
+    arrow1[2].y = ty + ( th - 1 ) / 2 + dh;
+
+    arrow2[0].x = tx + tw - th + bw;
+    arrow2[0].y = ty + ( th - 1 ) / 2 - dh;
+    arrow2[1].x = tx + tw - bw - 1;
+    arrow2[1].y = ty + ( th - 1 )  / 2;
+    arrow2[2].x = tx + tw - th + bw;
+    arrow2[2].y = ty + ( th - 1 ) / 2 + dh;
+  }
+
+  // left/top arrow box
+  _aguix->drawBorder( win, ( bar_dir == 1 ) ? true : false, tx, ty,  ( vertical == true ) ? tw : th, ( vertical == true ) ? tw : th, 0 );
+
+  // Left/Up-Arrow
+  _aguix->setFG( 1 );
+  _aguix->DrawTriangleFilled( win,
+			      arrow1[0].x, arrow1[0].y,
+			      arrow1[1].x, arrow1[1].y,
+			      arrow1[2].x, arrow1[2].y );
+
+  // middle box
+  if ( _aguix->extColorsAvail() == true ) {
+    _aguix->setFG( AGUIX::EXTCOLOR_DARKGRAY );
+    _aguix->FillRectangle( win, ( vertical == true ) ? tx : tx + th, ( vertical == true ) ? ty + tw : ty,
+			   ( vertical == true ) ? tw : tw -  2 * th, ( vertical == true ) ? th -  2 * tw : th );
+  }
+
+  _aguix->setFG( 1 );
+  p[0].x = ( vertical == true ) ? tx + tw - 1: tx + th;
+  p[0].y = ( vertical == true ) ? ty + tw : ty + th - 1;
+  p[1].x = ( vertical == true ) ? tx + tw - 1: tx + tw - th - 1;
+  p[1].y = ( vertical == true ) ? ty + th - tw - 1: ty + th - 1;
+  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
+  _aguix->setFG( 2 );
+  p[0].x = ( vertical == true ) ? tx : tx + th;
+  p[0].y = ( vertical == true ) ? ty + tw : ty;
+  p[1].x = ( vertical == true ) ? tx : tx + tw - th - 1;
+  p[1].y = ( vertical == true ) ? ty + th - tw - 1 : ty;
+  _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
+
+  // right/bottom arrow box
+  p[0].x = ( vertical == true ) ? tx : tx + tw - th;
+  p[0].y = ( vertical == true ) ? ty + th - tw : ty;
+  _aguix->drawBorder( win, ( bar_dir == 2 ) ? true : false, p[0].x, p[0].y, ( vertical == true ) ? tw : th, ( vertical == true ) ? tw : th, 0 );
+
+  // Right-Arrow
+  _aguix->setFG( 1 );
+  _aguix->DrawTriangleFilled( win,
+			      arrow2[0].x, arrow2[0].y,
+			      arrow2[1].x, arrow2[1].y,
+			      arrow2[2].x, arrow2[2].y );
+
+  // jetzt noch die eigentliche Leiste
+  if ( vertical == true ) {
+    tx++;
+    ty += tw;
+    th -= 2 * tw;  // Hoehe wenn alles anzeigbar ist
+    tw -= 2;
+  } else {
+    ty++;
+    tx += th;
+    tw -= 2 * th;  // Breite wenn alles anzeigbar ist
+    th -= 2;
+  }
+  if ( maxlen > maxdisplay ) {
+    int d = ( ( vertical == true ) ? th : tw ) * maxdisplay;
+    d /= maxlen;
+
+    if ( d < 10 ) d = 10;
+
+    int a = maxlen - maxdisplay;
+    double b = ( ( vertical == true ) ? th : tw ) - d;  // das was brig bleibt
+    b /= a;            // verteilt sich auch die nichtsichtbaren Zeichen
+    if ( vertical == true ) {
+      ty += (int)( offset * b );
+      th = d;
+    } else {
+      tx += (int)( offset * b );
+      tw = d;
+    }
+  }
+
+  _aguix->setFG( _parent->getBG() );
+  _aguix->FillRectangle( win, tx, ty,
+			 tw, th );
+
+  _aguix->drawBorder( win, bar_pressed, tx, ty, tw, th, 0 );
 }
 
 int Slider::getOffset() const
@@ -380,21 +357,26 @@ void Slider::setMaxDisplay( int nv )
 
 void Slider::handleBar( Message *msg )
 {
-  if ( isCreated() == false ) return;
   int mx, my;
   int dir;
   int hx, hy, hw, hh;
-  int maxlen = getMaxLen();
   int tx, ty, tw, th;
   double b = 1.0;
+  int bgbw;
+
+  if ( isCreated() == false ) return;
+
+  int maxlen = getMaxLen();
 
   mx = msg->mousex;
   my = msg->mousey;
 
-  hw = _w - ( ( displayFocus == true ) ? 2 : 0 );
-  hh = _h - ( ( displayFocus == true ) ? 2 : 0 );
-  hx = ( displayFocus == true ) ? 1 : 0;
-  hy = ( displayFocus == true ) ? 1 : 0;
+  bgbw = 1;
+
+  hw = _w - ( ( displayFocus == true ) ? 2 * bgbw : 0 );
+  hh = _h - ( ( displayFocus == true ) ? 2 * bgbw : 0 );
+  hx = ( displayFocus == true ) ? bgbw : 0;
+  hy = ( displayFocus == true ) ? bgbw : 0;
 
   tw = hw;
   th = hh;
