@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: stringgadget.cc,v 1.49 2005/05/15 13:47:38 ralf Exp $ */
+/* $Id: stringgadget.cc,v 1.54 2005/12/12 20:45:29 ralf Exp $ */
 
 #include "stringgadget.h"
 #include "awindow.h"
@@ -50,15 +50,13 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,int height,cons
   cursorpos=0;
   active=false;
   this->text=dupstring(ttext);
-  tbg=-1;
-  bgset=false;
+
   selstart=selend=cursorpos;
   font=NULL;
   forbidPosChange=false;
   strongkeycapture=true;
   wantpaste=false;
   pasterequest=0;
-  twin = 0;
   setCanHandleFocus();
   setAcceptFocus( true );
   passwordMode = false;
@@ -66,6 +64,9 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,int height,cons
 
 StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,const char *ttext,int tdata):GUIElement(taguix)
 {
+  int bw;
+
+  bw = getBorderWidth();
   this->data=tdata;
   _x=tx;
   _y=ty;
@@ -73,20 +74,19 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,const char *tte
     _w = width;
   else
     _w = 8;
-  _h=taguix->getCharHeight()+2+6;
+
+  _h = taguix->getCharHeight() + 2 * bw;
   xoffset=0;
   cursorpos=0;
   active=false;
   this->text=dupstring(ttext);
-  tbg=-1;
-  bgset=false;
+
   selstart=selend=cursorpos;
   font=NULL;
   forbidPosChange=false;
   strongkeycapture=true;
   wantpaste=false;
   pasterequest=0;
-  twin = 0;
   setCanHandleFocus();
   setAcceptFocus( true );
   passwordMode = false;
@@ -117,15 +117,26 @@ void StringGadget::setData(int tdata)
 
 void StringGadget::redraw()
 {
-  bredraw();
-  tredraw();
-}
+  int maxcol=_aguix->getMaxCols();
+  int newbg;
+  GC usegc;
 
-void StringGadget::bredraw()
-{
   if ( isCreated() == true ) {
-    _aguix->SetWindowBG(win,_parent->getBG());
+    prepareBG();
+
     _aguix->ClearWin(win);
+    if(active==true) {
+      if(maxcol>7) {
+	newbg=7;
+      } else {
+	newbg=0;
+      }
+    } else {
+      newbg=0;
+    }
+    
+    if(font==NULL) usegc=0; else usegc=font->getGC();
+    
     _aguix->setFG(2);
     _aguix->DrawLine(win,0,_h-1,0,0);
     _aguix->DrawLine(win,0,0,_w-1,0);
@@ -136,123 +147,154 @@ void StringGadget::bredraw()
     _aguix->DrawLine(win,_w-1,_h-1,_w-1,0);
     _aguix->DrawLine(win,2,_h-1-2,2,2);
     _aguix->DrawLine(win,2,2,_w-1-2,2);
+    textRedraw();
   }
 }
 
-void StringGadget::tredraw()
+void StringGadget::textRedraw()
 {
   int maxcol=_aguix->getMaxCols();
-  int newbg;
   GC usegc;
   int minx, maxx;
+  int bw = getBorderWidth();
+  int inner_x, inner_y;
 
   if ( isCreated() == false ) return;
-  if(active==true) {
-    if(maxcol>7) {
-      newbg=7;
-    } else {
-      newbg=0;
-    }
-  } else {
-    newbg=0;
-  }
-  _aguix->SetWindowBG(twin,newbg);
-  tbg=newbg;
-  _aguix->ClearWin(twin);
+
+  clearTextBG();
+
   if(font==NULL) usegc=0; else usegc=font->getGC();
-  int cw,ch;
+
+  inner_x = inner_y = getBorderWidth();
+
+  int ch;
   if(font==NULL) {
     ch=_aguix->getCharHeight();
-    cw=_aguix->getCharWidth();
   } else {
     ch=font->getCharHeight();
-    cw=font->getCharWidth();
   }
-  char *tstr=(char*)_allocsafe(maxdisplay+1);
+  char *tstr = dupstring( text );
   int dx;
   dx=1;
-  double f1=((_h-6-2)/2)-(ch/2);
+  double f1 = ( ( _h - 2 * bw ) / 2 ) - ( ch / 2 );
   int dy=(int)f1;
   int x1,x2;
-  int len;
+  int tstr_len = strlen( tstr );
+  int temp_ch_pos;
+  char temp_ch;
+
+  if ( passwordMode == true ) {
+    memset( tstr, '*', tstr_len );
+  }
 
   x1=(selstart<=selend?selstart:selend);
   x2=(selstart>selend?selstart:selend);
   if((x2==(int)strlen(text))&&(selstart!=selend)) x2--;
+
+  if ( ( x1 < 0 ) || ( x1 > tstr_len ) ) x1 = 0;
+  if ( ( x2 < 0 ) || ( x2 > tstr_len ) ) x2 = 0;
+  if ( x2 < x1 ) x2 = x1;
   
+  int restwidth = getInnerWidth() - 2;
+  int strwidth, vislen;
+  bool cont = true;
+
   if( xoffset < x1 ) {
     // links vom x1 ist noch Text
     _aguix->setFG(usegc,1);
-    
-    len = a_min( x1 - xoffset, maxdisplay );
 
-    if ( passwordMode == true ) {
-      memset( tstr, '*', len );
-    } else {
-      strncpy( tstr, text + xoffset, len );
+    temp_ch = tstr[x1];
+    temp_ch_pos = x1;
+    tstr[x1] = '\0';
+    vislen = _aguix->getStrlen4Width( tstr + xoffset, restwidth, &strwidth, font );
+
+    // xoffset + vislen is equal or less x1 in any case
+    if ( tstr[xoffset + vislen] != '\0' ) {
+      tstr[temp_ch_pos] = temp_ch;
+      temp_ch = tstr[xoffset + vislen];
+      temp_ch_pos = xoffset + vislen;
+      tstr[temp_ch_pos] = '\0';
+
+      // doesn't fit completely so don't draw anything else
+      cont = false;
     }
-    tstr[ len ]=0;
-    if(font==NULL) _aguix->DrawText(twin,tstr,dx,dy);
-    else _aguix->DrawText(twin,font,tstr,dx,dy);
-    dx+=strlen(tstr)*cw;
+
+    if ( vislen > 0 ) {
+      if ( font == NULL ) _aguix->DrawText( win, tstr + xoffset, inner_x + dx, inner_y + dy );
+      else _aguix->DrawText( win, font, tstr + xoffset, inner_x + dx, inner_y + dy );
+    }
+
+    tstr[temp_ch_pos] = temp_ch;
+    
+    dx += strwidth;
+    restwidth -= strwidth;
   }
-  if ( ! ( ( x2 < xoffset ) || ( ( x1 - xoffset ) > maxdisplay ) ) ) {
-    // die Selektion ist sichtbar
-    minx=(x1<xoffset)?xoffset:x1;
-    maxx=(x2<(xoffset+maxdisplay))?x2:(xoffset+maxdisplay-1);
-    len = maxx - minx + 1;
-    if ( passwordMode == true ) {
-      if ( *( text + minx ) != '\0' )
-	memset( tstr, '*', len );
-      else
-	tstr[0] = '\0';
-    } else {
-      strncpy( tstr, text + minx, len );
+
+  if ( ( cont == true ) && ( x2 >= xoffset ) ) {
+    // some part of the selection is visible
+
+    minx = ( x1 < xoffset ) ? xoffset : x1;
+    maxx = x2;
+    if ( tstr[maxx] != '\0' ) maxx++;
+
+    // draw selection from minx to maxx which can be outside screen
+
+    temp_ch = tstr[maxx];
+    temp_ch_pos = maxx;
+    tstr[maxx] = '\0';
+
+    vislen = _aguix->getStrlen4Width( tstr + minx, restwidth, &strwidth, font );
+
+    if ( tstr[minx + vislen] != '\0' ) {
+      tstr[temp_ch_pos] = temp_ch;
+      temp_ch = tstr[minx + vislen];
+      temp_ch_pos = minx + vislen;
+      tstr[temp_ch_pos] = '\0';
+
+      // doesn't fit completely so don't draw anything else
+      cont = false;
     }
-    tstr[len] = 0;
-    if(active==true) {
-      _aguix->setFG(usegc,1);
-    } else {
-      _aguix->setFG(usegc,0);
-    }
-    _aguix->FillRectangle( twin, usegc, dx, dy, len * cw, ch );
-    if(active==true) {
-      if(maxcol>7) {
-	_aguix->setFG(usegc,7);
-      } else {
-	_aguix->setFG(usegc,0);
+
+    if ( ( vislen > 0 ) || ( ( minx + vislen ) == tstr_len ) ) {
+      if(active==true) {
+	// draw selection area
+	_aguix->setFG(usegc,1);
+	_aguix->FillRectangle( win, usegc, inner_x + dx, inner_y + dy, strwidth, ch );
       }
-    } else {
-      _aguix->setFG(usegc,1);
+      if(active==true) {
+	if(maxcol>7) {
+	  _aguix->setFG(usegc,7);
+	} else {
+	  _aguix->setFG(usegc,0);
+	}
+      } else {
+	_aguix->setFG(usegc,1);
+      }
+      if ( font == NULL ) _aguix->DrawText( win, tstr + minx, inner_x + dx, inner_y + dy );
+      else _aguix->DrawText( win, font, tstr + minx, inner_x + dx, inner_y + dy );
     }
-    if(font==NULL) _aguix->DrawText(twin,tstr,dx,dy);
-    else _aguix->DrawText(twin,font,tstr,dx,dy);
-    dx += len * cw;
+
+    tstr[temp_ch_pos] = temp_ch;
+    
+    dx += strwidth;
+    restwidth -= strwidth;
   }
-  if((x2-xoffset)<(maxdisplay-1)) {
-    // Rest nach Selektion ist sichtbar
+
+  if ( ( cont == true ) && ( tstr[x2] != '\0' ) ) {
+    // the rest after the selection is possibly visible
     int first_vis_char;
     
     // end of selection can be less than xoffset
     first_vis_char = a_max( x2 + 1, xoffset );
     
-    if ( (int)strlen( text ) >= first_vis_char ) {
-      // as x2 can be less than xoffset, don't take more
-      // than maxdisplay
-      len = a_min( maxdisplay, maxdisplay - ( x2 - xoffset ) - 1 );
-      
-      if ( passwordMode == true ) {
-	len = a_min( len, (int)strlen( text ) - first_vis_char );
-	if ( len < 0 ) len = 0;
-	memset( tstr, '*', len );
-      } else {
-	strncpy( tstr, text + first_vis_char, len );
-      }
-      tstr[ len ] = 0;
-      
-      _aguix->setFG(usegc,1);
-      if(font==NULL) _aguix->DrawText(twin,tstr,dx,dy);
-      else _aguix->DrawText(twin,font,tstr,dx,dy);
+    vislen = _aguix->getStrlen4Width( tstr + first_vis_char, restwidth, &strwidth, font );
+    
+    if ( vislen > 0 ) {
+      tstr[first_vis_char + vislen] = '\0';
+
+      _aguix->setFG( usegc, 1 );
+      if ( font == NULL ) _aguix->DrawText( win, tstr + first_vis_char, inner_x + dx, inner_y + dy );
+      else _aguix->DrawText( win, font, tstr + first_vis_char, inner_x + dx, inner_y + dy );
     }
   }
   _freesafe(tstr);
@@ -275,22 +317,17 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 {
   bool returnvalue;
   returnvalue=false;
-  int cw;
   int tx,ty;
   AGMessage *agmsg;
+  int oldselstart;
   
   if ( isCreated() == false ) return false;
 
-  if(font==NULL) {
-    cw=_aguix->getCharWidth();
-  } else {
-    cw=font->getCharWidth();
-  }
   if(active==true) {
     if(msg->type==ButtonPress) {
-      if(msg->window!=twin) {
+      if ( msg->window != win ) {
         active=false;
-        tredraw();
+        redraw();
 //        returnvalue=true;
         agmsg = AGUIX_allocAGMessage();
         agmsg->type=AG_STRINGGADGET_DEACTIVATE;
@@ -300,15 +337,20 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
       } else {
         if(forbidPosChange==false) {
 	  _aguix->queryPointer(msg->window,&tx,&ty);
-          int nc=tx/cw;
-	  if ( nc < maxdisplay ) {
-	    cursorpos=nc+xoffset;
-	    if(cursorpos>=(int)strlen(text)) cursorpos=(int)strlen(text);
-	    if(cursorpos<0) cursorpos=0;
-	    selstart=selend=cursorpos;
-	    if(msg->button==Button2) insertSelection();
-	    redraw();
-	  }
+
+	  int bw = getBorderWidth();
+	  tx -= bw;
+	  ty -= bw;
+
+	  int l, strwidth;
+	  l = _aguix->getStrlen4Width( text + xoffset, a_max( tx - 2, 0 ), &strwidth, font );
+	  
+	  cursorpos = l + xoffset;
+	  if ( cursorpos >= (int)strlen( text ) ) cursorpos = (int)strlen( text );
+	  if ( cursorpos < 0 ) cursorpos = 0;
+	  selstart=selend=cursorpos;
+	  if(msg->button==Button2) insertSelection();
+	  redraw();
 	}
       }
     } else {
@@ -327,30 +369,32 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		    (msg->key==XK_Right))||
 		   ((msg->key==XK_f)&&(keystate==ControlMask))) {
 		  if(cursorpos<(int)strlen(text)) {
-		    cursorpos++;
-		    if((cursorpos-xoffset)>=maxdisplay) xoffset++;
+		    oldselstart = selstart;
+		    setCursor( cursorpos + 1 );
+		    selstart = oldselstart;
 		    if(keystate!=ShiftMask) selstart=selend=cursorpos;
 		    else {
 		      selend=cursorpos;
 		      applySelection();
 		    }
-		    tredraw();
+		    textRedraw();
 		    returnvalue=true;
 		  } else if ( ( selstart != selend ) && ( keystate != ShiftMask ) ) {
 		    // selection active and normal cursor right
 		    // => deactivate selection
 		    selstart = selend = cursorpos;
-		    tredraw();
+		    textRedraw();
 		    returnvalue = true;
 		  }
 		} else if(((keystate&Mod1Mask)==Mod1Mask)||
 			  (msg->key==XK_End)||
 			  ((msg->key==XK_e)&&(keystate==ControlMask))) {
-		  cursorpos=(int)strlen(text);
-		  while((cursorpos-xoffset)>=maxdisplay) xoffset++;
+		  oldselstart = selstart;
+		  setCursor( (int)strlen( text ) ); 
+		  selstart = oldselstart;
 		  if((keystate&ShiftMask)==0) selstart=selend=cursorpos;
 		  else selend=cursorpos;
-		  tredraw();
+		  textRedraw();
 		  returnvalue=true;
 		}
 		agmsg = AGUIX_allocAGMessage();
@@ -375,13 +419,13 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		      selend=cursorpos;
 		      applySelection();
 		    }
-		    tredraw();
+		    textRedraw();
 		    returnvalue=true;
 		  } else if ( ( selstart != selend ) && ( keystate != ShiftMask ) ) {
 		    // selection active and normal cursor left
 		    // => deactivate selection
 		    selstart = selend = cursorpos;
-		    tredraw();
+		    textRedraw();
 		    returnvalue = true;
 		  }
 		} else if(((keystate&Mod1Mask)==Mod1Mask)||
@@ -391,7 +435,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		  cursorpos=0;
 		  if((keystate&ShiftMask)==0) selstart=selend=cursorpos;
 		  else selend=cursorpos;
-		  tredraw();
+		  textRedraw();
 		  returnvalue=true;
 		}
 		agmsg = AGUIX_allocAGMessage();
@@ -404,7 +448,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 	      if(strongkeycapture==true) returnvalue=true;
 	      if(selstart!=selend) {
 		removeSelection();
-		tredraw();
+		textRedraw();
 	      } else if((cursorpos<len)&&(len>0)) {
 		char *tstr=(char*)_allocsafe(len);
 		strncpy(tstr,text,cursorpos);
@@ -412,7 +456,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		if(cursorpos<len) strcat(tstr,text+cursorpos+1);
 		_freesafe(text);
 		text=tstr;
-		tredraw();
+		textRedraw();
 		returnvalue=true;
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CONTENTCHANGE;
@@ -424,7 +468,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 	      if(strongkeycapture==true) returnvalue=true;
 	      if(selend!=selstart) {
 		removeSelection();
-		tredraw();
+		textRedraw();
 	      } else if(cursorpos>0) {
 		char *tstr=(char*)_allocsafe(len);
 		tstr[0]=0;
@@ -438,7 +482,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		cursorpos--;
 		if((cursorpos-xoffset)<0) xoffset--;
 		selstart=selend=cursorpos;
-		tredraw();
+		textRedraw();
 		returnvalue=true;
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CONTENTCHANGE;
@@ -455,11 +499,11 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 			( ( msg->key >= XK_BackSpace ) && ( msg->key <= XK_Escape ) ) ) {
 	      // catch this special keys even they are not handled
 	      // so they will not be added to the text
-	    } else if ( ( strlen( msg->keybuf ) > 0 ) && ( keystate != ControlMask ) ) {
+	    } else if ( ( strlen( msg->keybuf ) > 0 ) && ( ( keystate & ControlMask ) == 0 ) ) {
 	      int len = strlen( text );
 	      if ( selstart != selend ) {
 		removeSelection();
-		tredraw();
+		textRedraw();
 	      }
 	      char *tstr = (char*)_allocsafe(len + strlen( msg->keybuf ) + 1 );
 	      strncpy( tstr, text, cursorpos );
@@ -467,10 +511,9 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 	      strcat( tstr, text + cursorpos);
 	      _freesafe( text );
 	      text = tstr;
-	      cursorpos += strlen( msg->keybuf );
-	      while ( ( cursorpos - xoffset ) >= maxdisplay ) xoffset++;
+	      setCursor( cursorpos + strlen( msg->keybuf ) );
 	      selstart = selend = cursorpos;
-	      tredraw();
+	      textRedraw();
 	      returnvalue = true;
 	      agmsg = AGUIX_allocAGMessage();
 	      agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
@@ -486,7 +529,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 	    if((msg->key==XK_Return)||(msg->key==XK_Escape)) {
 	      active=false;
 	      selstart=selend=cursorpos;
-	      tredraw();
+	      redraw();
 	      returnvalue=true;
 	      agmsg = AGUIX_allocAGMessage();
 	      agmsg->type=AG_STRINGGADGET_DEACTIVATE;
@@ -533,26 +576,40 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 	}
       } else if(msg->type==ButtonRelease) {
         applySelection();
-      } else if(E->type==MotionNotify) {
+      } else if ( msg->type == MotionNotify &&
+		  msg->window == win &&
+		  ( msg->keystate & Button1Mask ) == Button1Mask ) {
         _aguix->queryPointer(msg->window,&tx,&ty);
-        int nc=tx/cw;
-        int ncp=nc+xoffset;
-        if(ncp>=(int)strlen(text)) ncp=strlen(text);
-        if(ncp<0) ncp=0;
-	cursorpos=ncp;
-	if((nc<0)&&(xoffset>0)) {
+
+	int bw = getBorderWidth();
+	tx -= bw;
+	ty -= bw;
+
+	if ( ( tx < 0 ) && ( xoffset > 0 ) ){
 	  xoffset--;
-	  cursorpos=xoffset;
-	} else if((nc>=maxdisplay)&&(((int)strlen(text)-xoffset)>=maxdisplay)) {
-	  xoffset++;
-	  cursorpos=xoffset+maxdisplay-1;
+	  cursorpos = xoffset;
+	} else if ( tx >= getInnerWidth() ) {
+	  int l, strwidth;
+	  l = _aguix->getStrlen4Width( text + xoffset, a_min( tx , getInnerWidth() ) - 2, &strwidth, font );
+
+	  cursorpos = l + xoffset;
+	  if ( cursorpos < (int)strlen( text ) ) xoffset++;
+	} else {
+	  int l, strwidth;
+	  l = _aguix->getStrlen4Width( text + xoffset, tx - 2, &strwidth, font );
+
+	  int ncp = l + xoffset;
+	  if(ncp>=(int)strlen(text)) ncp=strlen(text);
+	  if(ncp<0) ncp=0;
+	  cursorpos=ncp;
 	}
+
 	selend=cursorpos;
         redraw();
       }
     }
   } else if(msg->type==ButtonPress) {
-    if(msg->window==twin) {
+    if ( msg->window == win ) {
       takeFocus();
       active=true;
 //      returnvalue=true;
@@ -562,21 +619,26 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
       _aguix->putAGMsg(agmsg);
       if(forbidPosChange==false) {
         _aguix->queryPointer(msg->window,&tx,&ty);
-        int nc=tx/cw;
-	if ( nc < maxdisplay ) {
-	  cursorpos=nc+xoffset;
-	  if(cursorpos>=(int)strlen(text)) cursorpos=(int)strlen(text);
-	  if(cursorpos<0) cursorpos=0;
-	  selstart=selend=cursorpos;
-	  if(msg->button==Button2) insertSelection();
-	}
+
+	int bw = getBorderWidth();
+	tx -= bw;
+	ty -= bw;
+
+	int l, strwidth;
+	l = _aguix->getStrlen4Width( text + xoffset, a_max( tx - 2, 0 ), &strwidth, font );
+	cursorpos = l + xoffset;
+	if(cursorpos>=(int)strlen(text)) cursorpos=(int)strlen(text);
+	if(cursorpos<0) cursorpos=0;
+	selstart=selend=cursorpos;
+	if(msg->button==Button2) insertSelection();
       }
       redraw();
     }
   }
   if(msg->type==Expose) {
-    if(msg->window==win) bredraw();
-    else if(msg->window==twin) tredraw();
+    if ( msg->window == win ) {
+      redraw();
+    }
   }
   return returnvalue;
 }
@@ -590,7 +652,7 @@ void StringGadget::setText(const char *new_text)
   }
   selstart=selend=cursorpos;
   setXOffset( xoffset );
-  tredraw();
+  textRedraw();
 }
 
 const char *StringGadget::getText() const
@@ -608,19 +670,9 @@ void StringGadget::updateWin()
   int i1;
 
   if ( isCreated() == true ) {
-    _parent->resizeSubWin(twin,_w-6,_h-6);
-    if(font==NULL) maxdisplay=(_w-6-2)/_aguix->getCharWidth();
-    else maxdisplay=(_w-6-2)/font->getCharWidth();
-    
-    // make the cursor visible again
-    if ( maxdisplay > 0 ) {
-      // makes no sense if there is no char visible
-      i1 = a_min( selstart, selend );
-      // try to move xoffset as most left as possible while cursor remains visible
-      xoffset = i1 - maxdisplay + 1;
-      if ( xoffset < 0 ) xoffset = 0;
-    }
-    tredraw();
+    i1 = a_min( selstart, selend );
+    setXOffset( i1 );
+    textRedraw();
   }
 }
 
@@ -628,13 +680,13 @@ void StringGadget::activate()
 {
   active=true;
   ignoreRelease=true;
-  tredraw();
+  redraw();
 }
 
 void StringGadget::deactivate()
 {
   active=false;
-  tredraw();
+  redraw();
 }
 
 void StringGadget::applySelection()
@@ -725,7 +777,6 @@ bool StringGadget::isParent(Window child) const
 {
   if ( isCreated() == false ) return false;
   if(child==win) return true;
-  if(child==twin) return true;
   return false;
 }
 
@@ -736,13 +787,25 @@ int StringGadget::getXOffset() const
 
 void StringGadget::setXOffset( int new_pos )
 {
-  xoffset = new_pos;
+  int l, strwidth, newx;
 
-  if ( ( xoffset + maxdisplay - 1) > (int)strlen( text ) ) {
-    xoffset = (int)strlen( text ) - maxdisplay + 1;
+  xoffset = new_pos;
+  if ( xoffset >= (int)strlen( text ) ) xoffset = (int)strlen( text );
+
+  newx = xoffset;
+  while ( newx >= 0 ) {
+    l = _aguix->getStrlen4Width( text + newx, getInnerWidth() - 2, &strwidth, font );
+    
+    if ( ( l + newx ) == (int)strlen( text ) ) {
+      // everything visible reduce xoffset
+      // lower means not everything is visible, higher is not possible
+      xoffset = newx;
+      newx--;
+    } else break;
   }
+
   if ( xoffset < 0 ) xoffset = 0;
-  tredraw();
+  textRedraw();
 }
 
 int StringGadget::getCursor() const
@@ -752,6 +815,8 @@ int StringGadget::getCursor() const
 
 void StringGadget::setCursor( int new_pos )
 {
+  int newx, l, strwidth;
+
   cursorpos = new_pos;
 
   if ( cursorpos > (int)strlen( text ) )
@@ -762,9 +827,17 @@ void StringGadget::setCursor( int new_pos )
 
   if ( ( cursorpos - xoffset ) < 0 )
     xoffset = cursorpos;
-  if ( ( cursorpos - xoffset ) >= maxdisplay )
-    xoffset = cursorpos - maxdisplay + 1;
-  setXOffset( xoffset );
+
+  newx = xoffset;
+  for (;;) {
+    l = _aguix->getStrlen4Width( text + newx, getInnerWidth() - 2, &strwidth, font );
+    if ( ( l + newx ) == (int)strlen( text ) ) break;
+    else if ( cursorpos >= ( l + newx ) ) {
+      newx++;
+    } else break;
+  }
+
+  setXOffset( newx );
 }
 
 bool StringGadget::isPosChangeForbidden() const
@@ -820,19 +893,10 @@ void StringGadget::cancelcut()
 void StringGadget::doCreateStuff()
 {
   GUIElement::doCreateStuff();
-  if ( twin == 0 ) {
-    twin=_parent->getSubWindow(win,3,3,_w-6,_h-6);
-  }
-  if(font==NULL) maxdisplay=(_w-6-2)/_aguix->getCharWidth();
-  else maxdisplay=(_w-6-2)/font->getCharWidth();
 }
 
 void StringGadget::doDestroyStuff()
 {
-  if ( twin != 0 ) {
-    _parent->removeSubWin(twin);
-    twin = 0;
-  }
   GUIElement::doDestroyStuff();
 }
 
@@ -852,17 +916,17 @@ void StringGadget::insertAtCursor( const char *str )
   strcat( tstr, text + cursorpos );
   _freesafe( text );
   text = tstr;
-  redraw();
+  textRedraw();
 }
 
 void StringGadget::selectAll()
 {
   cursorpos=(int)strlen(text);
-  while ( ( cursorpos - xoffset ) >= maxdisplay ) xoffset++;
+  setXOffset( cursorpos );
   selstart = 0;
   selend = cursorpos;
   applySelection();
-  tredraw();
+  redraw();
 }
 
 void StringGadget::setPasswordMode( bool nv )
@@ -875,7 +939,7 @@ void StringGadget::lostFocus()
 {
   if ( active == true ) {
     active = false;
-    tredraw();
+    redraw();
     AGMessage *agmsg = AGUIX_allocAGMessage();
     agmsg->type = AG_STRINGGADGET_DEACTIVATE;
     agmsg->stringgadget.sg = this;
@@ -894,3 +958,52 @@ void StringGadget::gotFocus()
     _aguix->putAGMsg( agmsg );
   }
 }
+
+int StringGadget::getInnerWidth() const
+{
+  int bw = getBorderWidth();
+  return _w - 2 * bw;
+}
+
+void StringGadget::prepareBG( bool force )
+{
+  if ( isCreated() == false ) return;
+  if ( win == 0 ) return;
+
+  _aguix->SetWindowBG( win, _parent->getBG() );
+}
+
+int StringGadget::getBorderWidth() const
+{
+  int bw;
+
+  bw = 4;
+  
+  return bw;
+}
+
+int StringGadget::clearTextBG()
+{
+  if ( isCreated() == false ) return 1;
+
+  int bw = getBorderWidth();
+  int maxcol=_aguix->getMaxCols();
+  int newbg;
+  GC usegc;
+  
+  if ( active == true ) {
+    if(maxcol>7) {
+      newbg=7;
+    } else {
+      newbg=0;
+    }
+  } else {
+    newbg=0;
+  }
+  
+  if(font==NULL) usegc=0; else usegc=font->getGC();
+  
+  _aguix->setFG( usegc, newbg );
+  _aguix->FillRectangle( win, usegc, bw, bw, getInnerWidth(), _h - 2 * bw );
+  return 0;
+}
