@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: stringgadget.h,v 1.18 2005/05/15 13:47:42 ralf Exp $ */
+/* $Id: stringgadget.h,v 1.20 2005/10/05 19:44:51 ralf Exp $ */
 
 #ifndef STRINGGADGET_H
 #define STRINGGADGET_H
@@ -72,10 +72,6 @@ private:
   int xoffset;
   bool active;
   static const char *type;
-  Window twin;
-  int tbg;
-  bool bgset;
-  int maxdisplay;
   int selstart,selend;
   class AGUIXFont *font;
   bool forbidPosChange;
@@ -83,8 +79,7 @@ private:
   bool strongkeycapture;
   
   void updateWin();
-  void tredraw();
-  void bredraw();
+  void textRedraw();
   void applySelection();
   void removeSelection();
   void insertSelection();
@@ -94,6 +89,12 @@ private:
   bool passwordMode;
   void lostFocus();
   void gotFocus();
+
+  int getInnerWidth() const;
+
+  void prepareBG( bool force = false );
+  int getBorderWidth() const;
+  int clearTextBG();
 };
 
 #endif
