@@ -1,6 +1,6 @@
 /* util.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: util.cc,v 1.17 2004/10/27 20:43:10 ralf Exp $ */
+/* $Id: util.cc,v 1.18 2005/11/22 20:40:04 ralf Exp $ */
 
 #include "util.h"
 #include "lowlevelfunc.h"
@@ -696,6 +696,18 @@ void *ArrayList::getNextElement()
   return array[actindex];
 }
 
+void *ArrayList::getPrevElement()
+{
+  if(elements==0) return NULL;
+  if((actindex<0)||(actindex>=elements)) return NULL;
+  actindex--;
+  if(actindex<0) {
+    actindex=-1;
+    return NULL;
+  }
+  return array[actindex];
+}
+
 void *ArrayList::getFirstElement(int id)
 {
   if((id<0)||(id>=enums)) return NULL;
@@ -734,6 +746,19 @@ void *ArrayList::getNextElement(int id)
   return array[acts[id]];
 }
 
+void *ArrayList::getPrevElement(int id)
+{
+  if((id<0)||(id>=enums)) return NULL;
+  if(elements==0) return NULL;
+  if((acts[id]<0)||(acts[id]>=elements)) return NULL;
+  acts[id]--;
+  if(acts[id]<0) {
+    acts[id]=-1;
+    return NULL;
+  }
+  return array[acts[id]];
+}
+
 int ArrayList::getIndex(void *obj) const
 {
   if(obj==NULL) return -1;
