@@ -1,6 +1,6 @@
 /* util.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: util.h,v 1.10 2004/10/27 20:43:05 ralf Exp $ */
+/* $Id: util.h,v 1.11 2005/11/22 20:39:59 ralf Exp $ */
 
 #ifndef UTIL_H
 #define UTIL_H
@@ -109,10 +109,12 @@ public:
   void *getElementAt(int,int);
   void *getLastElement(int);
   void *getNextElement(int);
+  void *getPrevElement(int);
   void *getFirstElement();
   void *getElementAt(int);
   void *getLastElement();
   void *getNextElement();
+  void *getPrevElement();
   int getIndex(void *) const;
   void sort(int (*relfunc)(void*,void*));
   void sort(int (*relfunc)(void*,void*,int),int);
