@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: basic_actions.cc,v 1.24 2005/05/15 14:03:55 ralf Exp $ */
+/* $Id: basic_actions.cc,v 1.27 2005/12/04 20:00:38 ralf Exp $ */
 
 #include "basic_actions.h"
 #include "listermode.h"
@@ -55,10 +55,9 @@ DNDAction *DNDAction::duplicate() const
   return dnda;
 }
 
-int DNDAction::run(ActionMessage *msg)
+int DNDAction::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  FunctionProto::run( msg );
   // do nothing in case of DND
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
@@ -66,7 +65,7 @@ int DNDAction::run(ActionMessage *msg)
       lm1=l1->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmodedndaction();
+          normalmodedndaction( msg );
     }
   }
   return 0;
@@ -77,7 +76,7 @@ const char *DNDAction::getDescription()
   return catalog.getLocaleCom(0);
 }
 
-void DNDAction::normalmodedndaction()
+void DNDAction::normalmodedndaction( ActionMessage *am )
 {
   ListerMode *lm1;
   Lister *l1 = am->getWorker()->getActiveLister();
@@ -214,19 +213,18 @@ DoubleClickAction *DoubleClickAction::duplicate() const
   return ta;
 }
 
-int DoubleClickAction::run(ActionMessage *msg)
+int DoubleClickAction::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmodeddaction();
+          normalmodeddaction( msg );
     }
-  } else normalmodeddaction();
+  } else normalmodeddaction( msg );
   return 0;
 }
 
@@ -235,7 +233,7 @@ const char *DoubleClickAction::getDescription()
   return catalog.getLocaleCom(1);
 }
 
-void DoubleClickAction::normalmodeddaction()
+void DoubleClickAction::normalmodeddaction( ActionMessage *am )
 {
   ListerMode *lm1;
   Lister *l1;
@@ -399,19 +397,18 @@ ShowAction *ShowAction::duplicate() const
   return ta;
 }
 
-int ShowAction::run(ActionMessage *msg)
+int ShowAction::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmodeshow();
+          normalmodeshow( msg );
     }
-  } else normalmodeshow();
+  } else normalmodeshow( msg );
   return 0;
 }
 
@@ -420,7 +417,7 @@ const char *ShowAction::getDescription()
   return catalog.getLocaleCom(2);
 }
 
-void ShowAction::normalmodeshow()
+void ShowAction::normalmodeshow( ActionMessage *am )
 {
   ListerMode *lm1;
   NormalMode *nm=NULL;
@@ -584,19 +581,18 @@ RawShowAction *RawShowAction::duplicate() const
   return ta;
 }
 
-int RawShowAction::run(ActionMessage *msg)
+int RawShowAction::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmoderawshow();
+          normalmoderawshow( msg );
     }
-  } else normalmoderawshow();
+  } else normalmoderawshow( msg );
   return 0;
 }
 
@@ -605,7 +601,7 @@ const char *RawShowAction::getDescription()
   return catalog.getLocaleCom(3);
 }
 
-void RawShowAction::normalmoderawshow()
+void RawShowAction::normalmoderawshow( ActionMessage *am )
 {
   ListerMode *lm1;
   NormalMode *nm=NULL;
@@ -772,19 +768,18 @@ UserAction *UserAction::duplicate() const
   return ta;
 }
 
-int UserAction::run(ActionMessage *msg)
+int UserAction::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
       lm1=l1->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmodeuseraction();
+          normalmodeuseraction( msg );
     }
-  } else normalmodeuseraction();
+  } else normalmodeuseraction( msg );
   return 0;
 }
 
@@ -793,7 +788,7 @@ const char *UserAction::getDescription()
   return catalog.getLocaleCom(4);
 }
 
-void UserAction::normalmodeuseraction()
+void UserAction::normalmodeuseraction( ActionMessage *am )
 {
   ListerMode *lm1;
   NormalMode *nm=NULL;
@@ -919,24 +914,23 @@ void UserAction::normalmodeuseraction()
 int UserAction::configure()
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   AWindow *win;
   CycleButton *rcyb;
-  int tw,w,h,x,y,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   char *tstr;
   
-  w=h=10;
-  x=y=5;
-
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(4))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(4));
-  win =new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win =new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
-  rcyb=(CycleButton*)win->add(new CycleButton(aguix,x,y,100,1,0,0));
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  rcyb = (CycleButton*)ac1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 0, 0, AContainer::CINCW );
   rcyb->addOption(catalog.getLocale(255));
   rcyb->addOption(catalog.getLocale(256));
   rcyb->addOption(catalog.getLocale(257));
@@ -950,40 +944,29 @@ int UserAction::configure()
   rcyb->resize(rcyb->getMaxSize(),rcyb->getHeight());
   rcyb->setOption(nr);
   
-  y+=rcyb->getHeight()+5;
-  tw=x+rcyb->getWidth()+5;
-  if(tw>w) w=tw;
-  x=5;
-
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  w-5-t2,
-                                  y,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
+  ac1->readLimits();
   
-  h=y;
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( -1 );
+  ac1_1->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_1->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, AContainer::CFIX );
+  Button *cb = (Button*)ac1_1->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, AContainer::CFIX );
+
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMaxSize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
@@ -1079,11 +1062,10 @@ const char *ChangeHiddenFlag::getName()
   return name;
 }
 
-int ChangeHiddenFlag::run(ActionMessage *msg)
+int ChangeHiddenFlag::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -1133,24 +1115,23 @@ const char *ChangeHiddenFlag::getDescription()
 int ChangeHiddenFlag::configure()
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   AWindow *win;
   CycleButton *rcyb;
-  int tw,w,h,x,y,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   char *tstr;
   
-  w=h=10;
-  x=y=5;
-
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(7))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(7));
-  win=new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win=new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
-  rcyb=(CycleButton*)win->add(new CycleButton(aguix,x,y,100,1,0,0));
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  rcyb = (CycleButton*)ac1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 0, 0, AContainer::CINCW );
   rcyb->addOption(catalog.getLocale(360));
   rcyb->addOption(catalog.getLocale(361));
   rcyb->addOption(catalog.getLocale(362));
@@ -1166,41 +1147,29 @@ int ChangeHiddenFlag::configure()
       rcyb->setOption(0);
       break;
   }
+  ac1->readLimits();
   
-  y+=rcyb->getHeight()+5;
-  tw=x+rcyb->getWidth()+5;
-  if(tw>w) w=tw;
-  x=5;
-
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  w-5-t2,
-                                  y,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( -1 );
+  ac1_1->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_1->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, AContainer::CFIX );
+  Button *cb = (Button*)ac1_1->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, AContainer::CFIX );
   
-  h=y;
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMaxSize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
