@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: basic_actions.h,v 1.11 2004/10/27 21:05:26 ralf Exp $ */
+/* $Id: basic_actions.h,v 1.12 2005/10/19 18:08:00 ralf Exp $ */
 
 #ifndef BASIC_ACTIONS_H
 #define BASIC_ACTIONS_H
@@ -40,13 +40,13 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 
   static List *getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags );
 protected:
   static const char *name;
-  void normalmodedndaction();
+  void normalmodedndaction( ActionMessage *am );
 };
 
 class DoubleClickAction:public FunctionProto
@@ -63,13 +63,13 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 
   static List *getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags );
 protected:
   static const char *name;
-  void normalmodeddaction();
+  void normalmodeddaction( ActionMessage *am );
 };
 
 class ShowAction:public FunctionProto
@@ -86,13 +86,13 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 
   static List *getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags );
 protected:
   static const char *name;
-  void normalmodeshow();
+  void normalmodeshow( ActionMessage *am );
 };
 
 class RawShowAction:public FunctionProto
@@ -109,13 +109,13 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 
   static List *getActionList( class WCFiletype *filetype, int id, WCGlobalFlags **return_flags );
 protected:
   static const char *name;
-  void normalmoderawshow();
+  void normalmoderawshow( ActionMessage *am );
 };
 
 class UserAction:public FunctionProto
@@ -132,7 +132,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
   virtual bool save(Datei*);
   virtual int configure();
@@ -143,7 +143,7 @@ public:
 protected:
   static const char *name;
   int nr;
-  void normalmodeuseraction();
+  void normalmodeuseraction( ActionMessage *am );
 };
 
 class ChangeHiddenFlag:public FunctionProto
@@ -160,7 +160,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
   virtual int configure();
