@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: changesymlinkop.h,v 1.9 2004/10/27 21:05:39 ralf Exp $ */
+/* $Id: changesymlinkop.h,v 1.10 2005/10/19 18:07:34 ralf Exp $ */
 
 #ifndef CHANGESYMLINKOP_H
 #define CHANGESYMLINKOP_H
@@ -46,7 +46,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 protected:
   static const char *name;
@@ -55,7 +55,7 @@ protected:
   // temp variables
   Lister *startlister;
   
-  int normalmodechangesl();
+  int normalmodechangesl( ActionMessage* );
 };
 
 #endif
