@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: chownop.cc,v 1.13 2005/05/15 15:53:10 ralf Exp $ */
+/* $Id: chownop.cc,v 1.15 2005/10/19 18:07:08 ralf Exp $ */
 
 #include "chownop.h"
 #include "listermode.h"
@@ -64,11 +64,10 @@ ChOwnOp::getName()
 }
 
 int
-ChOwnOp::run( ActionMessage *msg )
+ChOwnOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
 
-  am = msg;
   if ( msg->mode != msg->AM_MODE_DNDACTION ) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if ( l1 != NULL ) {
@@ -76,7 +75,7 @@ ChOwnOp::run( ActionMessage *msg )
       lm1 = startlister->getActiveMode();
       if ( lm1 != NULL )
         if ( lm1->isType( "NormalMode" ) == true )
-          normalmodechown();
+          normalmodechown( msg );
     }
   }
   return 0;
@@ -100,7 +99,7 @@ ChOwnOp::getDescription()
 }
 
 int
-ChOwnOp::normalmodechown()
+ChOwnOp::normalmodechown( ActionMessage *am )
 {
   NormalMode *nm1 = NULL;
   ListerMode *lm1 = NULL;
@@ -166,78 +165,69 @@ int
 ChOwnOp::doconfigure( int mode )
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb, *cb;
   AWindow *win;
   ChooseButton *ofcb, *odcb, *rfcb = NULL, *rcb;
-  int tw, w, h, x, y;
   AGMessage *msg;
   int endmode = -1;
   char *tstr;
-  GUIElement *li[2];
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
   
-  w = h = 10;
-  x = y = 5;
   tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( catalog.getLocaleCom( 43 ) ) + 1 );
   sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 43 ) );
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe( tstr );
 
-  Text *tt1 = (Text*)win->add( new Text( aguix, x, y, catalog.getLocaleCom( 43 ), 1 ) );
-  y += tt1->getHeight() + 5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 6 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
 
-  ofcb = (ChooseButton*)win->add( new ChooseButton( aguix, x, y, ( onfiles == true ) ? 1 : 0,
-                                                    catalog.getLocale( 295 ), LABEL_RIGHT, 1, 0 ) );
-  y += ofcb->getHeight() + 5;
-  tw = ofcb->getWidth() + 10;
-  if ( tw > w ) w = tw;
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocaleCom( 43 ), 1 ), 0, 0, cincwnr );
 
-  odcb = (ChooseButton*)win->add( new ChooseButton( aguix, x, y, ( ondirs == true ) ? 1 : 0,
-                                                    catalog.getLocale( 296 ), LABEL_RIGHT, 1, 0 ) );
-  y += odcb->getHeight() + 5;
-  tw = odcb->getWidth() + 10;
-  if ( tw > w ) w = tw;
+  ofcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( onfiles == true ) ? 1 : 0,
+                                                    catalog.getLocale( 295 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
 
-  rcb = (ChooseButton*)win->add( new ChooseButton( aguix, x, y, ( recursive == true ) ? 1 : 0,
-                                                   catalog.getLocale( 297 ), LABEL_RIGHT, 1, 0 ) );
-  y += rcb->getHeight() + 5;
-  tw = rcb->getWidth() + 10;
-  if ( tw > w ) w = tw;
+  odcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( ondirs == true ) ? 1 : 0,
+                                                    catalog.getLocale( 296 ), LABEL_RIGHT, 1, 0 ), 0, 2, cincwnr );
+
+  rcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( recursive == true ) ? 1 : 0,
+                                                   catalog.getLocale( 297 ), LABEL_RIGHT, 1, 0 ), 0, 3, cincwnr );
 
   if ( mode == 0 ) {
-    rfcb = (ChooseButton*)win->add( new ChooseButton( aguix, x, y, ( requestflags == true ) ? 1 : 0,
-                                                      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ) );
-    y += rfcb->getHeight() + 5;
-    tw = rfcb->getWidth() + 10;
-    if ( tw > w ) w = tw;
+    rfcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( requestflags == true ) ? 1 : 0,
+                                                      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ), 0, 4, cincwnr );
   }
 
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  5,
-                                  y,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  li[0] = okb;
-  li[1] = cb;
-  tw = AGUIX::scaleElementsW( w, 5, 10, -1, false, false, li, NULL, 2 );
-  if ( tw > w ) w = tw;
-  y += okb->getHeight() + 5;
-  
-  h = y;
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 5 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( -1 );
+  ac1_1->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_1->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_1->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
+
   okb->takeFocus();
   win->setDoTabCycling( true );
-  win->resize( w, h );
-  win->setMaxSize( w, h );
-  win->setMinSize( w, h );
+  win->contMaximize( true );
   win->show();
   for( ; endmode == -1; ) {
     msg = aguix->WaitMessage( win );
