@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: condparser.cc,v 1.7 2005/03/08 22:38:11 ralf Exp $ */
+/* $Id: condparser.cc,v 1.8 2005/05/15 15:53:16 ralf Exp $ */
 
 #include "condparser.h"
 #include <aguix/lowlevelfunc.h>
@@ -1077,8 +1077,8 @@ const char *CondParser::requestFlag()
   w=400;
   h=300;
   x=y=5;
-  win=new AWindow(aguix);
-  win->create(NULL,10,10,w,h,0,catalog.getLocale(338));
+  win = new AWindow( aguix, 10, 10, w, h, 0, catalog.getLocale( 338 ) );
+  win->create();
 
   win->addTextFromString( catalog.getLocale( 578 ), x, y, 5, NULL, NULL, &y );
   y += 5;
@@ -1168,7 +1168,6 @@ const char *CondParser::requestFlag()
     }
   }
   
-  win->close();
   delete win;
 
   return returnstr;
