@@ -309,14 +309,23 @@
      CUSTOMFILES_WCP = 532,
      SHOWMODE_WCP = 533,
      SELECTED_WCP = 534,
-     ERROR = 535,
-     ACTIVESIDE_WCP = 536,
-     SHOWFREESPACE_WCP = 537,
-     ACTIVEMODE_WCP = 538,
-     ASK_WCP = 539,
-     SSHALLOW_WCP = 540,
-     STRING_WCP = 541,
-     NUM_WCP = 542
+     REVERSESEARCH_WCP = 535,
+     MOUSECONF_WCP = 536,
+     SELECTBUTTON_WCP = 537,
+     ACTIVATEBUTTON_WCP = 538,
+     SCROLLBUTTON_WCP = 539,
+     SELECTMETHOD_WCP = 540,
+     ALTERNATIVE_WCP = 541,
+     ERROR = 542,
+     ACTIVESIDE_WCP = 543,
+     SHOWFREESPACE_WCP = 544,
+     ACTIVEMODE_WCP = 545,
+     ASK_WCP = 546,
+     SSHALLOW_WCP = 547,
+     FIELD_WIDTH_WCP = 548,
+     QUICKSEARCHENABLED_WCP = 549,
+     STRING_WCP = 550,
+     NUM_WCP = 551
    };
 #endif
 #define LEFTBRACE_WCP 258
@@ -596,14 +605,23 @@
 #define CUSTOMFILES_WCP 532
 #define SHOWMODE_WCP 533
 #define SELECTED_WCP 534
-#define ERROR 535
-#define ACTIVESIDE_WCP 536
-#define SHOWFREESPACE_WCP 537
-#define ACTIVEMODE_WCP 538
-#define ASK_WCP 539
-#define SSHALLOW_WCP 540
-#define STRING_WCP 541
-#define NUM_WCP 542
+#define REVERSESEARCH_WCP 535
+#define MOUSECONF_WCP 536
+#define SELECTBUTTON_WCP 537
+#define ACTIVATEBUTTON_WCP 538
+#define SCROLLBUTTON_WCP 539
+#define SELECTMETHOD_WCP 540
+#define ALTERNATIVE_WCP 541
+#define ERROR 542
+#define ACTIVESIDE_WCP 543
+#define SHOWFREESPACE_WCP 544
+#define ACTIVEMODE_WCP 545
+#define ASK_WCP 546
+#define SSHALLOW_WCP 547
+#define FIELD_WIDTH_WCP 548
+#define QUICKSEARCHENABLED_WCP 549
+#define STRING_WCP 550
+#define NUM_WCP 551
 
 
 
@@ -615,7 +633,7 @@ typedef union {
   char *strptr;
 } yystype;
 /* Line 1281 of /usr/share/bison/yacc.c.  */
-#line 619 "configparser.tab.h"
+#line 637 "configparser.tab.h"
 # define YYSTYPE yystype
 #endif
 
