@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: configtokens.cc,v 1.20 2005/05/19 19:47:05 ralf Exp $ */
+/* $Id: configtokens.cc,v 1.24 2005/12/11 19:25:53 ralf Exp $ */
 
 #include "wdefines.h"
 #include <aguix/util.h>
@@ -305,7 +305,16 @@ struct mytoken tokenlist[]={
   { INTERNALVIEWOP_WCP, "internalviewop" },
   { CUSTOMFILES_WCP, "customfiles" },
   { SHOWMODE_WCP, "showmode" },
-  { SELECTED_WCP, "selected" }
+  { SELECTED_WCP, "selected" },
+  { FIELD_WIDTH_WCP, "field_width" },
+  { REVERSESEARCH_WCP, "reversesearch" },
+  { QUICKSEARCHENABLED_WCP, "quicksearchenabled"},
+  { MOUSECONF_WCP, "mouseconf" },
+  { SELECTBUTTON_WCP, "selectbutton" },
+  { ACTIVATEBUTTON_WCP, "activatebutton" },
+  { SCROLLBUTTON_WCP, "scrollbutton" },
+  { SELECTMETHOD_WCP, "selectmethod" },
+  { ALTERNATIVE_WCP, "alternative" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
