@@ -1,6 +1,6 @@
 /* copyop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: copyop.cc,v 1.66 2005/06/27 17:44:30 ralf Exp $ */
+/* $Id: copyop.cc,v 1.69 2005/10/19 18:06:50 ralf Exp $ */
 
 #include "listermode.h"
 #include "normalmode.h"
@@ -74,10 +74,9 @@ CopyOp::getName()
 }
 
 int
-CopyOp::run(ActionMessage *msg)
+CopyOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -86,10 +85,10 @@ CopyOp::run(ActionMessage *msg)
       lm1=startlister->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmodecopy();
+          normalmodecopy( msg );
     }
   } else {
-    normalmodecopy();
+    normalmodecopy( msg );
   }
   return 0;
 }
@@ -137,7 +136,7 @@ CopyOp::getDescription()
 }
 
 int
-CopyOp::normalmodecopy()
+CopyOp::normalmodecopy( ActionMessage *am )
 {
   struct NM_copyorder copyorder;
   NormalMode *nm1=NULL,
@@ -317,67 +316,56 @@ int
 CopyOp::doconfigure(int mode)
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   AWindow *win;
   ChooseButton *fscb,*mcb,*rcb,*sdcb,*rfcb=NULL,*rdcb,*pacb;
 //  CycleButton *ocyb,*fccyb;
   CycleButton *fccyb;
-  Text *ttext;
-  int tw,w,h,x,y,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   Requester *req;
   char *tstr;
   int i;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
   
   req=new Requester(aguix);
-  w=h=10;
-  x=y=5;
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(8))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(8));
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
-  ttext = (Text*)win->add( new Text( aguix, x, y, catalog.getLocaleCom( 8 ), 1 ) );
-  y += ttext->getHeight() + 5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 10 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
 
-  fscb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,20,20,(follow_symlinks==true)?1:0,
-                                                catalog.getLocale(298),LABEL_RIGHT,1,0));
-  y+=fscb->getHeight()+5;
-  tw=fscb->getWidth()+10;
-  if(tw>w) w=tw;
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocaleCom( 8 ), 1 ), 0, 0, cincwnr );
 
-  mcb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,20,20,(move==true)?1:0,
-                                               catalog.getLocale(299),LABEL_RIGHT,1,0));
-  y+=mcb->getHeight()+5;
-  tw=mcb->getWidth()+10;
-  if(tw>w) w=tw;
+  fscb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( follow_symlinks == true ) ? 1 : 0,
+						    catalog.getLocale( 298 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
 
-  rcb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,20,20,(do_rename==true)?1:0,
-                                               catalog.getLocale(300),LABEL_RIGHT,1,0));
-  y+=rcb->getHeight()+5;
-  tw=rcb->getWidth()+10;
-  if(tw>w) w=tw;
+  mcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( move == true ) ? 1 : 0,
+						   catalog.getLocale( 299 ), LABEL_RIGHT, 1, 0 ), 0, 2, cincwnr );
 
-  sdcb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,20,20,(same_dir==true)?1:0,
-                                                catalog.getLocale(301),LABEL_RIGHT,1,0));
-  y+=sdcb->getHeight()+5;
-  tw=sdcb->getWidth()+10;
-  if(tw>w) w=tw;
+  rcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( do_rename == true ) ? 1 : 0,
+						   catalog.getLocale( 300 ), LABEL_RIGHT, 1, 0 ), 0, 3, cincwnr );
 
-  rdcb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,20,20,(request_dest==true)?1:0,
-                                                catalog.getLocale(302),LABEL_RIGHT,1,0));
-  y+=rdcb->getHeight()+5;
-  tw=rdcb->getWidth()+10;
-  if(tw>w) w=tw;
+  sdcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( same_dir == true ) ? 1 : 0,
+						    catalog.getLocale( 301 ), LABEL_RIGHT, 1, 0 ), 0, 4, cincwnr );
 
-  pacb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,20,20,(preserve_attr==true)?1:0,
-                                                catalog.getLocale(150),LABEL_RIGHT,1,0));
-  y+=pacb->getHeight()+5;
-  tw=pacb->getWidth()+10;
-  if(tw>w) w=tw;
+  rdcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( request_dest == true ) ? 1 : 0,
+						    catalog.getLocale( 302 ), LABEL_RIGHT, 1, 0 ), 0, 5, cincwnr );
+
+  pacb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( preserve_attr == true ) ? 1 : 0,
+						    catalog.getLocale( 150 ), LABEL_RIGHT, 1, 0 ), 0, 6, cincwnr );
 
 /*  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(303),1));
   x+=ttext->getWidth()+5;
@@ -403,9 +391,13 @@ CopyOp::doconfigure(int mode)
   if(tw>w) w=tw;
   x=5;*/
 
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(307),1));
-  x+=ttext->getWidth()+5;
-  fccyb=(CycleButton*)win->add(new CycleButton(aguix,x,y,100,1,0,0));
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 7 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 307 ), 1 ), 0, 0, cfix );
+  fccyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
   fccyb->addOption(catalog.getLocale(308));
   fccyb->addOption(catalog.getLocale(309));
 //  fccyb->addOption("schnellster Modus");
@@ -421,50 +413,35 @@ CopyOp::doconfigure(int mode)
       fccyb->setOption(0);
       break;
   }
+  ac1_1->readLimits();
   
-  y+=fccyb->getHeight()+5;
-  tw=x+fccyb->getWidth()+5;
-  if(tw>w) w=tw;
-  x=5;
-
   if(mode==0) {
-    rfcb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,20,20,(request_flags==true)?1:0,
-                                                  catalog.getLocale(294),LABEL_RIGHT,1,0));
-    y+=rfcb->getHeight()+5;
-    tw=rfcb->getWidth()+10;
-    if(tw>w) w=tw;
+    rfcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( request_flags == true ) ? 1 : 0,
+						      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ), 0, 8, cincwnr );
   }
 
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  w-5-t2,
-                                  y,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 9 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_2->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
   
-  h=y;
   okb->takeFocus();
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMaxSize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
@@ -711,6 +688,10 @@ CopyOpWin::CopyOpWin( AGUIX*taguix, bool _move )
   glob_percent = 0;
   
   move = _move;
+  
+  lencalc = new AFontWidth( aguix, NULL );
+  memset( &stoptime, 0, sizeof( stoptime ) );
+  timer_stopped = false;
 }
 
 CopyOpWin::~CopyOpWin()
@@ -718,6 +699,7 @@ CopyOpWin::~CopyOpWin()
   if(source!=NULL) _freesafe(source);
   if(dest!=NULL) _freesafe(dest);
   if(window!=NULL) close();
+  delete lencalc;
 }
 
 int
@@ -793,9 +775,7 @@ CopyOpWin::open(bool tslim)
   tx=5;
   bb4=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,2,0));
   ty+=bb4->getHeight()+5;
-  cb=(Button*)window->add(new Button(aguix,tx,ty,
-                                     (strlen(catalog.getLocale(8))+2)*aguix->getCharWidth(),
-                                     catalog.getLocale(8),1,0,0));
+  cb = (Button*)window->add( new Button( aguix, tx, ty, catalog.getLocale( 8 ), 1, 0, 0 ) );
   cb->move(w/2-cb->getWidth()/2,cb->getY());
   ty+=cb->getHeight()+5;
   h=ty;
@@ -806,10 +786,10 @@ CopyOpWin::open(bool tslim)
   window->centerScreen();
   window->show();
 
-  filenamespace[0] = ( w - window->getBorderWidth() - sourcetext->getX() ) / aguix->getCharWidth();
-  filenamespace[0] -= strlen( catalog.getLocale( ( move == true ) ? 594 : 116 ) ) - 2;
-  filenamespace[1] = ( w - window->getBorderWidth() - desttext->getX() ) / aguix->getCharWidth();
-  filenamespace[1] -= strlen(catalog.getLocale(117)) - 2;
+  filenamespace[0] = w - window->getBorderWidth() - sourcetext->getX();
+  filenamespace[0] -= aguix->getTextWidth( catalog.getLocale( ( move == true ) ? 594 : 116 ) ) - 2 * aguix->getTextWidth( " " );
+  filenamespace[1] = w - window->getBorderWidth() - desttext->getX();
+  filenamespace[1] -= aguix->getTextWidth( catalog.getLocale( 117 ) ) - 2 * aguix->getTextWidth( " " );
 
   return 0;
 }
@@ -941,7 +921,7 @@ CopyOpWin::redraw()
   timerclear( &curtime );
   if ( ( update_sourcetext == true ) && ( ismessage[0] == false ) ) {
     if ( source != NULL ) {
-      tstr3 = Datei::shrinkFilename( source, filenamespace[0] );
+      tstr3 = Datei::shrinkFilename( source, filenamespace[0], *lencalc );
       if ( tstr3 == NULL)
         tstr3 = dupstring( source );
       tstr2 = (char*)_allocsafe( strlen( catalog.getLocale( ( move == true ) ? 594 : 116 ) ) + strlen( tstr3 ) + 1 );
@@ -958,7 +938,7 @@ CopyOpWin::redraw()
   }
   if ( ( update_desttext == true ) && ( ismessage[1] == false ) ) {
     if ( dest != NULL ) {
-      tstr3 = Datei::shrinkFilename( dest, filenamespace[1] );
+      tstr3 = Datei::shrinkFilename( dest, filenamespace[1], *lencalc );
       if ( tstr3 == NULL)
         tstr3 = dupstring( dest );
       tstr2 = (char*)_allocsafe( strlen( catalog.getLocale( 117 ) ) + strlen( tstr3 ) + 1 );
@@ -1154,10 +1134,10 @@ CopyOpWin::redraw()
             cb->move( msg->size.neww / 2 - cb->getWidth() / 2,
                       msg->size.newh - window->getBorderWidth() - cb->getHeight() );
             
-            filenamespace[0] = ( msg->size.neww - window->getBorderWidth() - sourcetext->getX() ) / aguix->getCharWidth();
-            filenamespace[0] -= strlen( catalog.getLocale( ( move == true ) ? 594 : 116 ) ) - 2;
-            filenamespace[1] = ( msg->size.neww - window->getBorderWidth() - desttext->getX() ) / aguix->getCharWidth();
-            filenamespace[1] -= strlen(catalog.getLocale(117)) - 2;
+            filenamespace[0] = msg->size.neww - window->getBorderWidth() - sourcetext->getX();
+            filenamespace[0] -= aguix->getTextWidth( catalog.getLocale( ( move == true ) ? 594 : 116 ) ) - 2 * aguix->getTextWidth( " " );
+            filenamespace[1] = msg->size.neww - window->getBorderWidth() - desttext->getX();
+            filenamespace[1] -= aguix->getTextWidth( catalog.getLocale( 117 ) ) - 2 * aguix->getTextWidth( " " );
             update_sourcetext = true;
             update_desttext = true;
   
@@ -1236,6 +1216,7 @@ void
 CopyOpWin::stoptimer()
 {
   gettimeofday( &stoptime, NULL );
+  timer_stopped = true;
 }
 
 void
@@ -1244,6 +1225,8 @@ CopyOpWin::conttimer()
   struct timeval curtime;
   long s, us;
 
+  if ( timer_stopped == false ) return;
+  
   gettimeofday( &curtime, NULL );
   
   s = curtime.tv_sec - stoptime.tv_sec;
