@@ -1,6 +1,6 @@
 /* copyop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: copyop.h,v 1.29 2004/10/27 21:06:41 ralf Exp $ */
+/* $Id: copyop.h,v 1.32 2005/10/19 18:06:46 ralf Exp $ */
 
 #ifndef COPYOP_H
 #define COPYOP_H
@@ -32,6 +32,7 @@
 #include <aguix/cyclebutton.h>
 #include <aguix/bevelbox.h>
 #include <aguix/request.h>
+#include <aguix/awidth.h>
 
 class CopyOp:public FunctionProto
 {
@@ -47,7 +48,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
   virtual int configure();
@@ -93,7 +94,7 @@ protected:
   overwrite_t toverwrite;
   fastcopy_t tfastcopy;
 
-  int normalmodecopy();
+  int normalmodecopy( ActionMessage *am );
   int requestdest( const char *defaultstr, char **dest );
 };
 
@@ -190,6 +191,9 @@ protected:
 */
   int glob_percent;
   bool move;
+  AFontWidth *lencalc;
+
+  bool timer_stopped;
 };
 
 #endif
