@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: cursorops.cc,v 1.22 2005/05/15 15:54:12 ralf Exp $ */
+/* $Id: cursorops.cc,v 1.24 2005/10/19 18:06:21 ralf Exp $ */
 
 #include "cursorops.h"
 #include "listermode.h"
@@ -57,11 +57,10 @@ RowUp *RowUp::duplicate() const
   return ta;
 }
 
-int RowUp::run(ActionMessage *msg)
+int RowUp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -116,11 +115,10 @@ RowDown *RowDown::duplicate() const
   return ta;
 }
 
-int RowDown::run(ActionMessage *msg)
+int RowDown::run( WPUContext *wpu, ActionMessage *msg)
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -175,11 +173,10 @@ FirstRow *FirstRow::duplicate() const
   return ta;
 }
 
-int FirstRow::run(ActionMessage *msg)
+int FirstRow::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -234,11 +231,10 @@ LastRow *LastRow::duplicate() const
   return ta;
 }
 
-int LastRow::run(ActionMessage *msg)
+int LastRow::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -293,11 +289,10 @@ PageUp *PageUp::duplicate() const
   return ta;
 }
 
-int PageUp::run(ActionMessage *msg)
+int PageUp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -352,11 +347,10 @@ PageDown *PageDown::duplicate() const
   return ta;
 }
 
-int PageDown::run(ActionMessage *msg)
+int PageDown::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -411,11 +405,10 @@ SelectOp *SelectOp::duplicate() const
   return ta;
 }
 
-int SelectOp::run(ActionMessage *msg)
+int SelectOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -470,11 +463,10 @@ SelectAllOp *SelectAllOp::duplicate() const
   return ta;
 }
 
-int SelectAllOp::run(ActionMessage *msg)
+int SelectAllOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -529,11 +521,10 @@ SelectNoneOp *SelectNoneOp::duplicate() const
   return ta;
 }
 
-int SelectNoneOp::run(ActionMessage *msg)
+int SelectNoneOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -588,11 +579,10 @@ InvertAllOp *InvertAllOp::duplicate() const
   return ta;
 }
 
-int InvertAllOp::run(ActionMessage *msg)
+int InvertAllOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -647,11 +637,10 @@ ParentDirOp *ParentDirOp::duplicate() const
   return ta;
 }
 
-int ParentDirOp::run(ActionMessage *msg)
+int ParentDirOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -819,28 +808,37 @@ const char *EnterDirOp::getDescription()
 int EnterDirOp::configure()
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   AWindow *win;
   CycleButton *rcyb;
   StringGadget *sg;
-  Text *ttext;
-  int tw,w,h,x,y,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   char *tstr;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
   
-  w=h=10;
-  x=y=5;
-
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(18))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(18));
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(317),1));
-  x+=ttext->getWidth()+5;
-  rcyb=(CycleButton*)win->add(new CycleButton(aguix,x,y,100,1,0,0));
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 0 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 317 ), 1 ), 0, 0, cfix );
+  rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
   rcyb->addOption(catalog.getLocale(318));
   rcyb->addOption(catalog.getLocale(319));
   rcyb->addOption(catalog.getLocale(320));
@@ -860,62 +858,48 @@ int EnterDirOp::configure()
       rcyb->setOption(0);
       break;
   }
+  ac1_1->readLimits();
   
-  y+=rcyb->getHeight()+5;
-  tw=x+rcyb->getWidth()+5;
-  if(tw>w) w=tw;
-  x=5;
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 4, 1 ), 0, 1 );
+  ac1_2->setMinSpace( 0 );
+  ac1_2->setMaxSpace( 0 );
+  ac1_2->setBorderWidth( 0 );
 
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(322),1));
-  x+=ttext->getWidth()+5;
-  tw=w-x-5;
-  if ( tw < ( 30 * aguix->getCharWidth() ) ) tw = 30 * aguix->getCharWidth();
-  sg=(StringGadget*)win->add(new StringGadget(aguix,x,y,tw,dir,0));
-  x += sg->getWidth();
-  Button *sgb = (Button*)win->add( new Button( aguix,
-                                               x,
-                                               y,
-                                               "F",
-                                               1,
-                                               0,
-                                               0 ) );
+  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 322 ), 1 ), 0, 0, cfix );
+  ac1_2->setMinWidth( 5, 1, 0 );
+  ac1_2->setMaxWidth( 5, 1, 0 );
+  sg = (StringGadget*)ac1_2->add( new StringGadget( aguix, 0, 0, 100, dir, 0 ), 2, 0, cincw );
+  Button *sgb = (Button*)ac1_2->add( new Button( aguix,
+						 0,
+						 0,
+						 "F",
+						 1,
+						 0,
+						 0 ), 3, 0, cfix );
   sgb->resize( sgb->getWidth(), sg->getHeight() );
+  ac1_2->readLimits();
 
-  y+=sg->getHeight()+5;
-  tw = sgb->getX() + sgb->getWidth() + 5;
-  if(tw>w) w=tw;
-  x=5;
+  AContainer *ac1_3 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ac1_3->setMinSpace( 5 );
+  ac1_3->setMaxSpace( -1 );
+  ac1_3->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_3->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_3->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
 
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  w-5-t2,
-                                  y,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
-  rcyb->resize( sgb->getX() + sgb->getWidth() - rcyb->getX(), rcyb->getHeight() );
-  
-  h=y;
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMaxSize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
