@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: datei.cc,v 1.114 2005/07/13 19:44:03 ralf Exp $ */
+/* $Id: datei.cc,v 1.116 2005/08/17 06:28:37 ralf Exp $ */
 
 #include "datei.h"
 #include <aguix/lowlevelfunc.h>
@@ -1059,8 +1059,6 @@ int FileEntry::writeDestination2Buf(char *buf,int size2,bool terminated)
   return x;
 }
 
-extern double d1,d2,d3;
-
 void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerTypes::listcol_t> *dis )
 {
   int mlen=0;
@@ -1071,10 +1069,14 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
   std::string s1;
   int ost, x;
   char nbuf[ A_BYTESFORNUMBER( loff_t ) ];
+  int cur_field;
   
   if ( ( lv == NULL ) || ( dis == NULL ) ) return;
   
+  cur_field = 0;
   for ( int i = 0; i < (int)dis->size(); i++ ) {
+    if ( i > 0 ) cur_field++;
+    
     switch( (*dis)[i]) {
       case WorkerTypes::LISTCOL_NAME:
         s1 = "";
@@ -1093,8 +1095,8 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
           else if ( isExe() == true ) s1 += '*';
           else s1 += ' ';
         }
-        s1 += name;
-        lv->setText( row, 2 * i, s1 );
+	s1 += name;
+        lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_SIZE:
         if ( S_ISCHR( statbuf.mode ) ||
@@ -1105,7 +1107,7 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
           s1 += ", ";
           snprintf( nbuf, sizeof( nbuf ), "%3d", x & 0xff );
           s1 += nbuf;
-          lv->setText( row, 2 * i, s1 );
+          lv->setText( row, cur_field, s1 );
         } else {
           if ( ( isDir() == true ) &&
                ( isLink == false ) &&
@@ -1120,10 +1122,10 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
           }
           if(sfds==true) {
             s1 = wconfig->getStringForDirSize();
-            lv->setText( row, 2 * i, s1 );
+            lv->setText( row, cur_field, s1 );
           } else {
 	    MakeLong2NiceStr( dissize, s1 );
-            lv->setText( row, 2 * i, s1 );
+            lv->setText( row, cur_field, s1 );
           }
         }
         break;
@@ -1138,11 +1140,11 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
             s1 = wconfig->getnotyettype()->getName();
           }
         }
-        lv->setText( row, 2 * i, s1 );
+        lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_PERM:
         s1 = getPermissionString();
-        lv->setText( row, 2 * i, s1 );
+        lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_OWNER:
         // will be 1 for Owner.group, 0 else
@@ -1155,16 +1157,16 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
           s1 += " @ ";
         }
         s1 += ugdb->getGroupNameS( statbuf.groupid );
-        lv->setText( row, 2 * i, s1 );
+        lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_DEST:
         str = getDestination();
         if ( str != NULL ) {
           // only if there will be something to print
-          lv->setText( row, 2 * i, str );
+          lv->setText( row, cur_field, str );
           _freesafe( str );
         } else {
-          lv->setText( row, 2 * i, "" );
+          lv->setText( row, cur_field, "" );
         }
         break;
       case WorkerTypes::LISTCOL_MOD:
@@ -1176,7 +1178,7 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
         str[ x ] = '\0';
         s1 = str;
         _freesafe( str );
-        lv->setText( row, 2 * i, s1 );
+        lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_ACC:
         timeptr = localtime( &( statbuf.lastaccess ) );
@@ -1187,7 +1189,7 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
         str[ x ] = '\0';
         s1 = str;
         _freesafe( str );
-        lv->setText( row, 2 * i, s1 );
+        lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_CHANGE:
         timeptr = localtime( &( statbuf.lastchange ) );
@@ -1198,26 +1200,27 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
         str[ x ] = '\0';
         s1 = str;
         _freesafe( str );
-        lv->setText( row, 2 * i, s1 );
+        lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_INODE:
         li = (loff_t)statbuf.inode;
 	MakeLong2NiceStr( li, s1, false );
-        lv->setText( row, 2 * i, s1 );
+        lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_NLINK:
         li = (loff_t)statbuf.nlink;
 	MakeLong2NiceStr( li, s1, false );
-        lv->setText( row, 2 * i, s1 );
+        lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_BLOCKS:
         li = (loff_t)statbuf.blocks;
 	MakeLong2NiceStr( li, s1, false );
-        lv->setText( row, 2 * i, s1 );
+        lv->setText( row, cur_field, s1 );
         break;
       default:
         break;
     }
+    cur_field++;
   }
   
   if ( customcolors == true ) {
@@ -2110,30 +2113,27 @@ ArrayList *Verzeichnis::getInvalidEntries()
   return invalid_entries;
 }
 
-char *Datei::shrinkFilename( const char *str, int maxlength )
+char *Datei::shrinkFilename( const char *str, int maxlength, AWidth &lencalc )
 {
   char *tstr = NULL;
-  int len, len1, len2, leftuse;
+  int len, len1, len2;
   bool stopnow;
   const char *lastl, *lastr, *startl, *startr, *str1;
   const char *filename;
+  int dddlen;
+  int l1, l2, l3, real_width;
+  std::string tstr1;
   
-  // first test for null pointer
   if ( str == NULL )
     return NULL;
   
-  // now test if maxlength if big enough
-  // let 5 chars be the minimum (1 at the beginning, 3 for "...", 1 at the end)
-  if ( maxlength < 5 )
-    return NULL;
-  
-  // from now we will always return a shorten string
-  
-  // now test if the str will fit in maxlength
+  // test if the str will fit in maxlength
   len = strlen( str );
-  if( len <= maxlength )
+  if( ( lencalc.getWidth( str, len ) <= maxlength ) || ( len <= 5 ) )
     return dupstring( str );
   
+  dddlen = lencalc.getWidth( "..."  );
+
   // now we really have to do something
   
   // first find the most important part, the filename
@@ -2172,16 +2172,14 @@ char *Datei::shrinkFilename( const char *str, int maxlength )
   
   if ( str1 < str ) {
     // no slash (or only a final one)
-    return shrinkstring( str, maxlength );
+    return shrinkstring( str, maxlength, lencalc );
   } else {
     // found filename
     // we will also take the slash into it
     filename = str1;
     
-    // longer then maxlength-5 ?
-    // then short with shrinkstring
-    if ( ( (int)strlen( filename ) ) > ( maxlength - 5 ) )
-      return shrinkstring( str, maxlength );
+    if ( lencalc.getWidth( filename ) + lencalc.getWidth( "/.../" ) > maxlength )
+      return shrinkstring( str, maxlength, lencalc );
     
     // enough room for some additional chars
     startl = str;
@@ -2220,14 +2218,22 @@ char *Datei::shrinkFilename( const char *str, int maxlength )
         len1 = startl - str + 1;
         len2 = len - ( lastr - str );  // ( lastr - str ) is the number of chars before lastr!
                                        // but because we sub it from len, don't add 1 like before
-        if ( ( len1 + 3 + len2 ) <= maxlength ) {
+
+	l1 = lencalc.getWidth( str, len1 );
+	l2 = lencalc.getWidth( lastr );
+
+        if ( ( l1 + dddlen + l2 ) <= maxlength ) {
           // new dir at the left will fit
           lastl = startl;
         }
         
         len1 = lastl - str + 1;
         len2 = len - ( startr - str );
-        if ( ( len1 + 3 + len2 ) <= maxlength ) {
+
+	l1 = lencalc.getWidth( str, len1 );
+	l2 = lencalc.getWidth( startr );
+
+        if ( ( l1 + dddlen + l2 ) <= maxlength ) {
           // new dir at the right will fit
           lastr = startr;
         }
@@ -2240,27 +2246,36 @@ char *Datei::shrinkFilename( const char *str, int maxlength )
       
       if ( stopnow == true ) {
         // time to stop
-        tstr = (char*)_allocsafe( sizeof(char) * ( maxlength + 1 ) );
         if ( lastl == str ) {
           // no fitting dirs found
           // so take as much as possibly
-          // use maxlength - 3 - strlen( filename) chars from left
-          leftuse = maxlength - 3 - strlen( filename );
-          strncpy( tstr, str, leftuse );
-          strncpy( tstr + leftuse, "...", 3 );
-          strncpy( tstr + leftuse + 3, filename, maxlength - 3 - leftuse );
-          tstr[ maxlength ] = '\0';
+
+	  l1 = lencalc.getWidth( filename );
+	  l1 += dddlen;
+	  l2 = maxlength - l1;
+	  
+	  if ( l2 > 0 ) {
+	    l3 = lencalc.getStrlen4Width( str, l2, &real_width );
+	    
+	    tstr1 = "";
+	    tstr1.append( str, l3 );
+	    tstr1 += "...";
+	    tstr1 += filename;
+	    tstr = dupstring( tstr1.c_str() );
+	  } else {
+	    tstr = shrinkstring( str, maxlength, lencalc );
+	  }
         } else {
           len1 = ( lastl - str + 1);
-          strncpy( tstr, str, len1 );
-          strncpy( tstr + len1, "...", 3 );
-          len1 += 3;
-          len2 = maxlength - len1;  // chars left in tstr
-          strncpy( tstr + len1, lastr, len2 );
-          // if there were less then len2 chars in lastr
-          // then tstr will be null-terminated
-          // otherwise we have to set the end
-          tstr[ maxlength ] = '\0';
+	  tstr1 = "";
+	  tstr1.append( str, len1 );
+	  tstr1 += "...";
+	  tstr1 += lastr;
+	  if ( lencalc.getWidth( tstr1.c_str() ) > maxlength ) {
+	    tstr = shrinkstring( str, maxlength, lencalc );
+	  } else {
+	    tstr = dupstring( tstr1.c_str() );
+	  }
         }
         break;
       }
