@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: datei.h,v 1.59 2005/07/13 19:43:27 ralf Exp $ */
+/* $Id: datei.h,v 1.60 2005/08/17 06:27:52 ralf Exp $ */
 
 #ifndef DATEI_H
 #define DATEI_H
@@ -30,6 +30,7 @@
 #include "worker_types.h"
 #include <vector>
 #include <list>
+#include <aguix/awidth.h>
 
 /* vvv Nur eins davon kann gleichzeitig aktiv sein, also durch numerieren */
 enum { SORT_NAME = 0,
@@ -97,7 +98,7 @@ public:
   static char *getNameWithoutExt(const char*);
   static char *createTMPName();
   static char *createTMPName( const char *infix );
-  static char *shrinkFilename( const char *str, int maxlength );
+  static char *shrinkFilename( const char *str, int maxlength, AWidth &lencalc );
   static loff_t fileSize( const char * );
   static char *getRelativePath( const char *source, const char *destdir );
   static int copyfile( const char *dest, const char *source );
