@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: deleteop.cc,v 1.28 2005/05/15 15:54:18 ralf Exp $ */
+/* $Id: deleteop.cc,v 1.30 2005/10/19 18:06:01 ralf Exp $ */
 
 #include "listermode.h"
 #include "normalmode.h"
@@ -58,10 +58,9 @@ DeleteOp::getName()
 }
 
 int
-DeleteOp::run(ActionMessage *msg)
+DeleteOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -69,7 +68,7 @@ DeleteOp::run(ActionMessage *msg)
       lm1=startlister->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmodedelete();
+          normalmodedelete( msg );
     }
   }
   return 0;
@@ -82,7 +81,7 @@ DeleteOp::getDescription()
 }
 
 int
-DeleteOp::normalmodedelete()
+DeleteOp::normalmodedelete( ActionMessage *am )
 {
   struct NM_deleteorder delorder;
   NormalMode *nm1=NULL;
@@ -118,56 +117,54 @@ DeleteOp::normalmodedelete()
 
 int DeleteOp::configure()
 {
-  int w,h,tw,ty,tx;
-  int t1,t2;
   ChooseButton *cb;
   AGUIX *aguix = Worker::getAGUIX();
   AWindow *win;
   char *tstr;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
 
-  w=h=10;
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(25))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(25));
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
   
-  ty=5;
-  tx=5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
 
-  cb=(ChooseButton*)win->add(new ChooseButton(aguix,tx,ty,20,20,(also_active==true)?1:0,
-                                              catalog.getLocale(153),LABEL_RIGHT,1,0));
-  ty+=cb->getHeight()+5;
-  tw=cb->getWidth()+10;
-  if(tw>w) w=tw;
+  cb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( also_active == true ) ? 1 : 0,
+						  catalog.getLocale( 153 ), LABEL_RIGHT, 1, 0 ), 0, 0, cincwnr );
   
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  Button *okb=(Button*)win->add(new Button(aguix,
-                                             5,
-                                             ty,
-                                             t1,
-                                             catalog.getLocale(11),
-                                             1,
-                                             0,
-                                             0));
-  Button *cancelb=(Button*)win->add(new Button(aguix,
-                                                 w-5-t2,
-                                                 ty,
-                                                 t2,
-                                                 catalog.getLocale(8),
-                                                 1,
-                                                 0,
-                                                 0));
-  h=okb->getY()+okb->getHeight()+5;
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( -1 );
+  ac1_1->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_1->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cancelb = (Button*)ac1_1->add( new Button( aguix,
+						     0,
+						     0,
+						     catalog.getLocale( 8 ),
+						     1,
+						     0,
+						     0 ), 1, 0, cfix );
+
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMinSize(w,h);
-  win->setMaxSize(w,h);
+  win->contMaximize( true );
   win->show();
   AGMessage *msg;
   while((msg=aguix->GetMessage(NULL))!=NULL) aguix->ReplyMessage(msg);
@@ -224,12 +221,15 @@ DeleteOpWin::DeleteOpWin(AGUIX*taguix)
   update_sourcetext = false;
   update_files2gotext = false;
   update_dirs2gotext = false;
+  
+  lencalc = new AFontWidth( aguix, NULL );
 }
 
 DeleteOpWin::~DeleteOpWin()
 {
   if(source!=NULL) _freesafe(source);
   if(window!=NULL) close();
+  delete lencalc;
 }
 
 int
@@ -271,9 +271,8 @@ DeleteOpWin::open()
 
   bb3=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,2,0));
   ty+=bb3->getHeight()+5;
-  cb=(Button*)window->add(new Button(aguix,tx,ty,
-                                     (strlen(catalog.getLocale(8))+2)*aguix->getCharWidth(),
-                                     catalog.getLocale(8),1,0,0));
+  cb = (Button*)window->add( new Button( aguix, tx, ty,
+					 catalog.getLocale( 8 ), 1, 0, 0 ) );
   cb->move(w/2-cb->getWidth()/2,cb->getY());
   ty+=cb->getHeight()+5;
   h=ty;
@@ -284,8 +283,8 @@ DeleteOpWin::open()
   window->centerScreen();
   window->show();
 
-  filenamespace = ( w - window->getBorderWidth() - sourcetext->getX() ) / aguix->getCharWidth();
-  filenamespace -= strlen(catalog.getLocale(141)) - 2;
+  filenamespace = w - window->getBorderWidth() - sourcetext->getX();
+  filenamespace -= aguix->getTextWidth( catalog.getLocale( 141 ) ) - 2 * aguix->getTextWidth( " " );
 
   return 0;
 }
@@ -358,7 +357,7 @@ DeleteOpWin::redraw()
 
   if ( ( update_sourcetext == true ) && ( ismessage == false ) ) {
     if ( source != NULL ) {
-      tstr3 = Datei::shrinkFilename( source, filenamespace );
+      tstr3 = Datei::shrinkFilename( source, filenamespace, *lencalc );
       if ( tstr3 == NULL)
         tstr3 = dupstring( source );
       tstr2 = (char*)_allocsafe( strlen( catalog.getLocale( 141 ) ) + strlen( tstr3 ) + 1 );
@@ -445,8 +444,8 @@ DeleteOpWin::redraw()
             cb->move( msg->size.neww / 2 - cb->getWidth() / 2,
                       msg->size.newh - window->getBorderWidth() - cb->getHeight() );
   
-            filenamespace = ( msg->size.neww - window->getBorderWidth() - sourcetext->getX() ) / aguix->getCharWidth();
-            filenamespace -= strlen(catalog.getLocale(141)) - 2;
+            filenamespace = msg->size.neww - window->getBorderWidth() - sourcetext->getX();
+            filenamespace -= aguix->getTextWidth( catalog.getLocale( 141 ) ) - 2 * aguix->getTextWidth( " " );
   
             // read copyop.cc:CopyOpWin::redraw for more comments
           }
