@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: deleteop.h,v 1.14 2004/10/27 21:07:05 ralf Exp $ */
+/* $Id: deleteop.h,v 1.16 2005/10/19 18:05:57 ralf Exp $ */
 
 #ifndef DELETEOP_H
 #define DELETEOP_H
@@ -32,6 +32,7 @@
 #include <aguix/cyclebutton.h>
 #include <aguix/bevelbox.h>
 #include <aguix/request.h>
+#include <aguix/awidth.h>
 
 class DeleteOp:public FunctionProto
 {
@@ -47,7 +48,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
   virtual int configure();
   virtual bool save(Datei *);
@@ -61,7 +62,7 @@ protected:
   // temp variables
   Lister *startlister;
   
-  int normalmodedelete();
+  int normalmodedelete( ActionMessage *am );
 };
 
 class DeleteOpWin
@@ -118,6 +119,7 @@ protected:
   int melw;
   int filenamespace;
   bool ismessage;
+  AFontWidth *lencalc;
 };
 
 #endif
