@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: dirsizeop.h,v 1.8 2004/10/27 21:07:10 ralf Exp $ */
+/* $Id: dirsizeop.h,v 1.9 2005/10/19 18:05:45 ralf Exp $ */
 
 #ifndef DIRSIZEOP_H
 #define DIRSIZEOP_H
@@ -42,7 +42,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 protected:
   static const char *name;
@@ -51,7 +51,7 @@ protected:
   // temp variables
   Lister *startlister;
   
-  int normalmodedirsize();
+  int normalmodedirsize( ActionMessage *am );
 };
 
 #endif
