@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: dnd.cc,v 1.10 2004/12/12 21:57:00 ralf Exp $ */
+/* $Id: dnd.cc,v 1.11 2005/05/15 15:54:32 ralf Exp $ */
 
 #include "dnd.h"
 #include "lister.h"
@@ -96,7 +96,7 @@ void DNDMsg::setStart(AGDNDSTART*s)
 {
   Lister *l1,*l2;
   ListerMode *lm1=NULL,*lm2=NULL;
-  GUIElement *gel;
+  Widget *wel;
 
   if ( start.specialinfo.rowDataP != NULL ) delete start.specialinfo.rowDataP;
   start=*s;
@@ -121,15 +121,15 @@ void DNDMsg::setStart(AGDNDSTART*s)
       sl=l2;
     }
   }*/
-  gel=start.element;
+  wel = start.element;
   if(lm1!=NULL) {
-    if(lm1->isyours(gel)==true) {
+    if ( lm1->isyours( wel ) == true ) {
       slm=lm1;
       sl=l1;
     }
   }
   if((sl==NULL)&&(lm2!=NULL)) {
-    if(lm2->isyours(gel)==true) {
+    if ( lm2->isyours( wel ) == true ) {
       slm=lm2;
       sl=l2;
     }
@@ -140,7 +140,7 @@ void DNDMsg::setEnd(AGDNDEND*e)
 {
   Lister *l1,*l2;
   ListerMode *lm1=NULL,*lm2=NULL;
-  GUIElement *gel;
+  Widget *wel;
 
   if ( end.specialinfo.rowDataP != NULL ) delete end.specialinfo.rowDataP;
   end=*e;
@@ -165,16 +165,16 @@ void DNDMsg::setEnd(AGDNDEND*e)
       el=l2;
     }
   }*/
-  gel=end.element;
-  if(gel!=NULL) {
+  wel = end.element;
+  if ( wel != NULL ) {
     if(lm1!=NULL) {
-      if(lm1->isyours(gel)==true) {
+      if ( lm1->isyours( wel ) == true ) {
         elm=lm1;
         el=l1;
       }
     }
     if((el==NULL)&&(lm2!=NULL)) {
-      if(lm2->isyours(gel)==true) {
+      if ( lm2->isyours( wel ) == true ) {
         elm=lm2;
         el=l2;
       }
