@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: enterpathop.h,v 1.8 2004/10/27 21:07:18 ralf Exp $ */
+/* $Id: enterpathop.h,v 1.9 2005/10/19 18:05:34 ralf Exp $ */
 
 #ifndef ENTERPATHOP_H
 #define ENTERPATHOP_H
@@ -45,7 +45,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
   virtual int configure();
@@ -63,7 +63,7 @@ protected:
   // temp variables
   Lister *startlister;
   
-  void normalmodeenterpath();
+  void normalmodeenterpath( ActionMessage *am );
 };
 
 #endif
