@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: execlass.cc,v 1.16 2005/02/07 07:06:39 ralf Exp $ */
+/* $Id: execlass.cc,v 1.17 2005/07/13 19:56:15 ralf Exp $ */
 
 #include "execlass.h"
 #include <stdarg.h>
@@ -51,7 +51,10 @@ ExeClass::ExeClass( execlass_execute_t exetype, Worker *w )
   fp = worker_fopen( tmpfile, "w" );
   if ( fp != NULL ) {
     worker_chmod( tmpfile, S_IRUSR | S_IWUSR | S_IXUSR );
-    fprintf( fp, "#! /bin/sh\n\n" );
+    if ( fprintf( fp, "#! /bin/sh\n\n" ) < 0 ) {
+      worker_fclose( fp );
+      fp = NULL;
+    }
   }
   lasterror = 0;
 }
@@ -85,6 +88,7 @@ void ExeClass::addCommand( const char *format, ... )
   int n, size = 1024;
   char *tstr;
   std::string string1;
+  int error = 0;
   
   if ( ( fp != NULL ) && ( format != NULL ) ) {
     // first create command str
@@ -100,13 +104,18 @@ void ExeClass::addCommand( const char *format, ... )
     string1 = Worker_secureCommandForShell( tstr );
     _freesafe( tstr );
     if ( string1.length() > 0 ) {
-      fprintf( fp, "%s", string1.c_str() );
+      if ( fprintf( fp, "%s", string1.c_str() ) < 0 ) error++;
       if ( type == EXECUTE_SHOW_OUTPUT ) {
-        fprintf( fp, " >>%s\n", tmpoutput );
+        if ( fprintf( fp, " >>%s\n", tmpoutput ) < 0 ) error++;
       } else {
-        fprintf( fp, "\n" );
+        if ( fprintf( fp, "\n" ) < 0 ) error++;
       }
     }
+    if ( error != 0 ) {
+      worker_fclose( fp );
+      fp = NULL;
+      //TODO show requests?
+    }
   }
 }
 
@@ -115,6 +124,7 @@ void ExeClass::addCommand( const char *format, ... )
 void ExeClass::execute()
 {
   char *exestr = NULL;
+  int error = 0;
   
   if ( fp == NULL ) return;
 
@@ -123,8 +133,8 @@ void ExeClass::execute()
   if ( ( type == EXECUTE_TERMINAL_WAIT ) ||
        ( type == EXECUTE_TERMINAL ) ) {
     if ( type == EXECUTE_TERMINAL_WAIT ) {
-      fprintf( fp, "echo %s\n", catalog.getLocale( 201 ) );
-      fprintf( fp, "read x\n" );
+      if ( fprintf( fp, "echo %s\n", catalog.getLocale( 201 ) ) < 0 ) error++;
+      if ( fprintf( fp, "read x\n" ) < 0 ) error++;
     }
     exestr = (char*)_allocsafe( strlen( wconfig->getTerminalStr() ) +
                                 strlen( tmpfile ) + 1 );
@@ -133,12 +143,17 @@ void ExeClass::execute()
     exestr = dupstring( tmpfile );
   }
   if ( type == EXECUTE_SHOW_OUTPUT ) {
-    fprintf( fp, OUTPUT_BIN, tmpoutput );
-    fprintf( fp, "\n" );
+    if ( fprintf( fp, OUTPUT_BIN, tmpoutput ) < 0 ) error++;
+    if ( fprintf( fp, "\n" ) < 0 ) error++;
   }
-  worker_fclose( fp );
+  if ( worker_fclose( fp ) != 0 ) error++;
   fp = NULL;
-  system( exestr );
+
+  if ( error == 0 ) {
+    system( exestr );
+  } else {
+    //TODO show requests?
+  }
   _freesafe(exestr);
 
   if ( worker != NULL ) worker->unsetWaitCursor();
@@ -188,7 +203,11 @@ int ExeClass::getOutputAndRV( char **return_output, int *return_value, int *retu
   
   if ( worker != NULL ) worker->setWaitCursor();
 
-  worker_fclose( fp );
+  if ( worker_fclose( fp ) != 0 ) {
+    fp  = NULL; 
+    if ( worker != NULL ) worker->unsetWaitCursor();
+    return 1;
+  }
   fp = NULL;
 
   exestr = tmpfile;
@@ -228,12 +247,20 @@ int ExeClass::getOutputAndRV( char **return_output, int *return_value, int *retu
 void ExeClass::cdDir( const char *dir )
 {
   char *tstr;
+  int error = 0;
+  
   if ( ( fp != NULL ) && ( dir != NULL ) ) {
     if ( worker_islocal( dir ) == 1 ) {
       tstr = AGUIX_prepareForSingleQuote( dir );
-      fprintf( fp, "cd '%s'\n", tstr );
+      if ( fprintf( fp, "cd '%s'\n", tstr ) < 0 ) error++;
       _freesafe( tstr );
     }
+
+    if ( error != 0 ) {
+      worker_fclose( fp );
+      fp = NULL;
+      //TODO show requests?
+    }
   }
 }
 
