@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: filereq.cc,v 1.19 2005/05/15 15:54:50 ralf Exp $ */
+/* $Id: filereq.cc,v 1.21 2005/12/12 19:59:57 ralf Exp $ */
 
 #include "filereq.h"
 #include "worker_locale.h"
@@ -57,43 +57,58 @@ int FileRequester::request( const char *title,
   if((title==NULL)||(dir==NULL)||(oktext==NULL)||(canceltext==NULL)||(infotext==NULL)) return -1;
   if((actdir==NULL)&&(strlen(dir)==0)) return -1;
   reset();
-  int w=200;
-  int w2=strlen(oktext)+4+strlen(canceltext)+4;
-  w2*=aguix->getCharWidth();
-  w2+=30;
-  if(w2>w) w=w2;
-  w2=strlen(infotext)+2;
-  w2*=aguix->getCharWidth();
-  w2+=10;
-  if(w2>w) w=w2;
-  int h=3*aguix->getCharHeight()+50+150;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
+  const int cmin = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW;
 
-  AWindow *win = new AWindow( aguix, 10, 10, w, h, 0, title );
+  AWindow *win = new AWindow( aguix, 10, 10, 300, 200, 0, title );
   win->create();
-  win->setMinSize(w,h);
-  int ty,dh;
-  ty=5;
-  win->add(new Text(aguix,5,ty,infotext,1));
-  ty+=aguix->getCharHeight()+5;
-  lv = (FieldListView*)win->add( new FieldListView( aguix, 5, ty, w - 10, 150, 0 ) );
+
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  ac1->add( new Text( aguix, 0, 0, infotext, 1 ), 0, 0, cincwnr );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 1, 2 ), 0, 1 );
+  ac1_1->setMinSpace( 0 );
+  ac1_1->setMaxSpace( 0 );
+  ac1_1->setBorderWidth( 0 );
+
+  lv = (FieldListView*)ac1_1->add( new FieldListView( aguix, 0, 0, 200, 150, 0 ), 0, 0, cmin );
   lv->setHBarState(2);
   lv->setVBarState(2);
-  ty+=lv->getHeight();
-  sg=(StringGadget*)win->add(new StringGadget(aguix,5,ty,w-10,dir,0));
-//  sg->move(5,cnb->getY()-5-sg->getHeight());
-//  dh-=sg->getHeight();
-  ty+=sg->getHeight()+5;
-//  int dh=h-dy;
-  int dw=(strlen(oktext)+2)*aguix->getCharWidth();
-  Button *okb=(Button*)win->add(new Button(aguix,5,ty,dw,oktext,1,0,0));
-  dw=(strlen(canceltext)+2)*aguix->getCharWidth();
-  Button *cnb=(Button*)win->add(new Button(aguix,w-5-dw,ty,dw,canceltext,1,0,0));
-//  dh-=h-cnb->getY()+5;
-  ty+=okb->getHeight()+5;
-  h=ty;
+
+  sg = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100, dir, 0 ), 0, 1, cincw );
+
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cnb = (Button*)ac1_2->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   AGMessage *msg;
   verz=new Verzeichnis();
@@ -116,15 +131,6 @@ int FileRequester::request( const char *title,
           if(msg->button.button==okb) endmode=1;
           else if(msg->button.button==cnb) endmode=0;
           break;
-        case AG_SIZECHANGED:
-          okb->move(5,msg->size.newh-5-okb->getHeight());
-          dw=cnb->getWidth();
-          cnb->move(msg->size.neww-dw-5,msg->size.newh-5-okb->getHeight());
-          sg->move(5,cnb->getY()-5-sg->getHeight());
-          sg->resize(msg->size.neww-10,sg->getHeight());
-          dh=sg->getY()-10-aguix->getCharHeight();
-          lv->resize(msg->size.neww-10,dh);
-          break;
         case AG_STRINGGADGET_DEACTIVATE:
           if(msg->stringgadget.sg==sg) {
             setDir(sg->getText());
@@ -320,17 +326,25 @@ int FileRequester::request_entry( const char *title,
                                   const char *infotext,
                                   bool allowEnterName )
 {
-  int w, h, ty, tw;
   AWindow *win;
   AGMessage *msg;
   int endmode=-1;
   StringGadget *sg2;
-  Button *b[2];
-  Text *ttext;
   char *use_dir = NULL;
   int lastrow = -1, trow;
   Time lasttime=0;
   Requester *req;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
+  const int cmin = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW;
   
   if ( ( title == NULL ) ||
        ( oktext == NULL ) ||
@@ -354,47 +368,56 @@ int FileRequester::request_entry( const char *title,
     }
   } else use_dir = dupstring( actdir );
 
-  w = h = 10;
-  win = new AWindow( aguix, 10, 10, w, h, 0, title );
+  win = new AWindow( aguix, 10, 10, 300, 200, 0, title );
   win->create();
 
-  ty=5;
-  ttext = (Text*)win->add( new Text( aguix, 5, ty, infotext, 1 ) );
-  ty += ttext->getHeight() + 5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
 
-  tw = 40 * aguix->getCharWidth();
+  ac1->add( new Text( aguix, 0, 0, infotext, 1 ), 0, 0, cincwnr );
   
-  sg = (StringGadget*)win->add( new StringGadget( aguix, 5, ty, tw, use_dir, 0 ) );
-  ty += sg->getHeight();
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 1, 3 ), 0, 1 );
+  ac1_1->setMinSpace( 0 );
+  ac1_1->setMaxSpace( 0 );
+  ac1_1->setBorderWidth( 0 );
 
-  lv = (FieldListView*)win->add( new FieldListView( aguix, 5, ty, 200, 250, 0 ) );
+  sg = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100, use_dir, 0 ), 0, 0, cincw );
+
+  lv = (FieldListView*)ac1_1->add( new FieldListView( aguix, 0, 0, 200, 250, 0 ), 0, 1, cmin );
   lv->setHBarState( 2 );
   lv->setVBarState( 2 );
-  ty += lv->getHeight() + 5;
   
   if ( allowEnterName == true ) {
-    sg2 = (StringGadget*)win->add( new StringGadget( aguix, 5, ty, tw, "", 0 ) );
-    ty += sg2->getHeight() + 5;
-  } else sg2 = NULL;
+    sg2 = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 0, 2, cincw );
+  } else {
+    sg2 = NULL;
+    ac1_1->setMinHeight( 0, 0, 2 );
+    ac1_1->setMaxHeight( 0, 0, 2 );
+  }
   
-  win->maximizeX();
-  w = win->getWidth();
-  
-  b[0] = (Button*)win->add( new Button( aguix, 0, ty, oktext, 1, 0, 0 ) );
-  b[1] = (Button*)win->add( new Button( aguix, 0, ty, canceltext, 1, 0, 0 ) );
-  ty += b[0]->getHeight() + 5;
-  
-  tw = AGUIX::scaleElementsW( w, 5, 10, -1, false, false, (GUIElement**)b, NULL, 2 );
-  if ( tw > w ) w = tw;
-  sg->resize( w - 10, sg->getHeight() );
-  if ( sg2 != NULL ) sg2->resize( w - 10, sg->getHeight() );
-  lv->resize( w - 10, lv->getHeight() );
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_2->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
 
-  h = ty;
-  b[0]->takeFocus();
+  okb->takeFocus();
   win->setDoTabCycling( true );
-  win->resize( w, h );
-  win->setMinSize( w, h );
+  win->contMaximize( true );
   win->show();
   
   verz = new Verzeichnis();
@@ -411,24 +434,9 @@ int FileRequester::request_entry( const char *title,
           if ( msg->closewindow.window == win->getWindow() ) endmode = 0;
           break;
         case AG_BUTTONCLICKED:
-          if ( msg->button.button == b[0] ) {
+          if ( msg->button.button == okb ) {
             FR_RE_TESTOKAY;
-          } else if ( msg->button.button == b[1] ) endmode = 0;
-          break;
-        case AG_SIZECHANGED:
-          AGUIX::scaleElementsW( msg->size.neww, 5, 10, -1, false, false, (GUIElement**)b, NULL, 2 );
-          sg->resize( msg->size.neww - 10, sg->getHeight() );
-          if ( sg2 != NULL ) sg2->resize( msg->size.neww - 10, sg->getHeight() );
-          
-          b[0]->move( b[0]->getX(), msg->size.newh - 5 - b[0]->getHeight() );
-          b[1]->move( b[1]->getX(), msg->size.newh - 5 - b[1]->getHeight() );
-          if ( sg2 != NULL ) sg2->move( sg->getX(), b[0]->getY() - 5 - sg->getHeight() );
-          
-          if ( sg2 != NULL ) {
-            lv->resize( msg->size.neww - 10, sg2->getY() - lv->getY() - 5 );
-          } else {
-            lv->resize( msg->size.neww - 10, b[0]->getY() - 5 - lv->getY() - 5 );
-          }
+          } else if ( msg->button.button == cb ) endmode = 0;
           break;
         case AG_STRINGGADGET_DEACTIVATE:
           if ( msg->stringgadget.sg == sg ) {
@@ -504,7 +512,7 @@ int FileRequester::request_entry( const char *title,
             switch ( msg->key.key ) {
               case XK_KP_Enter:
               case XK_Return:
-                if ( b[1]->getHasFocus() == false ) {
+                if ( cb->getHasFocus() == false ) {
                   FR_RE_TESTOKAY;
                 }
                 break;
