@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: fontreq.h,v 1.8 2004/10/27 21:07:28 ralf Exp $ */
+/* $Id: fontreq.h,v 1.9 2005/08/17 06:29:45 ralf Exp $ */
 
 #ifndef FONTREQ_H
 #define FONTREQ_H
@@ -26,6 +26,7 @@
 #include "wdefines.h"
 #include <aguix/fieldlistview.h>
 #include <aguix/text.h>
+#include <aguix/acontainer.h>
 
 #define FONTREQ_MINSIZE 8
 #define FONTREQ_STEPSIZE 2
@@ -52,10 +53,11 @@ private:
 
   class AGUIX *aguix;
   FieldListView *lv,*lv2;
-  Text *ftext,*etext,*text1;
+  Text *ftext,*etext;
   Button *okb,*cb,*xb;
   AWindow *win;
   List *fontlist;
+  AContainer *ac1, *ac1_2;
   
   void showsizes(int i);
   void updatefont();
@@ -71,12 +73,34 @@ static const struct request_fonts_def {
 		            { "9x15", FontRequester::request_fonts::FIXED, "9x15", 9},
 		            { "10x20", FontRequester::request_fonts::FIXED, "10x20", 10},
 		            { "12x24", FontRequester::request_fonts::FIXED, "12x24", 12},
-		            { "fixed", FontRequester::request_fonts::SCALEABLE, "-misc-fixed-medium-r-*-*-%d-*-*-*-*-*-*-*", 0},
-		            { "fixed bold", FontRequester::request_fonts::SCALEABLE, "-misc-fixed-bold-*-*-*-%d-*-*-*-*-*-*-*", 0},
-                            { "courier", FontRequester::request_fonts::SCALEABLE, "-adobe-courier-medium-r-*-*-%d-*-*-*-*-*-*-*", 0},
-                            { "courier bold", FontRequester::request_fonts::SCALEABLE, "-adobe-courier-bold-r-*-*-%d-*-*-*-*-*-*-*", 0},
-                            { "courier italic", FontRequester::request_fonts::SCALEABLE, "-adobe-courier-medium-o-*-*-%d-*-*-*-*-*-*-*", 0},
-                            { "courier bold italic", FontRequester::request_fonts::SCALEABLE, "-adobe-courier-bold-o-*-*-%d-*-*-*-*-*-*-*", 0}
+		            { "fixed", FontRequester::request_fonts::SCALEABLE,
+			      "-misc-fixed-medium-r-*-*-%d-*-*-*-*-*-*-*", 0},
+		            { "fixed bold", FontRequester::request_fonts::SCALEABLE,
+			      "-misc-fixed-bold-*-*-*-%d-*-*-*-*-*-*-*", 0},
+                            { "courier", FontRequester::request_fonts::SCALEABLE,
+			      "-adobe-courier-medium-r-*-*-%d-*-*-*-*-*-*-*", 0},
+                            { "courier bold", FontRequester::request_fonts::SCALEABLE,
+			      "-adobe-courier-bold-r-*-*-%d-*-*-*-*-*-*-*", 0},
+                            { "courier italic", FontRequester::request_fonts::SCALEABLE,
+			      "-adobe-courier-medium-o-*-*-%d-*-*-*-*-*-*-*", 0},
+                            { "courier bold italic", FontRequester::request_fonts::SCALEABLE,
+			      "-adobe-courier-bold-o-*-*-%d-*-*-*-*-*-*-*", 0},
+			    { "times", FontRequester::request_fonts::SCALEABLE,
+			      "-adobe-times-medium-r-*-*-%d-*-*-*-*-*-*-*", 0},
+			    { "times bold", FontRequester::request_fonts::SCALEABLE,
+			      "-adobe-times-bold-r-*-*-%d-*-*-*-*-*-*-*", 0},
+			    { "times italic", FontRequester::request_fonts::SCALEABLE,
+			      "-adobe-times-medium-i-*-*-%d-*-*-*-*-*-*-*", 0},
+			    { "times bold italic", FontRequester::request_fonts::SCALEABLE,
+			      "-adobe-times-bold-i-*-*-%d-*-*-*-*-*-*-*", 0},
+			    { "helvetica", FontRequester::request_fonts::SCALEABLE,
+			      "-*-helvetica-medium-r-*-*-%d-*-*-*-*-*-*-*", 0},
+			    { "helvetica bold", FontRequester::request_fonts::SCALEABLE,
+			      "-*-helvetica-bold-r-*-*-%d-*-*-*-*-*-*-*", 0},
+			    { "helvetica italic", FontRequester::request_fonts::SCALEABLE,
+			      "-*-helvetica-medium-o-*-*-%d-*-*-*-*-*-*-*", 0},
+			    { "helvetica bold italic", FontRequester::request_fonts::SCALEABLE,
+			      "-*-helvetica-bold-o-*-*-%d-*-*-*-*-*-*-*", 0}
                           };
 
 #endif
