@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: functionproto.cc,v 1.15 2004/12/12 21:56:12 ralf Exp $ */
+/* $Id: functionproto.cc,v 1.16 2005/10/19 18:05:15 ralf Exp $ */
 
 #include "functionproto.h"
 #include "worker.h"
@@ -78,16 +78,9 @@ int FunctionProto::presave(Datei *fh,FunctionProto *fp)
   return 0;
 }
 
-int FunctionProto::run(ActionMessage *msg)
-{
-  am = msg;
-  return 0;
-}
-
 int FunctionProto::run( WPUContext *wpu, ActionMessage *msg )
 {
-  /* at default do nothing with wpu */
-  return run( msg );
+  return 0;
 }
 
 ActionMessage::ActionMessage( Worker *w)
