@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: functionproto.h,v 1.14 2004/12/12 21:55:20 ralf Exp $ */
+/* $Id: functionproto.h,v 1.15 2005/10/19 18:04:50 ralf Exp $ */
 
 #ifndef FUNCTIONPROTO_H
 #define FUNCTIONPROTO_H
@@ -74,7 +74,6 @@ public:
   virtual bool isName(const char *);
   virtual const char *getName();
   virtual bool save(Datei *);
-  virtual int run(ActionMessage*);
   virtual int run( WPUContext *, ActionMessage * );
   virtual const char *getDescription();
   
@@ -82,7 +81,6 @@ public:
   int configureWhenAvail();
 protected:
   static const char *name;
-  ActionMessage *am;
   bool hasConfigure;
 };
 
