@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: goftpop.cc,v 1.3 2005/05/15 15:55:08 ralf Exp $ */
+/* $Id: goftpop.cc,v 1.4 2005/10/19 18:04:46 ralf Exp $ */
 
 #include "goftpop.h"
 #include "listermode.h"
@@ -70,7 +70,7 @@ GoFTPOp::getName()
 }
 
 int
-GoFTPOp::run(ActionMessage *msg)
+GoFTPOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   Requester *req = Worker::getRequester();
   std::string str1;
