@@ -1,7 +1,7 @@
 /* grouphash.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
  * Copyright (C) 2001-2004 Ralf Hoffmann.
- * You can contact me at: ralf.hoffmann@epost.de
+ * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: grouphash.h,v 1.7 2004/03/18 20:17:15 ralf Exp $ */
+/* $Id: grouphash.h,v 1.9 2004/10/27 21:07:37 ralf Exp $ */
 
 #ifndef GROUPHASH_H
 #define GROUPHASH_H
@@ -44,10 +44,14 @@ public:
   char *getGroupNameS(gid_t);
   char *getGroupName(gid_t);
   void getGroupName(gid_t,char*,int);
+  bool isInGroup( gid_t );
 protected:
   int hash(int);
+  void initUsersGroups();
+  void freeUsersGroups();
   struct scl **users;
   struct scl **groups;
+  struct scl **usersgroups;
   int size;
 };
 
