@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: informationmode.cc,v 1.35 2005/06/27 17:48:36 ralf Exp $ */
+/* $Id: informationmode.cc,v 1.36 2005/10/17 20:15:57 ralf Exp $ */
 
 #include "informationmode.h"
 #include "normalmode.h"
@@ -229,8 +229,10 @@ void InformationMode::update(bool force)
     } else {
       if ( ol->isActive() == true ) {
         // only clear LV when other side is active and has no active fe
-	clearLastActiveFE();
-        showinfos();
+	if ( lastactivefe != NULL ) {
+	  clearLastActiveFE();
+	  showinfos();
+	}
       }
     }
     
