@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: intviewop.cc,v 1.1 2005/05/19 19:47:37 ralf Exp $ */
+/* $Id: intviewop.cc,v 1.3 2005/10/19 18:04:08 ralf Exp $ */
 
 #include "intviewop.h"
 #include "listermode.h"
@@ -91,7 +91,7 @@ InternalViewOp::run( WPUContext *wpu, ActionMessage *msg )
       if ( l1 != NULL )
 	lm1 = l1->getActiveMode();
     } else {
-      lm1 = am->dndmsg->getSourceMode();
+      lm1 = msg->dndmsg->getSourceMode();
     }
     
     if ( ( lm1 != NULL ) && ( lm1->isType( "NormalMode" ) == true ) )
@@ -100,9 +100,9 @@ InternalViewOp::run( WPUContext *wpu, ActionMessage *msg )
     if ( msg->mode == msg->AM_MODE_ONLYACTIVE )
       _tmode = SHOW_ACTIVE_FILE;
     else if ( msg->mode == msg->AM_MODE_DNDACTION ) {
-      filelist.push_back( am->dndmsg->getFE()->fullname );
+      filelist.push_back( msg->dndmsg->getFE()->fullname );
     } else if ( msg->mode == msg->AM_MODE_SPECIAL ) {
-      filelist.push_back( am->getFE()->fullname );
+      filelist.push_back( msg->getFE()->fullname );
     }
 
     if ( filelist.size() < 1 ) {
@@ -402,7 +402,10 @@ void InternalViewOp::view( std::list<std::string> &filelist ) const
   Text *fnt = (Text*)ac1_1->add( new Text( aguix, 0, 0, "", 1 ), 1, 0, cincwnr );
 
   it1 = filelist.begin();
-  buildTextView( *it1, &ts, &tv, ac1, fnt );
+  
+  AFontWidth lencalc( aguix, NULL );
+
+  buildTextView( *it1, &ts, &tv, ac1, fnt, lencalc );
   ac1->readLimits();
   ac1_1->readLimits();
 
@@ -504,7 +507,8 @@ void InternalViewOp::buildTextView( std::string &filename,
 				    TextStorageFile **ts,
 				    TextView **tv,
 				    AContainer *ac1,
-				    class Text *fnt ) const
+				    class Text *fnt,
+				    AWidth &lencalc ) const
 {
   AGUIX *aguix = Worker::getAGUIX();
   const int cmin = AContainer::ACONT_MINH +
@@ -513,7 +517,7 @@ void InternalViewOp::buildTextView( std::string &filename,
   if ( ts == NULL || tv == NULL || ac1 == NULL ) return;
   
   delete *tv;
-  *ts = new TextStorageFile( filename );
+  *ts = new TextStorageFile( filename, lencalc );
   *tv = new TextView( aguix, 0, 0, 100, 100, 0, "", **ts );
   (*tv)->setDisplayFocus( true );
   ac1->add( *tv, 0, 1, cmin );
