@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: lister.cc,v 1.29 2005/05/15 15:55:39 ralf Exp $ */
+/* $Id: lister.cc,v 1.31 2005/10/17 19:07:45 ralf Exp $ */
 
 #include "lister.h"
 #include "worker.h"
@@ -209,71 +209,70 @@ bool Lister::isActive()
 
 void Lister::configure()
 {
-  int w2,h2,tw,ty,tx;
-  int t1,t2;
   int nr,j,i;
   const char *cstr;
   ChooseButton **cbs;
   Button **bs;
   AWindow *win2 = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 16 ) );
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
+  const int cfixnr = cfix +
+                     AContainer::ACONT_NORESIZE;
+
   win2->create();
-  w2=0;
-  h2=0;
-  ty=5;
-  Text *tt1=(Text*)win2->add(new Text(aguix,5,ty,catalog.getLocale(166),1));
-  tw=tt1->getWidth()+10;
-  if(tw>w2) w2=tw;
-  ty+=tt1->getHeight()+5;
+
+  AContainer *ac1 = win2->setContainer( new AContainer( win2, 1, 3 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 166 ), 1 ), 0, 0, cincwnr );
+
+  nr = parent->getMaxModeNr();
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win2, 2, nr ), 0, 1 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
 
-  nr=parent->getMaxModeNr();
   cbs=(ChooseButton**)_allocsafe(sizeof(ChooseButton*)*nr);
   bs=(Button**)_allocsafe(sizeof(Button*)*nr);
   for(i=0;i<nr;i++) {
-    cbs[i]=new ChooseButton(aguix,5,ty,((modes[i]==activemode)?1:0),"",LABEL_RIGHT,0,0);
-    win2->add(cbs[i]);
-    tx=cbs[i]->getX()+cbs[i]->getWidth()+5;
+    cbs[i] = new ChooseButton( aguix, 0, 0, ( ( modes[i] == activemode ) ? 1 : 0 ), "", LABEL_RIGHT, 0, 0 );
+    ac1_1->add( cbs[i], 0, i, cfixnr );
     cstr = modes[i]->getLocaleName();
-    bs[i]=new Button(aguix,tx,ty,cstr,1,0,0);
-    win2->add(bs[i]);
-    
-    if ( cbs[i]->getHeight() > bs[i]->getHeight() ) {
-      AGUIX::centerElementsY( bs[i], cbs[i] );
-    } else {
-      AGUIX::centerElementsY( cbs[i], bs[i] );
-    }
-
-    tw=bs[i]->getX()+bs[i]->getWidth()+10;
-    if(tw>w2) w2=tw;
-    ty+=a_max(cbs[i]->getHeight(),bs[i]->getHeight())+5;
+    bs[i] = new Button( aguix, 0, 0, cstr, 1, 0, 0 );
+    ac1_1->add( bs[i], 1, i, cincw );
   }
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w2) w2=tw;
-  Button *okb=(Button*)win2->add(new Button(aguix,
-                                             5,
-                                             ty,
-                                             t1,
-                                             catalog.getLocale(11),
-                                             1,
-                                             0,
-                                             0));
-  Button *cancelb=(Button*)win2->add(new Button(aguix,
-                                                 w2-5-t2,
-                                                 ty,
-                                                 t2,
-                                                 catalog.getLocale(8),
-                                                 1,
-                                                 0,
-                                                 0));
-  h2=okb->getY()+okb->getHeight()+5;
+
+  AContainer *ac1_2 = ac1->add( new AContainer( win2, 2, 1 ), 0, 2 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cancelb = (Button*)ac1_2->add( new Button( aguix,
+						     0,
+						     0,
+						     catalog.getLocale( 8 ),
+						     1,
+						     0,
+						     0 ), 1, 0, cfix );
+
   okb->takeFocus();
   win2->setDoTabCycling( true );
-  win2->resize(w2,h2);
-  win2->setMinSize(w2,h2);
-  win2->setMaxSize(w2,h2);
+  win2->contMaximize( true );
   win2->show();
   AGMessage *msg;
   while((msg=aguix->GetMessage(NULL))!=NULL) aguix->ReplyMessage(msg);
