@@ -1,6 +1,6 @@
 /* listermode.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: listermode.h,v 1.12 2004/10/27 21:07:54 ralf Exp $ */
+/* $Id: listermode.h,v 1.13 2005/05/15 15:56:02 ralf Exp $ */
 
 #ifndef LISTERMODE_H
 #define LISTERMODE_H
@@ -59,7 +59,7 @@ public:
   static int presave(Datei*,ListerMode*);*/
   
   virtual bool startdnd(DNDMsg *dm);
-  virtual bool isyours(GUIElement *elem);
+  virtual bool isyours( Widget *elem );
   virtual void lvbDoubleClicked();
 protected:
   Lister *parentlister;
