@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: makedirop.cc,v 1.8 2004/10/27 21:07:56 ralf Exp $ */
+/* $Id: makedirop.cc,v 1.9 2005/10/19 18:04:03 ralf Exp $ */
 
 #include "makedirop.h"
 #include "listermode.h"
@@ -55,10 +55,9 @@ MakeDirOp::getName()
 }
 
 int
-MakeDirOp::run(ActionMessage *msg)
+MakeDirOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
