@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: normalmode.h,v 1.106 2005/07/12 19:11:30 ralf Exp $ */
+/* $Id: normalmode.h,v 1.111 2005/11/28 22:03:45 ralf Exp $ */
 
 #ifndef NORMALMODE_H
 #define NORMALMODE_H
@@ -36,6 +36,7 @@
 #include "copyop.h"
 #include "deleteop.h"
 #include "condparser.h"
+#include <map>
 
 #ifdef WANT_THREADS
 #include <aguix/mutex.h>
@@ -330,8 +331,7 @@ public:
   void renamef(struct NM_renameorder *renorder);
   void dirsize(struct NM_dirsizeorder *dsorder);
   void simdd();
-  void searchentry();
-  void searchentry( bool ignore_case );
+  void searchentry( bool ignore_case, bool reverse_search = false );
   void enterpath();
   void scrolllister(int dir);
   void createsymlink(struct NM_createsymlinkorder *cslorder);
@@ -523,9 +523,28 @@ protected:
   char *StringRequest(char *sstr,class NM_externorder *extorder,int maxlen, NMExtList *entries[2]);
   void startsearchmode();
   void finishsearchmode();
+
+  /**
+   * jumps to the first matching entry starting from the active
+   */
   bool showfirstentry(const char *str);
-  bool shownextentry();
-  bool shownextentry( const char *str, int pos );
+
+  /**
+   * jumps to the next entry matching the last search string
+   */
+  bool shownextentry( bool reverse_search = false );
+
+  /**
+   * jumps to the next entry matching the given string or the last search
+   * string (if tstr == NULL )
+   */
+  bool shownextentry( const char *tstr, bool reverse_search = false );
+
+  /**
+   * jumps to the next entry matching the given string starting at given
+   * position
+   */
+  bool shownextentry( const char *str, int pos, bool reverse_search = false );
 
   typedef struct changemod_info{
     changemod_info();
@@ -560,6 +579,7 @@ protected:
   void setShowFreeSpace(bool v);
   void setUpdatetime(int nv);
   void setSSHAllow( enum ssh_allow_t nv );
+  void setQuicksearchEnabled( bool nv );
   
   static int maxfilestrlen,maxdirstrlen,maxbytesstrlen,maxwbytesstrlen,maxnochanges;
   
@@ -784,6 +804,12 @@ protected:
 			       CopyOpWin *cowin,
 			       loff_t bytesToCopy );
   bool checkForEmptyActionList( WCFiletype *ft );
+  std::map<std::string,int> _field_map;
+  std::map<std::string,int> _loaded_field_width;
+  int getAndEraseLoadedFieldWidth( std::string str1 );
+  int writeFieldWidthsToLoadMap();
+
+  bool quicksearch_enabled;
 };
 
 class NMFieldListViewDND:public FieldListViewDND
