@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: normalops.cc,v 1.22 2005/05/15 15:57:05 ralf Exp $ */
+/* $Id: normalops.cc,v 1.24 2005/10/19 18:03:49 ralf Exp $ */
 
 #include "normalops.h"
 #include "listermode.h"
@@ -58,7 +58,7 @@ ChangeListerSetOp *ChangeListerSetOp::duplicate() const
   return ta;
 }
 
-int ChangeListerSetOp::run(ActionMessage *msg)
+int ChangeListerSetOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   Lister *l1;
   switch(mode) {
@@ -86,32 +86,42 @@ const char *ChangeListerSetOp::getDescription()
 int ChangeListerSetOp::configure()
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   AWindow *win;
   CycleButton *rcyb;
-  Text *ttext;
-  int tw,w,h,x,y,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   char *tstr;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
   
-  w=h=10;
-  x=y=5;
-
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(19))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(19));
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(348),1));
-  x+=ttext->getWidth()+5;
-  rcyb=(CycleButton*)win->add(new CycleButton(aguix,x,y,100,1,0,0));
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 0 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 348 ), 1 ), 0, 0, cfix );
+  rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
   rcyb->addOption(catalog.getLocale(326));
   rcyb->addOption(catalog.getLocale(327));
   rcyb->addOption(catalog.getLocale(324));
   rcyb->addOption(catalog.getLocale(325));
   rcyb->resize(rcyb->getMaxSize(),rcyb->getHeight());
+  ac1_1->readLimits();
 
   switch(mode) {
     case CLS_RIGHT_LISTER:
@@ -128,40 +138,27 @@ int ChangeListerSetOp::configure()
       break;
   }
   
-  y+=rcyb->getHeight()+5;
-  tw=x+rcyb->getWidth()+5;
-  if(tw>w) w=tw;
-  x=5;
-
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  w-5-t2,
-                                  y,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_2->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
   
-  h=y;
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMaxSize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
@@ -273,7 +270,7 @@ SwitchListerOp *SwitchListerOp::duplicate() const
   return ta;
 }
 
-int SwitchListerOp::run(ActionMessage *msg)
+int SwitchListerOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   Lister *l1;
   l1 = msg->getWorker()->getOtherLister( msg->getWorker()->getActiveLister() );
@@ -343,12 +340,11 @@ FilterSelectOp *FilterSelectOp::duplicate() const
   return ta;
 }
 
-int FilterSelectOp::run(ActionMessage *msg)
+int FilterSelectOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   Lister *l1;
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -374,61 +370,59 @@ const char *FilterSelectOp::getDescription()
 
 int FilterSelectOp::configure()
 {
-  int w,h,tw,ty,tx;
-  int t1,t2;
   StringGadget *sg;
   AGUIX *aguix = Worker::getAGUIX();
   AWindow *win;
   char *tstr;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
 
-  w=h=10;
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(21))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(21));
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
   
-  ty=5;
-  tx=5;
-  Text *tt1=(Text*)win->add(new Text(aguix,tx,ty,catalog.getLocale(349),1));
-  tw=tt1->getWidth();
-  tx+=tw+5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
 
-  sg=(StringGadget*)win->add(new StringGadget(aguix,tx,ty,100,
-                                              filter,
-                                              0));
-  tw=tx+sg->getWidth()+5;
-  if(tw>w) w=tw;
-  ty+=sg->getHeight()+5;
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 0 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 349 ), 1 ), 0, 0, cfix );
+  sg = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100,
+						    filter,
+						    0 ), 1, 0, cincw );
   
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  Button *okb=(Button*)win->add(new Button(aguix,
-                                             5,
-                                             ty,
-                                             t1,
-                                             catalog.getLocale(11),
-                                             1,
-                                             0,
-                                             0));
-  Button *cancelb=(Button*)win->add(new Button(aguix,
-                                                 w-5-t2,
-                                                 ty,
-                                                 t2,
-                                                 catalog.getLocale(8),
-                                                 1,
-                                                 0,
-                                                 0));
-  h=okb->getY()+okb->getHeight()+5;
-  sg->resize(w-10-tt1->getWidth()-5,sg->getHeight());
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cancelb = (Button*)ac1_2->add( new Button( aguix,
+						     0,
+						     0,
+						     catalog.getLocale( 8 ),
+						     1,
+						     0,
+						     0 ), 1, 0, cfix );
+
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMinSize(w,h);
-  win->setMaxSize(w,h);
+  win->contMaximize( true );
   win->show();
   AGMessage *msg;
   while((msg=aguix->GetMessage(NULL))!=NULL) aguix->ReplyMessage(msg);
@@ -466,8 +460,7 @@ bool FilterSelectOp::requestfilter()
                                                // programmer calls closeHistory
                                                // but to be sure...
 
-  int w,h,tw,ty;
-  int t1,t2;
+  int w, h;
   StringGadget *sg;
   FieldListView *lv;
   AGUIX *aguix = Worker::getAGUIX();
@@ -476,23 +469,34 @@ bool FilterSelectOp::requestfilter()
   char *tstr;
   bool lvstill;
   int lastrow;
-  GUIElement *bs[2];
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
+  const int cmin = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW;
 
-  w = h = 10;
-  win = new AWindow( aguix, 10, 10, w, h, 0, catalog.getLocale( 268 ) );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 268 ) );
   win->create();
-  ty=5;
-  Text *tt1=(Text*)win->add(new Text(aguix,5,ty,catalog.getLocale(270),1));
-  tw=tt1->getWidth()+10;
-  if(tw>w) w=tw;
-  ty+=tt1->getHeight()+5;
-  tt1=(Text*)win->add(new Text(aguix,10,ty,catalog.getLocale(272),1));
-  tw=tt1->getWidth()+10;
-  if(tw>w) w=tw;
-  ty+=tt1->getHeight()+5;
 
-  lv = (FieldListView*)win->add( new FieldListView( aguix, 5, ty, a_max( w - 10, 10 * aguix->getCharWidth() ),
-                                                    7 * aguix->getCharHeight(), 0 ) );
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 270 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 272 ), 1 ), 0, 1, cincwnr );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 1, 2 ), 0, 2 );
+  ac1_1->setMinSpace( 0 );
+  ac1_1->setMaxSpace( 0 );
+  ac1_1->setBorderWidth( 0 );
+
+  lv = (FieldListView*)ac1_1->add( new FieldListView( aguix, 0, 0, 100, 7 * aguix->getCharHeight(), 0 ), 0, 0, cmin );
 
   lv->setHBarState( 2 );
   lv->setVBarState( 2 );
@@ -511,55 +515,32 @@ bool FilterSelectOp::requestfilter()
   lv->showRow( filter_history->size() - 1 );
   lv->redraw();
 
-  tw = lv->getWidth() + 10;
-  if ( tw > w ) w = tw;
-  ty += lv->getHeight();
-
-  sg=(StringGadget*)win->add(new StringGadget(aguix,5,ty,w-10,
-                                              strlen(actual_filter)>0?actual_filter:filter,
-                                              0));
-  tw=sg->getWidth()+10;
-  if(tw>w) w=tw;
-  ty+=sg->getHeight()+5;
+  sg=(StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100,
+						  strlen(actual_filter)>0?actual_filter:filter,
+						  0 ), 0, 1, cincw );
   
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  Button *okb=(Button*)win->add(new Button(aguix,
-                                             5,
-                                             ty,
-                                             t1,
-                                             catalog.getLocale(11),
-                                             1,
-                                             0,
-                                             0));
-  Button *cancelb=(Button*)win->add(new Button(aguix,
-                                                 w-5-t2,
-                                                 ty,
-                                                 t2,
-                                                 catalog.getLocale(8),
-                                                 1,
-                                                 0,
-                                                 0));
-  bs[0] = okb;
-  bs[1] = cancelb;
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cancelb = (Button*)ac1_2->add( new Button( aguix,
+						     0,
+						     0,
+						     catalog.getLocale( 8 ),
+						     1,
+						     0,
+						     0 ), 1, 0, cfix );
+  win->contMaximize( true );
+  w = ( lastw > 0 ) ? lastw : win->getWidth();
+  h = ( lasth > 0 ) ? lasth : win->getHeight();
 
-  h = okb->getY() + okb->getHeight() + 5;
-  win->setMinSize( w, h );
-  
-  w = ( lastw > 0 ) ? lastw : w;
-  h = ( lasth > 0 ) ? lasth : h;
-
-  AGUIX::scaleElementsW( w, 5, 5, -1, false, false, bs, NULL, 2 );
-  okb->move( okb->getX(), h - 5 - okb->getHeight() );
-  cancelb->move( cancelb->getX(), h - 5 - cancelb->getHeight() );
-  sg->resize( w - 10, sg->getHeight() );
-  sg->move( sg->getX(), okb->getY() - 5 - sg->getHeight() );
-  lv->resize( sg->getWidth(), sg->getY() - lv->getY() );
-  
   win->setDoTabCycling( true );
   win->resize(w,h);
   win->show();
@@ -626,15 +607,6 @@ bool FilterSelectOp::requestfilter()
             sg->setText( tstr );
           }
         }
-      } else if ( msg->type == AG_SIZECHANGED ) {
-        if ( msg->size.window == win->getWindow() ) {
-          AGUIX::scaleElementsW( msg->size.neww, 5, 5, -1, false, false, bs, NULL, 2 );
-          okb->move( okb->getX(), msg->size.newh - 5 - okb->getHeight() );
-          cancelb->move( cancelb->getX(), msg->size.newh - 5 - cancelb->getHeight() );
-          sg->resize( msg->size.neww - 10, sg->getHeight() );
-          sg->move( sg->getX(), okb->getY() - 5 - sg->getHeight() );
-          lv->resize( sg->getWidth(), sg->getY() - lv->getY() );
-        }
       }
       aguix->ReplyMessage(msg);
     }
@@ -781,12 +753,11 @@ FilterUnSelectOp *FilterUnSelectOp::duplicate() const
   return ta;
 }
 
-int FilterUnSelectOp::run(ActionMessage *msg)
+int FilterUnSelectOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   Lister *l1;
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -812,61 +783,60 @@ const char *FilterUnSelectOp::getDescription()
 
 int FilterUnSelectOp::configure()
 {
-  int w,h,tw,ty,tx;
-  int t1,t2;
   StringGadget *sg;
   AGUIX *aguix = Worker::getAGUIX();
   AWindow *win;
   char *tstr;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
 
-  w=h=10;
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(22))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(22));
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
   
-  ty=5;
-  tx=5;
-  Text *tt1=(Text*)win->add(new Text(aguix,tx,ty,catalog.getLocale(349),1));
-  tw=tt1->getWidth();
-  tx+=tw+5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
 
-  sg=(StringGadget*)win->add(new StringGadget(aguix,tx,ty,100,
-                                              filter,
-                                              0));
-  tw=tx+sg->getWidth()+5;
-  if(tw>w) w=tw;
-  ty+=sg->getHeight()+5;
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 0 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 349 ), 1 ), 0, 0, cfix );
+
+  sg = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100,
+						    filter,
+						    0 ), 1, 0, cincw );
   
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  Button *okb=(Button*)win->add(new Button(aguix,
-                                             5,
-                                             ty,
-                                             t1,
-                                             catalog.getLocale(11),
-                                             1,
-                                             0,
-                                             0));
-  Button *cancelb=(Button*)win->add(new Button(aguix,
-                                                 w-5-t2,
-                                                 ty,
-                                                 t2,
-                                                 catalog.getLocale(8),
-                                                 1,
-                                                 0,
-                                                 0));
-  h=okb->getY()+okb->getHeight()+5;
-  sg->resize(w-10-tt1->getWidth()-5,sg->getHeight());
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cancelb = (Button*)ac1_2->add( new Button( aguix,
+						     0,
+						     0,
+						     catalog.getLocale( 8 ),
+						     1,
+						     0,
+						     0 ), 1, 0, cfix );
+
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMinSize(w,h);
-  win->setMaxSize(w,h);
+  win->contMaximize( true );
   win->show();
   AGMessage *msg;
   while((msg=aguix->GetMessage(NULL))!=NULL) aguix->ReplyMessage(msg);
@@ -897,8 +867,6 @@ bool FilterUnSelectOp::requestfilter()
                                                // programmer calls closeHistory
                                                // but to be sure...
 
-  int w,h,tw,ty;
-  int t1,t2;
   StringGadget *sg;
   FieldListView *lv;
   AGUIX *aguix = Worker::getAGUIX();
@@ -907,23 +875,35 @@ bool FilterUnSelectOp::requestfilter()
   char *tstr;
   bool lvstill;
   int lastrow;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
+  const int cmin = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW;
 
   win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 269 ) );
   win->create();
-  w=0;
-  h=0;
-  ty=5;
-  Text *tt1=(Text*)win->add(new Text(aguix,5,ty,catalog.getLocale(271),1));
-  tw=tt1->getWidth()+10;
-  if(tw>w) w=tw;
-  ty+=tt1->getHeight()+5;
-  tt1=(Text*)win->add(new Text(aguix,10,ty,catalog.getLocale(272),1));
-  tw=tt1->getWidth()+10;
-  if(tw>w) w=tw;
-  ty+=tt1->getHeight()+5;
 
-  lv = (FieldListView*)win->add( new FieldListView( aguix, 5, ty, a_max( w - 10, 10 * aguix->getCharWidth() ),
-                                                    7 * aguix->getCharHeight(), 0 ) );
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 271 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 272 ), 1 ), 0, 1, cincwnr );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ac1_1->setMinSpace( 0 );
+  ac1_1->setMaxSpace( 0 );
+  ac1_1->setBorderWidth( 0 );
+
+  lv = (FieldListView*)ac1_1->add( new FieldListView( aguix, 0, 0, 100,
+						      7 * aguix->getCharHeight(), 0 ), 0, 0, cmin );
 
   lv->setHBarState( 2 );
   lv->setVBarState( 2 );
@@ -942,46 +922,31 @@ bool FilterUnSelectOp::requestfilter()
   lv->showRow( filter_history->size() - 1 );
   lv->redraw();
 
-  tw = lv->getWidth() + 10;
-  if ( tw > w ) w = tw;
-  ty += lv->getHeight();
-
-  sg=(StringGadget*)win->add(new StringGadget(aguix,5,ty,tw-10,
-                                              strlen(actual_filter)>0?actual_filter:filter,
-                                              0));
-  tw=sg->getWidth()+10;
-  if(tw>w) w=tw;
-  ty+=sg->getHeight()+5;
+  sg = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100,
+						    strlen(actual_filter)>0?actual_filter:filter,
+						    0 ), 0, 1, cincw );
   
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  Button *okb=(Button*)win->add(new Button(aguix,
-                                             5,
-                                             ty,
-                                             t1,
-                                             catalog.getLocale(11),
-                                             1,
-                                             0,
-                                             0));
-  Button *cancelb=(Button*)win->add(new Button(aguix,
-                                                 w-5-t2,
-                                                 ty,
-                                                 t2,
-                                                 catalog.getLocale(8),
-                                                 1,
-                                                 0,
-                                                 0));
-  h=okb->getY()+okb->getHeight()+5;
-  sg->resize(w-10,sg->getHeight());
-  lv->resize( w - 10, lv->getHeight() );
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cancelb = (Button*)ac1_2->add( new Button( aguix,
+						     0,
+						     0,
+						     catalog.getLocale( 8 ),
+						     1,
+						     0,
+						     0 ), 1, 0, cfix );
+
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMinSize(w,h);
-  win->setMaxSize(w,h);
+  win->contMaximize( true );
   win->show();
   AGMessage *msg;
   while((msg=aguix->GetMessage(NULL))!=NULL) aguix->ReplyMessage(msg);
@@ -1093,13 +1058,12 @@ Path2OSideOp *Path2OSideOp::duplicate() const
   return ta;
 }
 
-int Path2OSideOp::run(ActionMessage *msg)
+int Path2OSideOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   Lister *l1;
   ListerMode *lm1;
   NormalMode *nm1;
   char *dir=NULL;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -1170,7 +1134,7 @@ QuitOp *QuitOp::duplicate() const
   return ta;
 }
 
-int QuitOp::run(ActionMessage *msg)
+int QuitOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   msg->getWorker()->quit( mode == Q_QUICK_QUIT ? 1 : 0 );
   return 0;
@@ -1184,30 +1148,40 @@ const char *QuitOp::getDescription()
 int QuitOp::configure()
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   AWindow *win;
   CycleButton *rcyb;
-  Text *ttext;
-  int tw,w,h,x,y,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   char *tstr;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
   
-  w=h=10;
-  x=y=5;
-
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(24))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(24));
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(350),1));
-  x+=ttext->getWidth()+5;
-  rcyb=(CycleButton*)win->add(new CycleButton(aguix,x,y,100,1,0,0));
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 0 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 350 ), 1 ), 0, 0, cfix );
+  rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
   rcyb->addOption(catalog.getLocale(351));
   rcyb->addOption(catalog.getLocale(352));
   rcyb->resize(rcyb->getMaxSize(),rcyb->getHeight());
+  ac1_1->readLimits();
 
   switch(mode) {
     case Q_QUICK_QUIT:
@@ -1218,40 +1192,27 @@ int QuitOp::configure()
       break;
   }
   
-  y+=rcyb->getHeight()+5;
-  tw=x+rcyb->getWidth()+5;
-  if(tw>w) w=tw;
-  x=5;
-
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  w-5-t2,
-                                  y,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_2->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
   
-  h=y;
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMaxSize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
