@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: ownop.cc,v 1.35 2005/05/19 19:53:01 ralf Exp $ */
+/* $Id: ownop.cc,v 1.37 2005/10/19 18:03:30 ralf Exp $ */
 
 #include "ownop.h"
 #include "listermode.h"
@@ -85,7 +85,6 @@ int
 OwnOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   use_wpu = wpu;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
@@ -95,9 +94,9 @@ OwnOp::run( WPUContext *wpu, ActionMessage *msg )
       lm1=startlister->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmodeown();
+          normalmodeown( msg );
     }
-  } else normalmodeown();
+  } else normalmodeown( msg );
   return 0;
 }
 
@@ -138,7 +137,7 @@ OwnOp::getDescription()
 }
 
 int
-OwnOp::normalmodeown()
+OwnOp::normalmodeown( ActionMessage *am )
 {
   class NM_externorder extorder;
   NormalMode *nm1=NULL,
@@ -229,13 +228,11 @@ int
 OwnOp::configure()
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb,*fb, *comreqb, *comreqb2;
+  Button *fb, *comreqb, *comreqb2;
   StringGadget *sg[2];
   AWindow *win;
   ChooseButton *scb,*rcb, *ibcb, *tdcb, *dcdcb;
   CycleButton *cyb;
-  Text *ttext;
-  int tw,w,h,x,y,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   Requester *req;
@@ -244,62 +241,63 @@ OwnOp::configure()
   char *buttonstr,*tstr;
   int erg;
   std::string str1;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
   
   req=new Requester(aguix);
   freq = new FileRequester( aguix );
-  w=h=10;
-  x=y=5;
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(28))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(28));
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
-  scb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,(separate_each_entry==true)?1:0,
-                                               catalog.getLocale(329),LABEL_RIGHT,1,0));
-  y+=scb->getHeight()+5;
-  tw=scb->getWidth()+10;
-  if(tw>w) w=tw;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 9 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
 
-  rcb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,(recursive==true)?1:0,
-                                               catalog.getLocale(330),LABEL_RIGHT,1,0));
-  y+=rcb->getHeight()+5;
-  tw=rcb->getWidth()+10;
-  if(tw>w) w=tw;
+  scb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( separate_each_entry == true ) ? 1 : 0,
+						   catalog.getLocale( 329 ), LABEL_RIGHT, 1, 0 ), 0, 0, cincwnr );
 
-  tdcb = (ChooseButton*)win->add( new ChooseButton( aguix, x, y, ( take_dirs == true ) ? 1 : 0,
-                                                    catalog.getLocale( 513 ), LABEL_RIGHT, 1, 0 ) );
-  y += tdcb->getHeight() + 5;
-  tw = tdcb->getWidth() + 10;
-  if ( tw > w ) w = tw;
+  rcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( recursive == true ) ? 1 : 0,
+						   catalog.getLocale( 330 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
 
-  dcdcb = (ChooseButton*)win->add( new ChooseButton( aguix, x, y, ( dontcd == true ) ? 1 : 0,
-						     catalog.getLocale( 617 ), LABEL_RIGHT, 1, 0 ) );
-  y += dcdcb->getHeight() + 5;
-  tw = dcdcb->getWidth() + 10;
-  if ( tw > w ) w = tw;
+  tdcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( take_dirs == true ) ? 1 : 0,
+                                                    catalog.getLocale( 513 ), LABEL_RIGHT, 1, 0 ), 0, 2, cincwnr );
 
-  ibcb = (ChooseButton*)win->add( new ChooseButton( aguix,
-                                                    x,
-                                                    y,
+  dcdcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( dontcd == true ) ? 1 : 0,
+						     catalog.getLocale( 617 ), LABEL_RIGHT, 1, 0 ), 0, 3, cincwnr );
+
+  ibcb = (ChooseButton*)ac1->add( new ChooseButton( aguix,
+                                                    0,
+                                                    0,
                                                     ( inbackground == true ) ? 1 : 0,
                                                     catalog.getLocale( 435 ),
                                                     LABEL_RIGHT,
                                                     1,
-                                                    0 ) );
-  y+=ibcb->getHeight()+5;
-  tw=ibcb->getWidth()+10;
-  if(tw>w) w=tw;
+                                                    0 ), 0, 4, cincwnr );
 
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(331),1));
-  x+=ttext->getWidth()+5;
-  cyb=(CycleButton*)win->add(new CycleButton(aguix,x,y,100,1,0,0));
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 5 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 331 ), 1 ), 0, 0, cfix );
+  cyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
   cyb->addOption(catalog.getLocale(332));
   cyb->addOption(catalog.getLocale(333));
   cyb->addOption(catalog.getLocale(334));
   cyb->addOption(catalog.getLocale(335));
   cyb->resize(cyb->getMaxSize(),cyb->getHeight());
+  ac1_1->readLimits();
   switch(ownstart) {
     case OWNOP_START_IN_TERMINAL:
       cyb->setOption(1);
@@ -315,76 +313,53 @@ OwnOp::configure()
       break;
   }
   
-  y+=cyb->getHeight()+5;
-  tw=x+cyb->getWidth()+5;
-  if(tw>w) w=tw;
-  x=5;
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 5, 1 ), 0, 6 );
+  ac1_2->setMinSpace( 0 );
+  ac1_2->setMaxSpace( 0 );
+  ac1_2->setBorderWidth( 0 );
 
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(336),1));
-  x+=ttext->getWidth()+5;
-  comreqb = (Button*)win->add( new Button( aguix, x, y, catalog.getLocale( 458 ), 1, 0, 0 ) );
-  x += comreqb->getWidth();
+  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 336 ), 1 ), 0, 0, cfix );
+  ac1_2->setMinWidth( 5, 1, 0 );
+  ac1_2->setMaxWidth( 5, 1, 0 );
 
-  tw=w-x-5;
-  if ( tw < ( 20 * aguix->getCharWidth() ) ) tw = 20 * aguix->getCharWidth();
-  sg[0]=(StringGadget*)win->add(new StringGadget(aguix,x,y,tw,com_str,0));
-  
-  fb=(Button*)win->add(new Button(aguix,x+sg[0]->getWidth(),y,sg[0]->getHeight(),
-                                  sg[0]->getHeight(),"O",1,0,0));
-  comreqb->resize( comreqb->getWidth(), sg[0]->getHeight() );
-  
-  y+=sg[0]->getHeight()+5;
-  tw=sg[0]->getWidth()+5+x;
-  if(tw>w) w=tw;
-  x=5;
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(337),1));
-  x+=ttext->getWidth()+5;
-  comreqb2 = (Button*)win->add( new Button( aguix, x, y, catalog.getLocale( 458 ), 1, 0, 0 ) );
-  x += comreqb2->getWidth();
-  
-  tw=w-x-5;
-  if ( tw < ( 20 * aguix->getCharWidth() ) ) tw = 20 * aguix->getCharWidth();
-  sg[1]=(StringGadget*)win->add(new StringGadget(aguix,x,y,tw,view_str,0));
-  comreqb2->resize( comreqb2->getWidth(), sg[1]->getHeight() );
-  
-  y+=sg[1]->getHeight()+5;
-  tw=sg[1]->getWidth()+5+x;
-  if(tw>w) w=tw;
-  x=5;
+  comreqb = (Button*)ac1_2->add( new Button( aguix, 0, 0, catalog.getLocale( 458 ), 1, 0, 0 ), 2, 0, cfix );
 
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  w-5-t2,
-                                  y,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
+  sg[0] = (StringGadget*)ac1_2->add( new StringGadget( aguix, 0, 0, 100, com_str, 0 ), 3, 0, cincw );
   
-  sg[0]->resize(w-5-sg[0]->getX()-sg[0]->getHeight(),sg[0]->getHeight());
-  sg[1]->resize(w-5-sg[1]->getX(),sg[1]->getHeight());
-  fb->move(w-5-fb->getWidth(),fb->getY());
+  fb = (Button*)ac1_2->add( new Button( aguix, 0, 0, "O", 1, 0, 0 ), 4, 0, cfix );
+  
+  AContainer *ac1_3 = ac1->add( new AContainer( win, 4, 1 ), 0, 7 );
+  ac1_3->setMinSpace( 0 );
+  ac1_3->setMaxSpace( 0 );
+  ac1_3->setBorderWidth( 0 );
 
-  h=y;
+  ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 337 ), 1 ), 0, 0, cfix );
+  ac1_3->setMinWidth( 5, 1, 0 );
+  ac1_3->setMaxWidth( 5, 1, 0 );
+  comreqb2 = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 458 ), 1, 0, 0 ), 2, 0, cfix );
+  sg[1] = (StringGadget*)ac1_3->add( new StringGadget( aguix, 0, 0, 100, view_str, 0 ), 3, 0, cincw );
+  
+  AContainer *ac1_4 = ac1->add( new AContainer( win, 2, 1 ), 0, 8 );
+  ac1_4->setMinSpace( 5 );
+  ac1_4->setMaxSpace( -1 );
+  ac1_4->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_4->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_4->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
+  
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMaxSize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
