@@ -1,6 +1,6 @@
 /* partspace.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: partspace.h,v 1.12 2004/10/27 21:08:26 ralf Exp $ */
+/* $Id: partspace.h,v 1.13 2005/01/11 23:21:18 ralf Exp $ */
 
 #ifndef PARTSPACE_H
 #define PARTSPACE_H
@@ -59,7 +59,8 @@ protected:
   loff_t freespace;
   loff_t space;
   
-  double info_lifetime, info_maxlifetime;
+  double info_lifetime;
+  int spaceinfo_maxsize;
   
 #ifdef WANT_THREADS  
   struct {
@@ -78,6 +79,7 @@ protected:
   public:
     typedef struct _space_request_list_t {
       char *name;
+      dev_t device;
 #ifdef HAVE_STATVFS
       worker_struct_statvfs fsstatistic;
 #elif defined( HAVE_STATFS )
