@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: reloadop.cc,v 1.19 2005/05/15 20:54:58 ralf Exp $ */
+/* $Id: reloadop.cc,v 1.21 2005/10/19 18:03:00 ralf Exp $ */
 
 #include "reloadop.h"
 #include "listermode.h"
@@ -62,10 +62,9 @@ ReloadOp::getName()
 }
 
 int
-ReloadOp::run(ActionMessage *msg)
+ReloadOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -73,9 +72,9 @@ ReloadOp::run(ActionMessage *msg)
       lm1=startlister->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmodereload();
+          normalmodereload( msg );
     }
-  } else normalmodereload();
+  } else normalmodereload( msg );
   return 0;
 }
 
@@ -109,7 +108,7 @@ ReloadOp::getDescription()
 }
 
 void
-ReloadOp::normalmodereload()
+ReloadOp::normalmodereload( ActionMessage *am )
 {
   NormalMode *nm1=NULL;
   ListerMode *lm1=NULL;
@@ -155,33 +154,45 @@ int
 ReloadOp::configure()
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   AWindow *win;
   CycleButton *rcyb;
   ChooseButton *rdscb, *kftcb;
-  Text *ttext;
-  int tw,w,h,x,y,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   char *tstr;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
   
-  w=h=10;
-  x=y=5;
-
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(26))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(26));
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(339),1));
-  x+=ttext->getWidth()+5;
-  rcyb=(CycleButton*)win->add(new CycleButton(aguix,x,y,100,1,0,0));
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 0 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 339 ), 1 ), 0, 0, cfix );
+  rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
   rcyb->addOption(catalog.getLocale(324));
   rcyb->addOption(catalog.getLocale(325));
   rcyb->addOption(catalog.getLocale(326));
   rcyb->addOption(catalog.getLocale(327));
   rcyb->resize(rcyb->getMaxSize(),rcyb->getHeight());
+  ac1_1->readLimits();
   switch(reloadside) {
     case RELOADOP_OTHERSIDE:
       rcyb->setOption(1);
@@ -197,58 +208,39 @@ ReloadOp::configure()
       break;
   }
   
-  y+=rcyb->getHeight()+5;
-  tw=x+rcyb->getWidth()+5;
-  if(tw>w) w=tw;
-  x=5;
+  rdscb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( reset_dirsizes == true ) ? 1 : 0,
+						     catalog.getLocale( 385 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
 
-  rdscb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,(reset_dirsizes==true)?1:0,
-                                                 catalog.getLocale(385),LABEL_RIGHT,1,0));
-  y+=rdscb->getHeight()+5;
-  tw=rdscb->getWidth()+10;
-  if(tw>w) w=tw;
-
-  kftcb = (ChooseButton*)win->add( new ChooseButton( aguix,
-                                                     x,
-                                                     y,
+  kftcb = (ChooseButton*)ac1->add( new ChooseButton( aguix,
+                                                     0,
+                                                     0,
                                                      ( keep_filetypes == true ) ? 1 : 0,
                                                      catalog.getLocale( 434 ),
                                                      LABEL_RIGHT,
                                                      1,
-                                                     0 ) );
-  y+=kftcb->getHeight()+5;
-  tw=kftcb->getWidth()+10;
-  if(tw>w) w=tw;
-
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  w-5-t2,
-                                  y,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
+                                                     0 ), 0, 2, cincwnr  );
+  
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_2->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
   
-  h=y;
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMaxSize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
