@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: reloadop.h,v 1.10 2004/10/27 21:08:33 ralf Exp $ */
+/* $Id: reloadop.h,v 1.11 2005/10/19 18:02:57 ralf Exp $ */
 
 #ifndef RELOADOP_H
 #define RELOADOP_H
@@ -47,7 +47,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
   virtual int configure();
@@ -69,7 +69,7 @@ protected:
   // temp variables
   Lister *startlister;
   
-  void normalmodereload();
+  void normalmodereload( ActionMessage *am );
 };
 
 #endif
