@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: renameop.cc,v 1.12 2004/12/12 21:45:53 ralf Exp $ */
+/* $Id: renameop.cc,v 1.13 2005/10/19 18:02:51 ralf Exp $ */
 
 #include "renameop.h"
 #include "listermode.h"
@@ -55,10 +55,9 @@ RenameOp::getName()
 }
 
 int
-RenameOp::run(ActionMessage *msg)
+RenameOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -66,7 +65,7 @@ RenameOp::run(ActionMessage *msg)
       lm1=startlister->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmoderename();
+          normalmoderename( msg );
     }
   }
   return 0;
@@ -79,7 +78,7 @@ RenameOp::getDescription()
 }
 
 int
-RenameOp::normalmoderename()
+RenameOp::normalmoderename( ActionMessage *am )
 {
   NormalMode *nm1=NULL;
   ListerMode *lm1=NULL;
