@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: renameop.h,v 1.9 2004/10/27 21:08:36 ralf Exp $ */
+/* $Id: renameop.h,v 1.10 2005/10/19 18:02:45 ralf Exp $ */
 
 #ifndef RENAMEOP_H
 #define RENAMEOP_H
@@ -40,7 +40,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 protected:
   static const char *name;
@@ -49,7 +49,7 @@ protected:
   // temp variables
   Lister *startlister;
   
-  int normalmoderename();
+  int normalmoderename( ActionMessage *am );
 };
 
 #endif
