@@ -1,6 +1,6 @@
 /* scriptop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2004 Ralf Hoffmann.
+ * Copyright (C) 2002-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: scriptop.cc,v 1.18 2005/05/15 21:20:49 ralf Exp $ */
+/* $Id: scriptop.cc,v 1.19 2005/08/17 06:32:35 ralf Exp $ */
 
 #include "scriptop.h"
 #include "listermode.h"
@@ -26,6 +26,7 @@
 #include "worker.h"
 #include "wpucontext.h"
 #include "execlass.h"
+#include <aguix/acontainerbb.h>
 
 const char *ScriptOp::name="ScriptOp";
 
@@ -517,37 +518,46 @@ const char *ScriptOp::getIfLabel()
 int ScriptOp::configure()
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   AWindow *win;
   FieldListView *lv;
   ChooseButton *chb;
-  Text *ttext;
-  int tw,ttw,tth,ttx,tty;
   AGMessage *msg;
   int endmode=-1;
   char *tstr;
   char buf[ A_BYTESFORNUMBER( int ) ];
   AWindow *push_win, *label_win, *if_win, *nop_win, *pop_win, *end_win, *set_win, *win_win, *goto_win;
-  int lx, ly;
-  GUIElement *bs[2];
   StringGadget *popsg;
   AWindow *winlist[9];
   int cur_win;
-  int trow;
+  int trow, i, tw, th;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
+  const int cfixnr = cfix + AContainer::ACONT_NORESIZE;
+  const int cmin = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW;
+  char **liness;
+  int lines;
   
-  ttw=tth=10;
-  ttx=tty=5;
-
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getName())+1);
   sprintf(tstr,catalog.getLocale(293),getName());
-  win = new AWindow( aguix, 10, 10, ttw, tth, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
-  ttext = (Text*)win->add( new Text( aguix, ttx, tty, catalog.getLocale( 461 ), 1 ) );
-  tty += ttext->getHeight() + 5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
 
-  lv = (FieldListView*)win->add( new FieldListView( aguix, ttx, tty, 100, 50, 0 ) );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 461 ), 1 ), 0, 0, cincwnr );
+
+  lv = (FieldListView*)ac1->add( new FieldListView( aguix, 0, 0, 100, 50, 0 ), 0, 1, cincwnr );
   lv->setVBarState( 0 );
   lv->setHBarState( 0 );
   lv->setDisplayFocus( true );
@@ -590,419 +600,367 @@ int ScriptOp::configure()
   else if ( type == SCRIPT_WINDOW ) lv->setActiveRow( 7 );
   else if ( type == SCRIPT_GOTO ) lv->setActiveRow( 8 );
   else lv->setActiveRow( 0 );
+  ac1->readLimits();
 
-  tty += lv->getHeight() + 5;  
-
-  tw = ttx + lv->getWidth() + 5;
-  if(tw>ttw) ttw=tw;
-  ttx=5;
-
-  push_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
-  win->add( push_win );
+  push_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  ac1->add( push_win, 0, 2, cmin );
   push_win->create();
   push_win->setBorderWidth( 0 );
-  lx = 0;
-  ly = 0;
-  ttext = (Text*)push_win->add( new Text( aguix, lx, ly, catalog.getLocale( 468 ), 1 ) );
 
-  ly += ttext->getHeight() + 5;
+  AContainer *push_win_ac1 = push_win->setContainer( new AContainer( push_win, 1, 5 ), true );
+  push_win_ac1->setMinSpace( 5 );
+  push_win_ac1->setMaxSpace( 5 );
+  push_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 468 ), 1 ), 0, 0, cincwnr );
 
-  chb = (ChooseButton*)push_win->add( new ChooseButton( aguix, lx, ly,
-                                                        ( push_useoutput == true ) ? 1 : 0,
-                                                        catalog.getLocale( 469 ), LABEL_RIGHT, 1, 0 ) );
-  ly += chb->getHeight() + 5;
+  chb = (ChooseButton*)push_win_ac1->add( new ChooseButton( aguix, 0, 0,
+							    ( push_useoutput == true ) ? 1 : 0,
+							    catalog.getLocale( 469 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
+
+  AContainer *push_win_ac1_1 = push_win_ac1->add( new AContainer( push_win, 2, 1 ), 0, 2 );
+  push_win_ac1_1->setMinSpace( 5 );
+  push_win_ac1_1->setMaxSpace( 5 );
+  push_win_ac1_1->setBorderWidth( 0 );
 
   sprintf( buf, "%d", stack_nr );
-  ttext = (Text*)push_win->add( new Text( aguix, lx, ly, catalog.getLocale( 470 ), 1 ) );
-  lx += ttext->getWidth() + 5;
-  StringGadget *psnsg = (StringGadget*)push_win->add( new StringGadget( aguix,
-                                                                        lx,
-                                                                        ly,
-                                                                        20 * aguix->getCharWidth(),
-                                                                        buf,
-                                                                        0 ) );
+  push_win_ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 470 ), 1 ), 0, 0, cfix );
+  StringGadget *psnsg = (StringGadget*)push_win_ac1_1->add( new StringGadget( aguix,
+									      0,
+									      0,
+									      100,
+									      buf,
+									      0 ), 1, 0, cincw );
 
-  ly += psnsg->getHeight() + 5;
-  lx = 0;
+  AContainer *push_win_ac1_2 = push_win_ac1->add( new AContainer( push_win, 3, 1 ), 0, 3 );
+  push_win_ac1_2->setMinSpace( 5 );
+  push_win_ac1_2->setMaxSpace( 5 );
+  push_win_ac1_2->setBorderWidth( 0 );
 
-  AGUIX::centerElementsY( ttext, psnsg );
-
-  ttext = (Text*)push_win->add( new Text( aguix, lx, ly, catalog.getLocale( 471 ), 1 ) );
-  lx += ttext->getWidth() + 5;
-  StringGadget *pssg = (StringGadget*)push_win->add( new StringGadget( aguix,
-                                                                       lx,
-                                                                       ly,
-                                                                       20 * aguix->getCharWidth(),
-                                                                       ( push_string != NULL ) ? push_string : "",
-                                                                       0 ) );
-  lx += pssg->getWidth();
-  Button *psb = (Button*)push_win->add( new Button( aguix,
-                                                    lx,
-                                                    ly,
-                                                    "F",
-                                                    1,
-                                                    0,
-                                                    0 ) );
-  psb->resize( psb->getWidth(), pssg->getHeight() );
-  AGUIX::centerElementsY( ttext, pssg );
+  push_win_ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 471 ), 1 ), 0, 0, cfix );
+  StringGadget *pssg = (StringGadget*)push_win_ac1_2->add( new StringGadget( aguix,
+									     0,
+									     0,
+									     100,
+									     ( push_string != NULL ) ? push_string : "",
+									     0 ), 1, 0, cincw );
+  Button *psb = (Button*)push_win_ac1_2->add( new Button( aguix,
+							  0,
+							  0,
+							  "F",
+							  1,
+							  0,
+							  0 ), 2, 0, cfix );
   
-  lx = 0;
-  ly += pssg->getHeight() + 5;
+  ChooseButton *pdcb = (ChooseButton*)push_win_ac1->add( new ChooseButton( aguix,
+									   0,
+									   0,
+									   dodebug,
+									   catalog.getLocale( 474 ),
+									   LABEL_RIGHT,
+									   1,
+									   0 ), 0, 4, cincwnr );
   
-  ChooseButton *pdcb = (ChooseButton*)push_win->add( new ChooseButton( aguix,
-                                                                       lx,
-                                                                       ly,
-                                                                       dodebug,
-                                                                       catalog.getLocale( 474 ),
-                                                                       LABEL_RIGHT,
-                                                                       1,
-                                                                       0 ) );
-
-  push_win->maximizeX();
-  push_win->maximizeY();
-  
-  pop_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
-  win->add( pop_win );
+  pop_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  ac1->add( pop_win, 0, 2, cmin );
   pop_win->create();
   pop_win->setBorderWidth( 0 );
-  lx = 0;
-  ly = 0;
-  ttext = (Text*)pop_win->add( new Text( aguix, lx, ly, catalog.getLocale( 472 ), 1 ) );
 
-  ly += ttext->getHeight() + 5;
+  AContainer *pop_win_ac1 = pop_win->setContainer( new AContainer( pop_win, 1, 2 ), true );
+  pop_win_ac1->setMinSpace( 5 );
+  pop_win_ac1->setMaxSpace( 5 );
+
+  pop_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 472 ), 1 ), 0, 0, cincwnr  );
+
+  AContainer *pop_win_ac1_1 = pop_win_ac1->add( new AContainer( pop_win, 2, 1 ), 0, 1 );
+  pop_win_ac1_1->setMinSpace( 5 );
+  pop_win_ac1_1->setMaxSpace( 5 );
+  pop_win_ac1_1->setBorderWidth( 0 );
 
   sprintf( buf, "%d", stack_nr );
-  ttext = (Text*)pop_win->add( new Text( aguix, lx, ly, catalog.getLocale( 470 ), 1 ) );
-  lx += ttext->getWidth() + 5;
-  popsg = (StringGadget*)pop_win->add( new StringGadget( aguix,
-                                                         lx,
-                                                         ly,
-                                                         20 * aguix->getCharWidth(),
-                                                         buf,
-                                                         0 ) );
-  AGUIX::centerElementsY( ttext, popsg );
-
-  ly += popsg->getHeight() + 5;
-  pop_win->maximizeX();
-  pop_win->maximizeY();
+  pop_win_ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 470 ), 1 ), 0, 0, cfix );
+  popsg = (StringGadget*)pop_win_ac1_1->add( new StringGadget( aguix,
+							       0,
+							       0,
+							       100,
+							       buf,
+							       0 ), 1, 0, cincw );
   
-  label_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
-  win->add( label_win );
+  label_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  ac1->add( label_win, 0, 2, cmin );
   label_win->create();
   label_win->setBorderWidth( 0 );
-  lx = 0;
-  ly = 0;
 
-  ttext = (Text*)label_win->add( new Text( aguix, lx, ly, catalog.getLocale( 475 ), 1 ) );
-  lx += ttext->getWidth() + 5;
-  StringGadget *labelsg = (StringGadget*)label_win->add( new StringGadget( aguix,
-                                                                          lx,
-                                                                          ly,
-                                                                          20 * aguix->getCharWidth(),
-                                                                          ( label != NULL ) ? label : "",
-                                                                          0 ) );
-  AGUIX::centerElementsY( ttext, labelsg );
+  AContainer *label_win_ac1 = label_win->setContainer( new AContainer( label_win, 2, 1 ), true );
+  label_win_ac1->setMinSpace( 5 );
+  label_win_ac1->setMaxSpace( 5 );
+
+  label_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 475 ), 1 ), 0, 0, cfix );
+  StringGadget *labelsg = (StringGadget*)label_win_ac1->add( new StringGadget( aguix,
+									       0,
+									       0,
+									       100,
+									       ( label != NULL ) ? label : "",
+									       0 ), 1, 0, cincw );
 
-  label_win->maximizeX();
-  label_win->maximizeY();
   
-  nop_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
-  win->add( nop_win );
+  nop_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  ac1->add( nop_win, 0, 2, cmin );
   nop_win->create();
   nop_win->setBorderWidth( 0 );
-  lx = 0;
-  ly = 0;
-  ttext = (Text*)nop_win->add( new Text( aguix, lx, ly, catalog.getLocale( 476 ), 1 ) );
-  nop_win->maximizeX();
-  nop_win->maximizeY();
+
+  AContainer *nop_win_ac1 = nop_win->setContainer( new AContainer( nop_win, 1, 1 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  nop_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 476 ), 1 ), 0, 0, cincwnr );
   
-  end_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
-  win->add( end_win );
+  end_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  ac1->add( end_win, 0, 2, cmin );
   end_win->create();
   end_win->setBorderWidth( 0 );
-  lx = 0;
-  ly = 0;
-  ttext = (Text*)end_win->add( new Text( aguix, lx, ly, catalog.getLocale( 477 ), 1 ) );
-  end_win->maximizeX();
-  end_win->maximizeY();
+
+  AContainer *end_win_ac1 = end_win->setContainer( new AContainer( end_win, 1, 1 ), true );
+  end_win_ac1->setMinSpace( 5 );
+  end_win_ac1->setMaxSpace( 5 );
+
+  end_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 477 ), 1 ), 0, 0, cincwnr );
   
-  if_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
-  win->add( if_win );
+  if_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  ac1->add( if_win, 0, 2, cmin );
   if_win->create();
   if_win->setBorderWidth( 0 );
-  lx = 0;
-  ly = 0;
-  ttext = (Text*)if_win->add( new Text( aguix, lx, ly, catalog.getLocale( 478 ), 1 ) );
-  lx += ttext->getWidth() + 5;
-  Button *ifhelpb = (Button*)if_win->add( new Button( aguix, lx, ly, catalog.getLocale( 483 ), 1, 0, 0 ) );
-  lx = 0;
-  AGUIX::centerElementsY( ttext, ifhelpb );
+
+  AContainer *if_win_ac1 = if_win->setContainer( new AContainer( if_win, 1, 4 ), true );
+  if_win_ac1->setMinSpace( 5 );
+  if_win_ac1->setMaxSpace( 5 );
+
+  AContainer *if_win_ac1_1 = if_win_ac1->add( new AContainer( if_win, 2, 1 ), 0, 0 );
+  if_win_ac1_1->setMinSpace( 5 );
+  if_win_ac1_1->setMaxSpace( 5 );
+  if_win_ac1_1->setBorderWidth( 0 );
+
+  if_win_ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 478 ), 1 ), 0, 0, cfix );
+  Button *ifhelpb = (Button*)if_win_ac1_1->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 1, 0, 0 ), 1, 0, cincw );
+
+  AContainer *if_win_ac1_2 = if_win_ac1->add( new AContainer( if_win, 3, 1 ), 0, 1 );
+  if_win_ac1_2->setMinSpace( 5 );
+  if_win_ac1_2->setMaxSpace( 5 );
+  if_win_ac1_2->setBorderWidth( 0 );
+
+  if_win_ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 479 ), 1 ), 0, 0, cfix );
+  StringGadget *iftsg = (StringGadget*)if_win_ac1_2->add( new StringGadget( aguix,
+									    0,
+									    0,
+									    100,
+									    ( if_test != NULL ) ? if_test : "",
+									    0 ), 1, 0, cincw );
+  Button *iftb = (Button*)if_win_ac1_2->add( new Button( aguix,
+							 0,
+							 0,
+							 "F",
+							 1,
+							 0,
+							 0 ), 2, 0, cfix );
+
+  AContainer *if_win_ac1_3 = if_win_ac1->add( new AContainer( if_win, 2, 1 ), 0, 2 );
+  if_win_ac1_3->setMinSpace( 5 );
+  if_win_ac1_3->setMaxSpace( 5 );
+  if_win_ac1_3->setBorderWidth( 0 );
+
+  if_win_ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 475 ), 1 ), 0, 0, cfix );
+  StringGadget *iflsg = (StringGadget*)if_win_ac1_3->add( new StringGadget( aguix,
+									    0,
+									    0,
+									    100,
+									    ( if_label != NULL ) ? if_label : "",
+									    0 ), 1, 0, cincw );
+
+  ChooseButton *idcb = (ChooseButton*)if_win_ac1->add( new ChooseButton( aguix,
+									 0,
+									 0,
+									 dodebug,
+									 catalog.getLocale( 474 ),
+									 LABEL_RIGHT,
+									 1,
+									 0 ), 0, 3, cincwnr );
+
   
-  ly += ifhelpb->getHeight() + 5;
-
-  ttext = (Text*)if_win->add( new Text( aguix, lx, ly, catalog.getLocale( 479 ), 1 ) );
-  lx += ttext->getWidth() + 5;
-  StringGadget *iftsg = (StringGadget*)if_win->add( new StringGadget( aguix,
-                                                                      lx,
-                                                                      ly,
-                                                                      20 * aguix->getCharWidth(),
-                                                                      ( if_test != NULL ) ? if_test : "",
-                                                                      0 ) );
-  lx += iftsg->getWidth();
-  Button *iftb = (Button*)if_win->add( new Button( aguix,
-                                                   lx,
-                                                   ly,
-                                                   "F",
-                                                   1,
-                                                   0,
-                                                   0 ) );
-  iftb->resize( iftb->getWidth(), iftsg->getHeight() );
-  AGUIX::centerElementsY( ttext, iftsg );
-
-  ly += iftsg->getHeight() + 5;
-  lx = 0;
-
-  ttext = (Text*)if_win->add( new Text( aguix, lx, ly, catalog.getLocale( 475 ), 1 ) );
-  lx += ttext->getWidth() + 5;
-  StringGadget *iflsg = (StringGadget*)if_win->add( new StringGadget( aguix,
-                                                                      lx,
-                                                                      ly,
-                                                                      20 * aguix->getCharWidth(),
-                                                                      ( if_label != NULL ) ? if_label : "",
-                                                                      0 ) );
-  AGUIX::centerElementsY( ttext, iflsg );
-
-  lx = 0;
-  ly += iflsg->getHeight() + 5;
-  
-  ChooseButton *idcb = (ChooseButton*)if_win->add( new ChooseButton( aguix,
-                                                                     lx,
-                                                                     ly,
-                                                                     dodebug,
-                                                                     catalog.getLocale( 474 ),
-                                                                     LABEL_RIGHT,
-                                                                     1,
-                                                                     0 ) );
-
-  if_win->maximizeX();
-  if_win->maximizeY();
-  
-  set_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
-  win->add( set_win );
+  set_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  ac1->add( set_win, 0, 2, cmin );
   set_win->create();
   set_win->setBorderWidth( 0 );
-  lx = 0;
-  ly = 0;
-  set_win->addTextFromString( catalog.getLocale( 487 ), lx, ly, 5, NULL, NULL, &ly );
-  ly += 5;
 
-  ChooseButton *setrcb = (ChooseButton*)set_win->add( new ChooseButton( aguix,
-                                                                        lx,
-                                                                        ly,
-                                                                        wpu_recursive,
-                                                                        catalog.getLocale( 330 ),
-                                                                        LABEL_RIGHT,
-                                                                        1,
-                                                                        0 ) );
-  ly += setrcb->getHeight() + 5;
+  lines = createLines( catalog.getLocale( 487 ), &liness );
 
-  ChooseButton *settdcb = (ChooseButton*)set_win->add( new ChooseButton( aguix,
-                                                                         lx,
-                                                                         ly,
-                                                                         wpu_take_dirs,
-                                                                         catalog.getLocale( 513 ),
-                                                                         LABEL_RIGHT,
-                                                                         1,
-                                                                         0 ) );
-  set_win->maximizeX();
-  set_win->maximizeY();
+  AContainer *set_win_ac1 = set_win->setContainer( new AContainer( set_win, 1, lines + 2 ), true );
+  set_win_ac1->setMinSpace( 5 );
+  set_win_ac1->setMaxSpace( 5 );
+
+  for ( i = 0; i < lines; i++ ) {
+    set_win_ac1->add( new Text( aguix, 0, 0, liness[i], 1 ), 0, i, cincwnr );
+  }
+
+  for ( i = 0; i < lines; i++ ) _freesafe( liness[i] );
+  _freesafe( liness );
+
+  ChooseButton *setrcb = (ChooseButton*)set_win_ac1->add( new ChooseButton( aguix,
+									    0,
+									    0,
+									    wpu_recursive,
+									    catalog.getLocale( 330 ),
+									    LABEL_RIGHT,
+									    1,
+									    0 ), 0, lines, cincwnr );
+
+  ChooseButton *settdcb = (ChooseButton*)set_win_ac1->add( new ChooseButton( aguix,
+									     0,
+									     0,
+									     wpu_take_dirs,
+									     catalog.getLocale( 513 ),
+									     LABEL_RIGHT,
+									     1,
+									     0 ), 0, lines + 1, cincwnr );
   
-  win_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
-  win->add( win_win );
+  win_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  ac1->add( win_win, 0, 2, cmin );
   win_win->create();
   win_win->setBorderWidth( 0 );
-  lx = 0;
-  ly = 0;
-  Button *winhelpb = (Button*)win_win->add( new Button( aguix, lx, ly, catalog.getLocale( 483 ), 1, 0, 0 ) );
-  ly += winhelpb->getHeight() + 5;
 
-  ChooseButton *cwcb = (ChooseButton*)win_win->add( new ChooseButton( aguix, lx, ly,
-                                                        ( wintype == SCRIPT_WINDOW_LEAVE ) ? 0 : 1,
-                                                        catalog.getLocale( 490 ), LABEL_RIGHT, 1, 0 ) );
-  lx += cwcb->getWidth() + 5;
-  CycleButton *cwcycb = (CycleButton*)win_win->add( new CycleButton( aguix, lx, ly, 100, 1, 0, 0 ) );
+  AContainer *win_win_ac1 = win_win->setContainer( new AContainer( win_win, 1, 4 ), true );
+  win_win_ac1->setMinSpace( 5 );
+  win_win_ac1->setMaxSpace( 5 );
+
+  Button *winhelpb = (Button*)win_win_ac1->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 1, 0, 0 ), 0, 0, cincwnr );
+
+  AContainer *win_win_ac1_1 = win_win_ac1->add( new AContainer( win_win, 2, 1 ), 0, 1 );
+  win_win_ac1_1->setMinSpace( 5 );
+  win_win_ac1_1->setMaxSpace( 5 );
+  win_win_ac1_1->setBorderWidth( 0 );
+
+  ChooseButton *cwcb = (ChooseButton*)win_win_ac1_1->add( new ChooseButton( aguix, 0, 0,
+									    ( wintype == SCRIPT_WINDOW_LEAVE ) ? 0 : 1,
+									    catalog.getLocale( 490 ), LABEL_RIGHT, 1, 0 ), 0, 0, cfixnr );
+  CycleButton *cwcycb = (CycleButton*)win_win_ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
   cwcycb->addOption( catalog.getLocale( 491 ) );
   cwcycb->addOption( catalog.getLocale( 492 ) );
   cwcycb->resize( cwcycb->getMaxSize(), cwcycb->getHeight() );
   if ( wintype == SCRIPT_WINDOW_CLOSE ) cwcycb->setOption( 1 );
   else cwcycb->setOption( 0 );
+  win_win_ac1_1->readLimits();
 
-  lx = 0;                                                        
-  ly += cwcb->getHeight() + 5;
+  AContainerBB *win_win_ac1_2 = static_cast<AContainerBB*>( win_win_ac1->add( new AContainerBB( win_win, 1, 2 ), 0, 2 ) );
+  win_win_ac1_2->setMinSpace( 5 );
+  win_win_ac1_2->setMaxSpace( 5 );
+
+  ChooseButton *cpcb = (ChooseButton*)win_win_ac1_2->add( new ChooseButton( aguix, 0, 0,
+									    ( change_progress == true ) ? 1 : 0,
+									    catalog.getLocale( 493 ), LABEL_RIGHT, 1, 0 ), 0, 0, cincwnr );
+  AContainer *win_win_ac1_2_1 = win_win_ac1_2->add( new AContainer( win_win, 2, 2 ), 0, 1 );
+  win_win_ac1_2_1->setMinSpace( 5 );
+  win_win_ac1_2_1->setMaxSpace( 5 );
+  win_win_ac1_2_1->setBorderWidth( 0 );
+  win_win_ac1_2_1->setMinWidth( 5, 0, 0 );
+  win_win_ac1_2_1->setMaxWidth( 5, 0, 0 );
+
+  AContainer *win_win_ac1_2_1_1 = win_win_ac1_2_1->add( new AContainer( win_win, 3, 1 ), 1, 0 );
+  win_win_ac1_2_1_1->setMinSpace( 5 );
+  win_win_ac1_2_1_1->setMaxSpace( 5 );
+
+  win_win_ac1_2_1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 494 ), 1 ), 0, 0, cfix );
+  StringGadget *prosg = (StringGadget*)win_win_ac1_2_1_1->add( new StringGadget( aguix,
+										 0,
+										 0,
+										 100,
+										 ( progress != NULL ) ? progress : "",
+										 0 ), 1, 0, cincw );
+  Button *prob = (Button*)win_win_ac1_2_1_1->add( new Button( aguix,
+							      0,
+							      0,
+							      "F",
+							      1,
+							      0,
+							      0 ), 2, 0, cfix );
+
+  ChooseButton *prouocb = (ChooseButton*)win_win_ac1_2_1->add( new ChooseButton( aguix, 0, 0,
+										 ( progress_useoutput == true ) ? 1 : 0,
+										 catalog.getLocale( 495 ), LABEL_RIGHT, 1, 0 ), 1, 1, cincwnr );
+
+  AContainerBB *win_win_ac1_3 = static_cast<AContainerBB*>( win_win_ac1->add( new AContainerBB( win_win, 1, 2 ), 0, 3 ) );
+  win_win_ac1_3->setMinSpace( 5 );
+  win_win_ac1_3->setMaxSpace( 5 );
+
+  ChooseButton *cwtcb = (ChooseButton*)win_win_ac1_3->add( new ChooseButton( aguix, 0, 0,
+									     ( change_text == true ) ? 1 : 0,
+									     catalog.getLocale( 496 ), LABEL_RIGHT, 1, 0 ), 0, 0, cincwnr );
+
+  AContainer *win_win_ac1_3_1 = win_win_ac1_3->add( new AContainer( win_win, 2, 2 ), 0, 1 );
+  win_win_ac1_3_1->setMinSpace( 5 );
+  win_win_ac1_3_1->setMaxSpace( 5 );
+  win_win_ac1_3_1->setBorderWidth( 0 );
+  win_win_ac1_3_1->setMinWidth( 5, 0, 0 );
+  win_win_ac1_3_1->setMaxWidth( 5, 0, 0 );
+
+  AContainer *win_win_ac1_3_1_1 = win_win_ac1_3_1->add( new AContainer( win_win, 3, 1 ), 1, 0 );
+  win_win_ac1_3_1_1->setMinSpace( 5 );
+  win_win_ac1_3_1_1->setMaxSpace( 5 );
+
+  win_win_ac1_3_1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 497 ), 1 ), 0, 0, cfix );
+  StringGadget *wintextsg = (StringGadget*)win_win_ac1_3_1_1->add( new StringGadget( aguix,
+										     0,
+										     0,
+										     100,
+										     ( wintext != NULL ) ? wintext : "",
+										     0 ), 1, 0, cincw );
+  Button *wintextb = (Button*)win_win_ac1_3_1_1->add( new Button( aguix,
+								  0,
+								  0,
+								  "F",
+								  1,
+								  0,
+								  0 ), 2, 0, cfix );
+
+  ChooseButton *wintextuocb = (ChooseButton*)win_win_ac1_3_1->add( new ChooseButton( aguix, 0, 0,
+										     ( wintext_useoutput == true ) ? 1 : 0,
+										     catalog.getLocale( 498 ), LABEL_RIGHT, 1, 0 ), 1, 1, cincwnr );
 
-  BevelBox *winbb1 = (BevelBox*)win_win->add( new BevelBox( aguix, lx, ly, 10, 10, 1 ) );
-  lx = 5;
-  ly += 5;
   
-  ChooseButton *cpcb = (ChooseButton*)win_win->add( new ChooseButton( aguix, lx, ly,
-                                                        ( change_progress == true ) ? 1 : 0,
-                                                        catalog.getLocale( 493 ), LABEL_RIGHT, 1, 0 ) );
-  ly += cpcb->getHeight() + 5;
-  lx = 15;
-
-  ttext = (Text*)win_win->add( new Text( aguix, lx, ly, catalog.getLocale( 494 ), 1 ) );
-  lx += ttext->getWidth() + 5;
-  StringGadget *prosg = (StringGadget*)win_win->add( new StringGadget( aguix,
-                                                                       lx,
-                                                                       ly,
-                                                                       20 * aguix->getCharWidth(),
-                                                                       ( progress != NULL ) ? progress : "",
-                                                                       0 ) );
-  lx += prosg->getWidth();
-  Button *prob = (Button*)win_win->add( new Button( aguix,
-                                                    lx,
-                                                    ly,
-                                                    "F",
-                                                    1,
-                                                    0,
-                                                    0 ) );
-  prob->resize( prob->getWidth(), prosg->getHeight() );
-  AGUIX::centerElementsY( ttext, prosg );
-  
-  lx = 15;
-  ly += prosg->getHeight();
-
-  ChooseButton *prouocb = (ChooseButton*)win_win->add( new ChooseButton( aguix, lx, ly,
-                                                           ( progress_useoutput == true ) ? 1 : 0,
-                                                           catalog.getLocale( 495 ), LABEL_RIGHT, 1, 0 ) );
-  ly += prouocb->getHeight() + 5;
-  winbb1->resize( winbb1->getWidth(), ly - winbb1->getY() );
-  ly += 5;
-  
-  lx = 0;
-
-  BevelBox *winbb2 = (BevelBox*)win_win->add( new BevelBox( aguix, lx, ly, 10, 10, 1 ) );
-  lx = 5;
-  ly += 5;
-  
-  ChooseButton *cwtcb = (ChooseButton*)win_win->add( new ChooseButton( aguix, lx, ly,
-                                                         ( change_text == true ) ? 1 : 0,
-                                                         catalog.getLocale( 496 ), LABEL_RIGHT, 1, 0 ) );
-  ly += cwtcb->getHeight() + 5;
-  lx = 15;
-
-  ttext = (Text*)win_win->add( new Text( aguix, lx, ly, catalog.getLocale( 497 ), 1 ) );
-  lx += ttext->getWidth() + 5;
-  StringGadget *wintextsg = (StringGadget*)win_win->add( new StringGadget( aguix,
-                                                                           lx,
-                                                                           ly,
-                                                                           20 * aguix->getCharWidth(),
-                                                                           ( wintext != NULL ) ? wintext : "",
-                                                                           0 ) );
-  lx += wintextsg->getWidth();
-  Button *wintextb = (Button*)win_win->add( new Button( aguix,
-                                                        lx,
-                                                        ly,
-                                                        "F",
-                                                        1,
-                                                        0,
-                                                        0 ) );
-  wintextb->resize( wintextb->getWidth(), wintextsg->getHeight() );
-  AGUIX::centerElementsY( ttext, wintextsg );
-  
-  lx = 15;
-  ly += wintextsg->getHeight();
-
-  ChooseButton *wintextuocb = (ChooseButton*)win_win->add( new ChooseButton( aguix, lx, ly,
-                                                               ( wintext_useoutput == true ) ? 1 : 0,
-                                                               catalog.getLocale( 498 ), LABEL_RIGHT, 1, 0 ) );
-  ly += wintextuocb->getHeight() + 5;
-  winbb2->resize( winbb2->getWidth(), ly - winbb2->getY() );
-  ly += 5;
-  
-  lx = 0;
-
-  win_win->maximizeX();
-  win_win->maximizeY();
-  
-  goto_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
-  win->add( goto_win );
+  goto_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  ac1->add( goto_win, 0, 2, cmin );
   goto_win->create();
   goto_win->setBorderWidth( 0 );
-  lx = 0;
-  ly = 0;
 
-  ttext = (Text*)goto_win->add( new Text( aguix, lx, ly, catalog.getLocale( 475 ), 1 ) );
-  lx += ttext->getWidth() + 5;
-  StringGadget *gotosg = (StringGadget*)goto_win->add( new StringGadget( aguix,
-                                                                         lx,
-                                                                         ly,
-                                                                         20 * aguix->getCharWidth(),
-                                                                         ( label != NULL ) ? label : "",
-                                                                         0 ) );
-  AGUIX::centerElementsY( ttext, gotosg );
+  AContainer *goto_win_ac1 = goto_win->setContainer( new AContainer( goto_win, 2, 1 ), true );
+  goto_win_ac1->setMinSpace( 5 );
+  goto_win_ac1->setMaxSpace( 5 );
+  
+  goto_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 475 ), 1 ), 0, 0, cfix );
+  StringGadget *gotosg = (StringGadget*)goto_win_ac1->add( new StringGadget( aguix,
+									     0,
+									     0,
+									     100,
+									     ( label != NULL ) ? label : "",
+									     0 ), 1, 0, cincw );
+  
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_2->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
 
-  goto_win->maximizeX();
-  goto_win->maximizeY();
-  
-  win->maximizeX();
-  win->maximizeY();
-  
-  tty = win->getHeight();
-  ttw = win->getWidth();
-
-  okb = (Button*)win->add( new Button( aguix,
-                                       5,
-                                       tty,
-                                       catalog.getLocale( 11 ),
-                                       1,
-                                       0,
-                                       0 ) );
-  cb = (Button*)win->add( new Button( aguix,
-                                      5,
-                                      tty,
-                                      catalog.getLocale( 8 ),
-                                      1,
-                                      0,
-                                      0 ) );
-  bs[0] = okb;
-  bs[1] = cb;
-  AGUIX::scaleElementsW( ttw, 5, 10, -1, false, false, bs, NULL, 2 );
-  
-  psnsg->resize( ttw - psnsg->getX() - 5 - 5, psnsg->getHeight() );
-  pssg->resize( ttw - pssg->getX() - 5 - 5 - psb->getWidth(), pssg->getHeight() );
-  psb->move( pssg->getX() + pssg->getWidth(), psb->getY() );
-  popsg->resize( ttw - popsg->getX() - 5 - 5, popsg->getHeight() );
-  labelsg->resize( ttw - labelsg->getX() - 5 - 5, labelsg->getHeight() );
-  iftsg->resize( ttw - iftsg->getX() - 5 - 5 - iftb->getWidth(), iftsg->getHeight() );
-  iftb->move( iftsg->getX() + iftsg->getWidth(), iftb->getY() );
-  iflsg->resize( ttw - iflsg->getX() - 5 - 5, iflsg->getHeight() );
-  ifhelpb->move( ttw - 5 - 5 - ifhelpb->getWidth(), ifhelpb->getY() );
-  prosg->resize( ttw - prosg->getX() - 5 - 5 - prob->getWidth() - 5, prosg->getHeight() );
-  prob->move( prosg->getX() + prosg->getWidth(), prob->getY() );
-  winbb1->resize( ttw - 5 - 5, winbb1->getHeight() );
-  wintextsg->resize( ttw - wintextsg->getX() - 5 - 5 - wintextb->getWidth() - 5, wintextsg->getHeight() );
-  wintextb->move( wintextsg->getX() + wintextsg->getWidth(), wintextb->getY() );
-  winbb2->resize( ttw - 5 - 5, winbb2->getHeight() );
-  gotosg->resize( ttw - gotosg->getX() - 5 - 5, gotosg->getHeight() );
-
-  push_win->maximizeX();
-  pop_win->maximizeX();
-  label_win->maximizeX();
-  if_win->maximizeX();
-  set_win->maximizeX();
-  win_win->maximizeX();
-  goto_win->maximizeX();
-  
-  tty += okb->getHeight() + 5;
-  
-  tth=tty;
-  
   win->setDoTabCycling( true );
-  win->resize(ttw,tth);
-  win->setMaxSize(ttw,tth);
-  win->setMinSize(ttw,tth);
-  
+
   winlist[0] = nop_win;
   winlist[1] = push_win;
   winlist[2] = pop_win;
@@ -1012,6 +970,21 @@ int ScriptOp::configure()
   winlist[6] = set_win;
   winlist[7] = win_win;
   winlist[8] = goto_win;
+
+  tw = 0;
+  th = 0;
+  AWindow *twin;
+  for ( i = 0; i < 9; i++ ) {
+    twin = winlist[i];
+    twin->contMaximize();
+    if ( twin->getWidth() > tw ) tw = twin->getWidth();
+    if ( twin->getHeight() > th ) th = twin->getHeight();
+  }
+  ac1->setMinWidth( tw, 0, 2 );
+  ac1->setMinHeight( th, 0, 2 );
+
+  win->contMaximize( true );
+  
   switch( type ) {
     case SCRIPT_PUSH:
       cur_win = 1;
@@ -1041,7 +1014,15 @@ int ScriptOp::configure()
       cur_win = 0;
       break;
   }
-  winlist[cur_win]->show();
+  for ( i = 0; i < 9; i++ ) {
+    if ( i != cur_win )
+      winlist[i]->hide();
+    else {
+      winlist[i]->show();
+      ac1->add( winlist[i], 0, 2 );
+      ac1->rearrange();
+    }
+  }
   
   win->show();
   for(;endmode==-1;) {
@@ -1091,10 +1072,17 @@ int ScriptOp::configure()
         case AG_FIELDLV_ONESELECT:
         case AG_FIELDLV_MULTISELECT:
           if ( msg->fieldlv.lv == lv ) {
-            winlist[cur_win]->hide();
             cur_win = lv->getActiveRow();
             if ( ( cur_win < 0 ) || ( cur_win > 8 ) ) cur_win = 0;
-            winlist[cur_win]->show();
+	    for ( i = 0; i < 9; i++ ) {
+	      if ( i != cur_win )
+		winlist[i]->hide();
+	      else {
+		winlist[i]->show();
+		ac1->add( winlist[i], 0, 2 );
+		ac1->rearrange();
+	      }
+	    }
           }
           break;
       }
