@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: scrolllisterop.h,v 1.8 2004/10/27 21:08:54 ralf Exp $ */
+/* $Id: scrolllisterop.h,v 1.9 2005/10/19 18:02:09 ralf Exp $ */
 
 #ifndef SCROLLLISTEROP_H
 #define SCROLLLISTEROP_H
@@ -45,7 +45,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
   virtual int configure();
@@ -61,7 +61,7 @@ protected:
   // temp variables
   Lister *startlister;
   
-  void normalmodescrolllister();
+  void normalmodescrolllister( ActionMessage *am );
 };
 
 #endif
