@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: searchentryop.cc,v 1.10 2005/05/15 20:55:34 ralf Exp $ */
+/* $Id: searchentryop.cc,v 1.12 2005/11/22 20:29:10 ralf Exp $ */
 
 #include "searchentryop.h"
 #include "listermode.h"
@@ -30,6 +30,7 @@ const char *SearchEntryOp::name="SearchEntryOp";
 SearchEntryOp::SearchEntryOp() : FunctionProto()
 {
   ignore_case = false;
+  reverse_search = false;
   hasConfigure = true;
 }
 
@@ -42,6 +43,7 @@ SearchEntryOp::duplicate() const
 {
   SearchEntryOp *ta=new SearchEntryOp();
   ta->ignore_case = ignore_case;
+  ta->reverse_search = reverse_search;
   return ta;
 }
 
@@ -58,10 +60,9 @@ SearchEntryOp::getName()
 }
 
 int
-SearchEntryOp::run(ActionMessage *msg)
+SearchEntryOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -93,7 +94,7 @@ SearchEntryOp::normalmodesearchentry()
   if(lm1->isType("NormalMode")!=true) return 1;
   nm1=(NormalMode*)lm1;
   
-  nm1->searchentry( ignore_case );
+  nm1->searchentry( ignore_case, reverse_search );
   return 0;
 }
 
@@ -101,6 +102,7 @@ bool SearchEntryOp::save( Datei *fh )
 {
   if ( fh == NULL ) return false;
   WConfig::configPutPairBool( fh, "ignorecase", ignore_case );
+  WConfig::configPutPairBool( fh, "reversesearch", reverse_search );
   return true;
 }
 
@@ -109,56 +111,67 @@ void SearchEntryOp::setIgnoreCase( bool nv )
   ignore_case = nv;
 }
 
+void SearchEntryOp::setReverseSearch( bool nv )
+{
+  reverse_search = nv;
+}
+
 int SearchEntryOp::configure()
 {
-  int w, h, tw, ty, tx;
-  ChooseButton *cb;
+  ChooseButton *cb, *rscb;
   AGUIX *aguix = Worker::getAGUIX();
   AWindow *win;
   char *tstr;
-  GUIElement *b[2];
   int ende = 0;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
 
-  w = h = 10;
   tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( getDescription() ) + 1 );
   sprintf( tstr, catalog.getLocale( 293 ), getDescription() );
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe( tstr );
   
-  ty = 5;
-  tx = 5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
 
-  cb = (ChooseButton*)win->add( new ChooseButton( aguix, tx, ty, ( ignore_case == true ) ? 1 : 0,
-                                                  catalog.getLocale( 501), LABEL_RIGHT, 1, 0 ) );
-  ty += cb->getHeight() + 5;
-  tw = cb->getWidth() + 10;
-  if ( tw > w ) w = tw;
+  cb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( ignore_case == true ) ? 1 : 0,
+						  catalog.getLocale( 501 ), LABEL_RIGHT, 1, 0 ), 0, 0, cincwnr );
+
+  rscb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( reverse_search == true ) ? 1 : 0,
+						    catalog.getLocale( 648 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
   
-  Button *okb = (Button*)win->add( new Button( aguix,
-                                               5,
-                                               ty,
-                                               catalog.getLocale( 11 ),
-                                               1,
-                                               0,
-                                               0 ) );
-  Button *cancelb = (Button*)win->add( new Button( aguix,
-                                                   5,
-                                                   ty,
-                                                   catalog.getLocale( 8 ),
-                                                   1,
-                                                   0,
-                                                   0 ) );
-  b[0] = okb;
-  b[1] = cancelb;
-  tw = AGUIX::scaleElementsW( w, 5, 5, -1, false, false, b, NULL, 2 );
-  if ( tw > w ) w = tw;
-  h = okb->getY() + okb->getHeight() + 5;
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( -1 );
+  ac1_1->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_1->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cancelb = (Button*)ac1_1->add( new Button( aguix,
+						     0,
+						     0,
+						     catalog.getLocale( 8 ),
+						     1,
+						     0,
+						     0 ), 1, 0, cfix );
+
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMinSize( w, h );
-  win->setMaxSize( w, h );
+  win->contMaximize( true );
   win->show();
+
   AGMessage *msg;
   while ( ( msg = aguix->GetMessage( NULL ) ) != NULL ) aguix->ReplyMessage( msg );
   while ( ende == 0 ) {
@@ -175,6 +188,7 @@ int SearchEntryOp::configure()
   }
   if ( ende == 1 ) {
     ignore_case = ( cb->getState() == 1 ) ? true : false;
+    reverse_search = ( rscb->getState() == 1 ) ? true : false;
   }
   delete win;
   return ( ende == 1 ) ? 0 : 1;
