@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: setfilterop.cc,v 1.18 2005/05/15 20:55:47 ralf Exp $ */
+/* $Id: setfilterop.cc,v 1.20 2005/10/19 18:01:52 ralf Exp $ */
 
 #include "setfilterop.h"
 #include "listermode.h"
@@ -77,10 +77,9 @@ SetFilterOp::getName()
 }
 
 int
-SetFilterOp::run(ActionMessage *msg)
+SetFilterOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -89,7 +88,7 @@ SetFilterOp::run(ActionMessage *msg)
       lm1=startlister->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmodesf();
+          normalmodesf( msg );
     }
   }
   return 0;
@@ -125,7 +124,7 @@ SetFilterOp::getDescription()
 }
 
 int
-SetFilterOp::normalmodesf()
+SetFilterOp::normalmodesf( ActionMessage *am )
 {
   NormalMode *nm1=NULL;
   ListerMode *lm1=NULL;
@@ -180,14 +179,11 @@ SetFilterOp::doconfigure(int mode)
                                                // but to be sure...
 
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   StringGadget *sg;
   FieldListView *lv;
   AWindow *win;
   ChooseButton *rfcb=NULL;
   CycleButton *fmcyb;
-  Text *ttext;
-  int tw,w,h,x,y,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   char *tstr;
@@ -195,21 +191,37 @@ SetFilterOp::doconfigure(int mode)
   int id, row;
   bool lvstill;
   int lastrow;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
+  const int cmin = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW;
   
-  w=h=10;
-  x=y=5;
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
   sprintf(tstr,catalog.getLocale(293),getDescription());
-  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
-  ttext = (Text*)win->add( new Text( aguix, x, y, getDescription(), 1 ) );
-  y += ttext->getHeight() + 5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 5 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
 
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(133),1));
-  x+=ttext->getWidth()+5;
-  fmcyb=(CycleButton*)win->add(new CycleButton(aguix,x,y,100,1,0,0));
+  ac1->add( new Text( aguix, 0, 0, getDescription(), 1 ), 0, 0, cincwnr );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 133 ), 1 ), 0, 0, cfix );
+  fmcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
   fmcyb->addOption(catalog.getLocale(191));
   fmcyb->addOption(catalog.getLocale(192));
   fmcyb->addOption(catalog.getLocale(193));
@@ -228,20 +240,18 @@ SetFilterOp::doconfigure(int mode)
     default:
       fmcyb->setOption(0);
   }
+  ac1_1->readLimits();
 
-  y+=fmcyb->getHeight()+5;
-  tw=x+fmcyb->getWidth()+5;
-  if(tw>w) w=tw;
-  x=5;
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 3, 2 ), 0, 2 );
+  ac1_2->setMinSpace( 0 );
+  ac1_2->setMaxSpace( 0 );
+  ac1_2->setBorderWidth( 0 );
 
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(93),1));
-  x+=ttext->getWidth()+5;
-  tw=w-x-5;
-  if(tw<50) tw=50;
+  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 93 ), 1 ), 0, 1, cfix );
 
   if ( mode != 0 ) {
-    lv = (FieldListView*)win->add( new FieldListView( aguix, x, y, a_max( tw, 10 * aguix->getCharWidth() ),
-                                                      7 * aguix->getCharHeight(), 0 ) );
+    lv = (FieldListView*)ac1_2->add( new FieldListView( aguix, 0, 0, 100,
+							7 * aguix->getCharHeight(), 0 ), 2, 0, cmin );
   
     lv->setHBarState( 2 );
     lv->setVBarState( 2 );
@@ -259,61 +269,40 @@ SetFilterOp::doconfigure(int mode)
     filter_history->closeEnum( id );
     lv->showRow( filter_history->size() - 1 );
     lv->redraw();
-  
-    tw = lv->getX() + lv->getWidth() + 5;
-    if ( tw > w ) w = tw;
-    tw = lv->getWidth(); // for following sg
-    y += lv->getHeight();
-    ttext->move( ttext->getX(), y );
   } else lv = NULL;
 
-  sg=(StringGadget*)win->add(new StringGadget(aguix,x,y,tw,filter,0));
-  y+=sg->getHeight()+5;
-  tw=sg->getWidth()+5+x;
-  if(tw>w) w=tw;
-  x=5;
+  sg = (StringGadget*)ac1_2->add( new StringGadget( aguix, 0, 0, 100, filter, 0 ), 2, 1, cincw );
+
+  ac1_2->setMinWidth( 5, 1, 0 );
+  ac1_2->setMaxWidth( 5, 1, 0 );
 
   if(mode==0) {
-    rfcb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,20,20,(request_flags==true)?1:0,
-                                                  catalog.getLocale(294),LABEL_RIGHT,1,0));
-    y+=rfcb->getHeight()+5;
-    tw=rfcb->getWidth()+10;
-    if(tw>w) w=tw;
+    rfcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20,( request_flags == true ) ? 1 : 0,
+						      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ), 0, 3, cincwnr );
   }
 
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  w-5-t2,
-                                  y,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
+  AContainer *ac1_3 = ac1->add( new AContainer( win, 2, 1 ), 0, 4 );
+  ac1_3->setMinSpace( 5 );
+  ac1_3->setMaxSpace( -1 );
+  ac1_3->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_3->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_3->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
   
-  sg->resize(w-5-sg->getX(),sg->getHeight());
-  if ( lv != NULL ) lv->resize( w - 5 - lv->getX(), lv->getHeight() );
-
-  h=y;
   fmcyb->takeFocus();
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  win->setMaxSize(w,h);
-  win->setMinSize(w,h);
+  win->contMaximize( true );
   win->show();
   lastrow = -1;
   lvstill = false;
