@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: setfilterop.h,v 1.8 2004/10/27 21:09:01 ralf Exp $ */
+/* $Id: setfilterop.h,v 1.9 2005/10/19 18:01:46 ralf Exp $ */
 
 #ifndef SETFILTEROP_H
 #define SETFILTEROP_H
@@ -43,7 +43,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
   virtual int configure();
@@ -68,7 +68,7 @@ protected:
   char *tfilter;
   setfilterop_mode tfiltermode;
 
-  int normalmodesf();
+  int normalmodesf( ActionMessage* );
 
   void addHistoryItem( const char *str );
   static List *filter_history;
