@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: setsortmodeop.cc,v 1.14 2005/05/15 20:55:52 ralf Exp $ */
+/* $Id: setsortmodeop.cc,v 1.16 2005/10/19 18:01:42 ralf Exp $ */
 
 #include "setsortmodeop.h"
 #include "listermode.h"
@@ -58,11 +58,10 @@ const char *SetSortmodeOp::getName()
   return name;
 }
 
-int SetSortmodeOp::run(ActionMessage *msg)
+int SetSortmodeOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   NormalMode *nm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -124,28 +123,39 @@ const char *SetSortmodeOp::getDescription()
 int SetSortmodeOp::configure()
 {
   AGUIX *aguix = Worker::getAGUIX();
-  Button *okb,*cb;
   AWindow *win;
   CycleButton *cyb[2];
   ChooseButton *chb;
-  Text *ttext;
-  int tw,ttw,tth,ttx,tty,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   char *tstr;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
   
-  ttw=tth=10;
-  ttx=tty=5;
-
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getName())+1);
   sprintf(tstr,catalog.getLocale(293),getName());
-  win = new AWindow( aguix, 10, 10, ttw, tth, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
-  ttext=(Text*)win->add(new Text(aguix,ttx,tty,catalog.getLocale(158),1));
-  ttx+=ttext->getWidth()+5;
-  cyb[0]=(CycleButton*)win->add(new CycleButton(aguix,ttx,tty,100,1,0,0));
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 0 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 158 ), 1 ), 0, 0, cfix );
+  cyb[0] = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
   cyb[0]->addOption(catalog.getLocale(160));
   cyb[0]->addOption(catalog.getLocale(161));
   cyb[0]->addOption(catalog.getLocale(162));
@@ -165,20 +175,19 @@ int SetSortmodeOp::configure()
   else if ( ( mode & 0xff ) == SORT_INODE ) cyb[0]->setOption( 7 );
   else if ( ( mode & 0xff ) == SORT_NLINK ) cyb[0]->setOption( 8 );
   else cyb[0]->setOption(0);
+  ac1_1->readLimits();
 
-  tty+=cyb[0]->getHeight()+5;
-  tw=ttx+cyb[0]->getWidth()+5;
-  if(tw>ttw) ttw=tw;
-  ttx=5;
+  chb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20,
+						   ( ( mode & SORT_REVERSE ) == SORT_REVERSE ) ? 1 : 0,
+						   catalog.getLocale( 165 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
 
-  chb=(ChooseButton*)win->add(new ChooseButton(aguix,ttx,tty,20,20,
-                                              ((mode&SORT_REVERSE)==SORT_REVERSE)?1:0,
-                                              catalog.getLocale(165),LABEL_RIGHT,1,0));
-  tty+=chb->getHeight()+5;
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( 5 );
+  ac1_2->setBorderWidth( 0 );
 
-  ttext=(Text*)win->add(new Text(aguix,ttx,tty,catalog.getLocale(353),1));
-  ttx+=ttext->getWidth()+5;
-  cyb[1]=(CycleButton*)win->add(new CycleButton(aguix,ttx,tty,100,1,0,0));
+  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 353 ), 1 ), 0, 0, cfix );
+  cyb[1] = (CycleButton*)ac1_2->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
   cyb[1]->addOption(catalog.getLocale(354));
   cyb[1]->addOption(catalog.getLocale(355));
   cyb[1]->addOption(catalog.getLocale(356));
@@ -186,42 +195,29 @@ int SetSortmodeOp::configure()
   if((mode&SORT_DIRLAST)==SORT_DIRLAST) cyb[1]->setOption(1);
   else if((mode&SORT_DIRMIXED)==SORT_DIRMIXED) cyb[1]->setOption(2);
   else cyb[1]->setOption(0);
+  ac1_2->readLimits();
 
-  tty+=cyb[1]->getHeight()+5;
-  tw=ttx+cyb[1]->getWidth()+5;
-  if(tw>ttw) ttw=tw;
-  ttx=5;
-
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>ttw) ttw=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   tty,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  ttw-5-t2,
-                                  tty,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  tty+=okb->getHeight()+5;
-  
-  tth=tty;
+  AContainer *ac1_3 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
+  ac1_3->setMinSpace( 5 );
+  ac1_3->setMaxSpace( -1 );
+  ac1_3->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_3->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_3->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
   
   win->setDoTabCycling( true );
-  win->resize(ttw,tth);
-  win->setMaxSize(ttw,tth);
-  win->setMinSize(ttw,tth);
+  win->contMaximize( true );
   win->show();
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
