@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: shortkeyfromlistop.cc,v 1.4 2004/10/27 21:09:09 ralf Exp $ */
+/* $Id: shortkeyfromlistop.cc,v 1.5 2005/10/19 18:01:35 ralf Exp $ */
 
 #include "shortkeyfromlistop.h"
 #include "listermode.h"
@@ -55,7 +55,7 @@ ShortkeyFromListOp::getName()
 }
 
 int
-ShortkeyFromListOp::run(ActionMessage *msg)
+ShortkeyFromListOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     msg->getWorker()->activateShortkeyFromList();
