@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: shortkeyfromlistop.h,v 1.5 2004/10/27 21:09:11 ralf Exp $ */
+/* $Id: shortkeyfromlistop.h,v 1.6 2005/10/19 18:01:31 ralf Exp $ */
 
 #ifndef SHORTKEYFROMLIST_H
 #define SHORTKEYFROMLIST_H
@@ -40,7 +40,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  virtual int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 protected:
   static const char *name;
