@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: showimagemode.cc,v 1.19 2005/05/15 20:55:58 ralf Exp $ */
+/* $Id: showimagemode.cc,v 1.20 2005/08/17 06:32:53 ralf Exp $ */
 
 #include "showimagemode.h"
 #include "normalmode.h"
@@ -128,11 +128,9 @@ const char *ShowImageMode::getStaticType()
 
 int ShowImageMode::configure()
 {
-  Button *okb,*cb,*db;
+  Button *db;
   AWindow *win;
   StringGadget *sg;
-  Text *ttext;
-  int tw,ttw,tth,ttx,tty,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   char *tstr;
@@ -140,64 +138,57 @@ int ShowImageMode::configure()
   int lines;
   Requester *req;
   int i;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
   
-  ttw=tth=10;
-  ttx=tty=5;
-
   tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( getLocaleName() ) + 1 );
   sprintf( tstr, catalog.getLocale( 293 ), getLocaleName() );
-  win = new AWindow( aguix, 10, 10, ttw, tth, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
   win->create();
   _freesafe(tstr);
 
   lines=createLines(catalog.getLocale(521),&liness);
 
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, lines + 3 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
   for(i=0;i<lines;i++) {
-    ttext=(Text*)win->add(new Text(aguix,ttx,tty,liness[i],1));
-    tty+=ttext->getHeight()+5;
-    tw=ttx+ttext->getWidth()+5;
-    if(tw>ttw) ttw=tw;
+    ac1->add( new Text( aguix, 0, 0, liness[i], 1 ), 0, i, cincwnr );
   }
 
-  sg=(StringGadget*)win->add(new StringGadget(aguix,ttx,tty,ttw-10,show_program,0));
+  sg = (StringGadget*)ac1->add( new StringGadget( aguix, 0, 0, 100, show_program, 0 ), 0, lines, cincw );
   
-  tty+=sg->getHeight()+5;
-  db=(Button*)win->add(new Button(aguix,ttx,tty,ttw-10,catalog.getLocale(110),1,0,0));
-  tty+=db->getHeight()+5;
+  db = (Button*)ac1->add( new Button( aguix, 0, 0, 100, catalog.getLocale( 110 ), 1, 0, 0 ), 0, lines + 1, cincw );
 
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>ttw) ttw=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   tty,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  ttw-5-t2,
-                                  tty,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  tty+=okb->getHeight()+5;
-  
-  tth=tty;
-  
-  sg->resize(ttw-10,sg->getHeight());
-  db->resize(ttw-10,db->getHeight());
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, lines + 2 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_2->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, cfix );
+  Button *cb = (Button*)ac1_2->add( new Button( aguix,
+						0,
+						0,
+						catalog.getLocale( 8 ),
+						1,
+						0,
+						0 ), 1, 0, cfix );
   
   win->setDoTabCycling( true );
-  win->resize(ttw,tth);
-  win->setMaxSize(ttw,tth);
-  win->setMinSize(ttw,tth);
+  win->contMaximize( true );
   win->show();
   req=new Requester(aguix);
   for(;endmode==-1;) {
