@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: simddop.h,v 1.8 2004/10/27 21:09:21 ralf Exp $ */
+/* $Id: simddop.h,v 1.9 2005/10/19 17:59:53 ralf Exp $ */
 
 #ifndef SIMDDEOP_H
 #define SIMDDOP_H
@@ -40,7 +40,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual const char *getDescription();
 protected:
   static const char *name;
@@ -49,7 +49,7 @@ protected:
   // temp variables
   Lister *startlister;
   
-  int normalmodesimdd();
+  int normalmodesimdd( ActionMessage *am );
 };
 
 #endif
