@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: startprogop.cc,v 1.30 2005/07/20 21:02:41 ralf Exp $ */
+/* $Id: startprogop.cc,v 1.32 2005/10/19 17:59:18 ralf Exp $ */
 
 #include "startprogop.h"
 #include "listermode.h"
@@ -29,6 +29,7 @@
 #include <aguix/acontainerbb.h>
 #include "execlass.h"
 #include "basic_actions.h"
+#include <algorithm>
 
 const char *StartProgOp::name="StartProgOp";
 
@@ -76,10 +77,9 @@ StartProgOp::getName()
 }
 
 int
-StartProgOp::run(ActionMessage *msg)
+StartProgOp::run( WPUContext *wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
-  am=msg;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
     Lister *l1 = msg->getWorker()->getActiveLister();
     if(l1!=NULL) {
@@ -88,7 +88,7 @@ StartProgOp::run(ActionMessage *msg)
       lm1=startlister->getActiveMode();
       if(lm1!=NULL)
         if(lm1->isType("NormalMode")==true)
-          normalmodestartprog();
+          normalmodestartprog( msg );
     }
   }
   return 0;
@@ -126,7 +126,7 @@ StartProgOp::getDescription()
 }
 
 int
-StartProgOp::normalmodestartprog()
+StartProgOp::normalmodestartprog( ActionMessage *am )
 {
   NormalMode *nm1 = NULL;
   ListerMode *lm1 = NULL;
