@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: startprogop.h,v 1.14 2005/07/12 20:22:15 ralf Exp $ */
+/* $Id: startprogop.h,v 1.15 2005/10/19 17:59:11 ralf Exp $ */
 
 #ifndef STARTPROGOP_H
 #define STARTPROGOP_H
@@ -47,7 +47,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
   virtual int configure();
@@ -79,7 +79,7 @@ protected:
   // temp variables
   Lister *startlister,*endlister;
   
-  int normalmodestartprog();
+  int normalmodestartprog( ActionMessage *am );
 
   class SettingsWidgets
   {
