@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: wconfig.h,v 1.55 2005/07/07 18:28:22 ralf Exp $ */
+/* $Id: wconfig.h,v 1.56 2005/12/11 19:29:46 ralf Exp $ */
 
 #ifndef WCONFIG_H
 #define WCONFIG_H
@@ -298,6 +298,16 @@ public:
   void buildLVFromFlat( FieldListView *lv,
 			std::vector<FlatTypeList::flattypelist_t> *l1,
 			WCFiletype *highlightft );
+  typedef enum { MOUSECONF_NORMAL_MODE,
+		 MOUSECONF_ALT_MODE } mouseconf_method_t;
+  void setMouseSelectButton( int nv );
+  void setMouseActivateButton( int nv );
+  void setMouseScrollButton( int nv );
+  void setMouseSelectMethod( mouseconf_method_t nv );
+  int getMouseSelectButton() const;
+  int getMouseActivateButton() const;
+  int getMouseScrollButton() const;
+  mouseconf_method_t getMouseSelectMethod() const;
 protected:
   char *lang;
   unsigned int rows,columns;
@@ -339,6 +349,11 @@ protected:
     bool buttonVert;
     bool listviewVert;
   } layoutConf;
+
+  struct {
+    int select_button, activate_button, scroll_button;
+    mouseconf_method_t select_method;
+  } mouseConf;
   
   char *terminalbin;
   
@@ -378,7 +393,8 @@ protected:
   bool changeDisplaySets(int);
   bool changeClockbarSets();
   bool configureLayout();
-
+  bool configureMouseConfig();
+  
   void showPathBank(int,Button**);
   void showButtonBank( int, Button***);
   
