@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: wconfigglb.cc,v 1.7 2005/06/23 18:14:35 ralf Exp $ */
+/* $Id: wconfigglb.cc,v 1.9 2005/12/11 21:10:24 ralf Exp $ */
 
 #include "wconfig.h"
 #include "worker.h"
@@ -516,7 +516,7 @@ bool WConfig::changeGlobal()
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
 
-  AContainer *ac1 = glwin->setContainer( new AContainer( glwin, 1, 12 ), true );
+  AContainer *ac1 = glwin->setContainer( new AContainer( glwin, 1, 13 ), true );
   ac1->setMaxSpace( 5 );
   ac1->setBorderWidth( 5 );
 
@@ -557,7 +557,7 @@ bool WConfig::changeGlobal()
   StringGadget *ccsg = (StringGadget*)ac1_1_0->add( new StringGadget( aguix,
 								      0,
 								      0,
-								      5 * aguix->getCharWidth(),
+								      aguix->getTextWidth( "00000" ),
 								      tstr,
 								      1 ), 1, 0, cincw );
   _freesafe(tstr);
@@ -594,7 +594,7 @@ bool WConfig::changeGlobal()
   StringGadget *rowsg = (StringGadget*)ac1_3->add( new StringGadget( aguix,
 								     0,
 								     0,
-								     5 * aguix->getCharWidth(),
+								     aguix->getTextWidth( "00000" ),
 								     tstr,
 								     1 ), 1, 0, cincw );
   _freesafe(tstr);
@@ -608,7 +608,7 @@ bool WConfig::changeGlobal()
   StringGadget *colsg = (StringGadget*)ac1_3->add( new StringGadget( aguix,
 								     0,
                                                                      0,
-								     5 * aguix->getCharWidth(),
+								     aguix->getTextWidth( "00000" ),
 								     tstr,
 								     1 ), 1, 1, cincw );
   _freesafe(tstr);
@@ -627,7 +627,7 @@ bool WConfig::changeGlobal()
   StringGadget *cachesg = (StringGadget*)ac1_4->add( new StringGadget( aguix,
                                                                        0,
                                                                        0,
-                                                                       7 * aguix->getCharWidth(),
+                                                                       aguix->getTextWidth( "0000000" ),
                                                                        tstr,
                                                                        1 ), 1, 0, cincw );
   _freesafe( tstr );
@@ -668,7 +668,7 @@ bool WConfig::changeGlobal()
   StringGadget *termsg = (StringGadget*)ac1_6->add( new StringGadget( aguix,
 								      0,
 								      0,
-								      30 * aguix->getCharWidth(),
+								      100,
                                                                       terminalbin,
 								      1 ), 0, 1, cincw );
   ac1_6->setMaxSpace( 5 );
@@ -698,9 +698,17 @@ bool WConfig::changeGlobal()
                                                              0,
                                                              0 ), 0, 9, cincw ) );
 
+  Button *mouseconfb = static_cast<Button*>( ac1->add( new Button( aguix,
+								   0,
+								   0,
+								   catalog.getLocale( 650 ),
+								   1,
+								   0,
+								   0 ), 0, 10, cincw ) );
+
   AContainer *ac1_9 = ac1->add( new AContainer( glwin,
                                                 2,
-                                                1 ), 0, 11 );
+                                                1 ), 0, 12 );
   Button *okb = (Button*)ac1_9->add( new Button( aguix,
                                                  0,
                                                  0,
@@ -772,6 +780,10 @@ bool WConfig::changeGlobal()
           glwin->hide();
           configureLayout();
           glwin->show();
+        } else if ( msg->button.button == mouseconfb ) {
+          glwin->hide();
+          configureMouseConfig();
+          glwin->show();
         }
       } else if(msg->type==AG_STRINGGADGET_DEACTIVATE) {
         if(msg->stringgadget.sg==ccsg) {
@@ -853,6 +865,10 @@ bool WConfig::changeGlobal()
     setLayoutOrders( wconfig_bak->getLayoutOrders() );
     setLayoutButtonVert( wconfig_bak->getLayoutButtonVert() );
     setLayoutListviewVert( wconfig_bak->getLayoutListviewVert() );
+    setMouseSelectButton( wconfig_bak->getMouseSelectButton() );
+    setMouseActivateButton( wconfig_bak->getMouseActivateButton() );
+    setMouseScrollButton( wconfig_bak->getMouseScrollButton() );
+    setMouseSelectMethod( wconfig_bak->getMouseSelectMethod() );
   } else {
     setOwnerstringtype(cyb->getSelectedOption());
     setTerminalBin(termsg->getText());
@@ -978,10 +994,10 @@ bool WConfig::changeDisplaySets(int side)
   lv1->maximizeY();
   lv2->maximizeX();
   lv2->maximizeY();
-  if ( lv1->getWidth() < ( 20 * aguix->getCharWidth() ) )
-    lv1->resize( ( 20 * aguix->getCharWidth() ), lv1->getHeight() );
-  if ( lv2->getWidth() < ( 20 * aguix->getCharWidth() ) )
-    lv2->resize( ( 20 * aguix->getCharWidth() ), lv2->getHeight() );
+  if ( lv1->getWidth() < 100 )
+    lv1->resize( 100, lv1->getHeight() );
+  if ( lv2->getWidth() < 100 )
+    lv2->resize( 100, lv2->getHeight() );
   ac1_1_1->readLimits();
   ac1_1->readLimits();
   win->setDoTabCycling( true );
@@ -1431,3 +1447,231 @@ bool WConfig::changeFileSets()
   delete twconfig;
   return (ende==-1)?false:true;
 }
+
+bool WConfig::configureMouseConfig()
+{
+  bool ok;
+  AGUIX *aguix=worker->getAGUIX();
+  
+  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 650 ) );
+  win->create();
+
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 0 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( 5 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 651 ), 1 ), 0, 0, AContainer::CFIX );
+
+  CycleButton *cycb1 = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 10, 1, 0, 0 ), 1, 0, AContainer::CINCW );
+  cycb1->addOption( catalog.getLocale( 652 ) );
+  cycb1->addOption( catalog.getLocale( 653 ) );
+  cycb1->addOption( catalog.getLocale( 654 ) );
+  cycb1->addOption( catalog.getLocale( 655 ) );
+  cycb1->resize( cycb1->getMaxSize(), cycb1->getHeight() );
+  ac1_1->readLimits();
+
+  if ( getMouseSelectButton() == 1 &&
+       getMouseActivateButton() == 2 &&
+       getMouseScrollButton() == 3 &&
+       getMouseSelectMethod() == MOUSECONF_NORMAL_MODE ) {
+    cycb1->setOption( 0 );
+  } else if ( getMouseSelectButton() == 2 &&
+       getMouseActivateButton() == 1 &&
+       getMouseScrollButton() == 3 &&
+       getMouseSelectMethod() == MOUSECONF_NORMAL_MODE ) {
+    cycb1->setOption( 1 );
+  } else if ( getMouseSelectButton() == 1 &&
+       getMouseActivateButton() == 2 &&
+       getMouseScrollButton() == 3 &&
+       getMouseSelectMethod() == MOUSECONF_ALT_MODE ) {
+    cycb1->setOption( 2 );
+  } else {
+    cycb1->setOption( 3 );
+  }
+
+  AContainerBB *ac1_2 = static_cast<AContainerBB*>( ac1->add( new AContainerBB( win, 1, 4 ), 0, 1 ) );
+  ac1_2->setMinSpace( 0 );
+  ac1_2->setMaxSpace( 0 );
+  ac1_2->setBorderWidth( 5 );
+
+  AContainer *ac1_2_1 = ac1_2->add( new AContainer( win, 2, 1 ), 0, 0 );
+  ac1_2_1->setMinSpace( 5 );
+  ac1_2_1->setMaxSpace( 5 );
+  ac1_2_1->setBorderWidth( 2 );
+
+  ac1_2_1->add( new Text( aguix, 0, 0, catalog.getLocale( 656 ), 1 ), 0, 0, AContainer::CFIX );
+
+  CycleButton *cycbsb = (CycleButton*)ac1_2_1->add( new CycleButton( aguix, 0, 0, 10, 1, 0, 0 ), 1, 0, AContainer::CINCW );
+  cycbsb->addOption( catalog.getLocale( 657 ) );
+  cycbsb->addOption( catalog.getLocale( 658 ) );
+  cycbsb->addOption( catalog.getLocale( 659 ) );
+  cycbsb->resize( cycbsb->getMaxSize(), cycbsb->getHeight() );
+  ac1_2_1->readLimits();
+
+  switch ( getMouseSelectButton() ) {
+    case 2:
+    case 3:
+      cycbsb->setOption( getMouseSelectButton() - 1 );
+      break;
+    default:
+      cycbsb->setOption( 0 );
+      break;
+  }
+
+  AContainer *ac1_2_2 = ac1_2->add( new AContainer( win, 2, 1 ), 0, 1 );
+  ac1_2_2->setMinSpace( 5 );
+  ac1_2_2->setMaxSpace( 5 );
+  ac1_2_2->setBorderWidth( 2 );
+
+  ac1_2_2->add( new Text( aguix, 0, 0, catalog.getLocale( 660 ), 1 ), 0, 0, AContainer::CFIX );
+
+  CycleButton *cycbab = (CycleButton*)ac1_2_2->add( new CycleButton( aguix, 0, 0, 10, 1, 0, 0 ), 1, 0, AContainer::CINCW );
+  cycbab->addOption( catalog.getLocale( 657 ) );
+  cycbab->addOption( catalog.getLocale( 658 ) );
+  cycbab->addOption( catalog.getLocale( 659 ) );
+  cycbab->resize( cycbab->getMaxSize(), cycbab->getHeight() );
+  ac1_2_2->readLimits();
+
+  switch ( getMouseActivateButton() ) {
+    case 2:
+    case 3:
+      cycbab->setOption( getMouseActivateButton() - 1 );
+      break;
+    default:
+      cycbab->setOption( 0 );
+      break;
+  }
+
+  AContainer *ac1_2_3 = ac1_2->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ac1_2_3->setMinSpace( 5 );
+  ac1_2_3->setMaxSpace( 5 );
+  ac1_2_3->setBorderWidth( 2 );
+
+  ac1_2_3->add( new Text( aguix, 0, 0, catalog.getLocale( 661 ), 1 ), 0, 0, AContainer::CFIX );
+
+  CycleButton *cycbscb = (CycleButton*)ac1_2_3->add( new CycleButton( aguix, 0, 0, 10, 1, 0, 0 ), 1, 0, AContainer::CINCW );
+  cycbscb->addOption( catalog.getLocale( 657 ) );
+  cycbscb->addOption( catalog.getLocale( 658 ) );
+  cycbscb->addOption( catalog.getLocale( 659 ) );
+  cycbscb->resize( cycbscb->getMaxSize(), cycbscb->getHeight() );
+  ac1_2_3->readLimits();
+
+  switch ( getMouseScrollButton() ) {
+    case 2:
+    case 3:
+      cycbscb->setOption( getMouseScrollButton() - 1 );
+      break;
+    default:
+      cycbscb->setOption( 0 );
+      break;
+  }
+
+  AContainer *ac1_2_4 = ac1_2->add( new AContainer( win, 2, 1 ), 0, 3 );
+  ac1_2_4->setMinSpace( 5 );
+  ac1_2_4->setMaxSpace( 5 );
+  ac1_2_4->setBorderWidth( 2 );
+
+  ac1_2_4->add( new Text( aguix, 0, 0, catalog.getLocale( 662 ), 1 ), 0, 0, AContainer::CFIX );
+
+  CycleButton *cycbsmb = (CycleButton*)ac1_2_4->add( new CycleButton( aguix, 0, 0, 10, 1, 0, 0 ), 1, 0, AContainer::CINCW );
+  cycbsmb->addOption( catalog.getLocale( 663 ) );
+  cycbsmb->addOption( catalog.getLocale( 664 ) );
+  cycbsmb->resize( cycbsmb->getMaxSize(), cycbsmb->getHeight() );
+  ac1_2_4->readLimits();
+
+  if ( getMouseSelectMethod() == MOUSECONF_ALT_MODE ) {
+    cycbsmb->setOption( 1 );
+  } else {
+    cycbsmb->setOption( 0 );
+  }
+
+  AContainer *ac1_3 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ac1_3->setMinSpace( 5 );
+  ac1_3->setMaxSpace( -1 );
+  ac1_3->setBorderWidth( 0 );
+  Button *okb =(Button*)ac1_3->add( new Button( aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 11 ),
+                                                1,
+                                                0,
+                                                0 ), 0, 0, AContainer::CFIX );
+  Button *cancelb = (Button*)ac1_3->add( new Button( aguix,
+						     0,
+						     0,
+						     catalog.getLocale( 8 ),
+						     1,
+						     0,
+						     0 ), 1, 0, AContainer::CFIX );
+
+  win->setDoTabCycling( true );
+  win->contMaximize( true );
+  win->show();
+  AGMessage *msg;
+  while((msg=aguix->GetMessage(NULL))!=NULL) aguix->ReplyMessage(msg);
+  int ende=0;
+  while(ende==0) {
+    msg=aguix->WaitMessage(win);
+    if(msg!=NULL) {
+      if(msg->type==AG_CLOSEWINDOW) {
+        if(msg->closewindow.window==win->getWindow()) ende=-1;
+      } else if(msg->type==AG_BUTTONCLICKED) {
+        if(msg->button.button==okb) ende=1;
+        else if(msg->button.button==cancelb) ende=-1;
+      } else if(msg->type==AG_CYCLEBUTTONCLICKED) {
+        if ( msg->cyclebutton.cyclebutton == cycb1 ) {
+          switch ( msg->cyclebutton.option ) {
+            case 1:
+	      cycbsb->setOption( 1 );
+	      cycbab->setOption( 0 );
+	      cycbscb->setOption( 2 );
+	      cycbsmb->setOption( 0 );
+              break;
+            case 2:
+	      cycbsb->setOption( 0 );
+	      cycbab->setOption( 1 );
+	      cycbscb->setOption( 2 );
+	      cycbsmb->setOption( 1 );
+	      break;
+	    case 3:
+	      break;
+            default:
+	      cycbsb->setOption( 0 );
+	      cycbab->setOption( 1 );
+	      cycbscb->setOption( 2 );
+	      cycbsmb->setOption( 0 );
+              break;
+           }
+        } else if ( msg->cyclebutton.cyclebutton == cycbsb ||
+		    msg->cyclebutton.cyclebutton == cycbab ||
+		    msg->cyclebutton.cyclebutton == cycbscb ||
+		    msg->cyclebutton.cyclebutton == cycbsmb ) {
+	  cycb1->setOption( 3 );
+	}
+      }
+      aguix->ReplyMessage(msg);
+    }
+  }
+  ok=false;
+  if(ende==1) {
+    setMouseSelectButton( cycbsb->getSelectedOption() + 1 );
+    setMouseActivateButton( cycbab->getSelectedOption() + 1 );
+    setMouseScrollButton( cycbscb->getSelectedOption() + 1 );
+    switch ( cycbsmb->getSelectedOption() ) {
+      case 1:
+	setMouseSelectMethod( MOUSECONF_ALT_MODE );
+	break;
+      default:
+	setMouseSelectMethod( MOUSECONF_NORMAL_MODE );
+	break;
+    }
+    ok = true;
+  }
+  delete win;
+  return ok;
+}
