@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker.cc,v 1.113 2005/07/13 20:00:58 ralf Exp $ */
+/* $Id: worker.cc,v 1.117 2005/12/11 19:26:59 ralf Exp $ */
 
 #include "worker.h"
 #include "lister.h"
@@ -291,7 +291,9 @@ void Worker::run()
           if(dm->getSourceLister()!=NULL) dm->getSourceLister()->startdnd(dm);
           break;
         case AG_KEYPRESSED:
-          activateShortkey(msg);
+          if ( activateShortkey(msg) != 0 ) {
+            handleSub = false;
+	  }
           break;
         default:
           break;
@@ -714,6 +716,7 @@ void Worker::setupMainWin()
   }
 
   font = aguix->getFont( wconfig->getFont(1) );
+
   th = aguix->getCharHeight() + 4;
   aboutb->resize( th, th );
   configureb->resize( th, th );
@@ -804,6 +807,11 @@ void Worker::setupMainWin()
   if ( lister[1] != NULL ) lister[1]->messageHandler( msg );
   delete msg;
 
+  FieldListView::changeButtonFunction( FieldListView::SELECT_BUTTON, wconfig->getMouseSelectButton() );
+  FieldListView::changeButtonFunction( FieldListView::ACTIVATE_BUTTON, wconfig->getMouseActivateButton() );
+  FieldListView::changeButtonFunction( FieldListView::SCROLL_BUTTON, wconfig->getMouseScrollButton() );
+  FieldListView::changeSelectMode( ( wconfig->getMouseSelectMethod() == WConfig::MOUSECONF_ALT_MODE ) ? FieldListView::MOUSE_SELECT_ALT : FieldListView::MOUSE_SELECT_NORMAL );
+
   mainwin->show();
 }
 
@@ -1145,7 +1153,7 @@ int Worker::interpret(List* coms,ActionMessage *msg)
   return 0;
 }
 
-void Worker::activateShortkey(AGMessage *msg)
+int Worker::activateShortkey(AGMessage *msg)
 {
   int keystate;
   WCHotkey *hk1;
@@ -1164,7 +1172,7 @@ void Worker::activateShortkey(AGMessage *msg)
       // and this would lead to wrong results
       // other way could be to just dont save this modifier presses in lastkey
       if ( AGUIX::isModifier( msg->key.key ) == true )
-        return;
+        return 0;
     }
 
     keystate=KEYSTATEMASK(msg->key.keystate);
@@ -1243,7 +1251,9 @@ void Worker::activateShortkey(AGMessage *msg)
         }
       }
     }
+    return ( found == true ) ? 1 : 0;
   }
+  return 0;
 }
 
 Lister *Worker::getLister(int side)
@@ -1560,8 +1570,8 @@ void Worker::updateTime(void)
   char *str,*buffer;
   const char *clbc;
   int dt=wconfig->getClockbarUpdatetime();
-  int maxchars;
   WConfig::clockbar_mode_t cbm=wconfig->getClockbarMode();
+  int tlen;
   
   time(&timep);
   if ( ( lasttimep == 0 ) ||
@@ -1576,18 +1586,14 @@ void Worker::updateTime(void)
     } else if(cbm==WConfig::CLOCKBAR_MODE_EXTERN) {
       clbc=wconfig->getClockbarCommand();
       if(strlen(clbc)>0) {
-        // this is the count the max chars fit in the clockbar
-        maxchars=clockbar->getWidth();
-        maxchars/=aguix->getCharWidth();
-
-        // start the program and store the output in a temp file
-        // then read no more then maxchars bytes and display it
+        // start the program
         ExeClass *myexe = new ExeClass( ExeClass::EXECUTE_NORMAL );
         myexe->addCommand( "%s", clbc );
         buffer = myexe->getOutput();
         if ( buffer != NULL ) {
-          if ( (int)strlen( buffer ) > maxchars ) {
-            buffer[maxchars] = '\0';
+	  tlen = aguix->getStrlen4Width( buffer, clockbar->getWidth() - 10, NULL );
+          if ( (int)strlen( buffer ) > tlen ) {
+            buffer[tlen] = '\0';
           }
         }
         delete myexe;
@@ -1988,10 +1994,8 @@ void Worker::activateShortkeyFromList()
   
   lw+=10;
 
-  t1=(strlen(catalog.getLocale(392))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
+  t1 = aguix->getTextWidth( catalog.getLocale( 392 ) ) + 10;
+  t2 = aguix->getTextWidth( catalog.getLocale( 8 ) ) + 10;
   tw=5+t1+5+t2+5;
   if(tw>lw) lw=tw;
   okb=(Button*)win->add(new Button(aguix,
@@ -2427,7 +2431,8 @@ void Worker::closeMainWin()
 
 void Worker::showLicense()
 {
-  TextStorageString ts( cgpl );
+  AFontWidth lencalc( aguix, NULL );
+  TextStorageString ts( cgpl, lencalc );
   req_static->request( catalog.getLocale( 509 ), ts, catalog.getLocale( 11 ) );
 }
 
@@ -2621,44 +2626,36 @@ AWindow *Worker::getListerWin( Lister *l )
   return NULL;
 }
 
-int Worker::getMaxButtonsLen()
+int Worker::getMaxButtonsWidth()
 {
+  int bw;
   int id;
   List *buttonlist;
   WCButton *b1;
-  int l, t;
+  int t;
   const char *tstr;
 
+  AGUIXFont *font = aguix->getFont( wconfig->getFont( 1 ) );
+  
+  if ( font == NULL ) return 0;
+
   buttonlist = wconfig->getButtons();
   id = buttonlist->initEnum();
   b1 = (WCButton*)buttonlist->getFirstElement( id );
-  l = 0;
+  bw = 0;
   while ( b1 != NULL ) {
     if( b1->getCheck() == true ) {
       tstr = b1->getText();
       if ( tstr != NULL ) {
-        t = strlen( tstr );
-        if ( t > l ) l = t;
+        t = aguix->getTextWidth( tstr, font );
+        if ( t > bw ) bw = t;
       }
     }
     b1 = (WCButton*)buttonlist->getNextElement( id );
   }
   buttonlist->closeEnum( id );
-  return l;
-}
-
-int Worker::getMaxButtonsWidth()
-{
-  int l;
   
-  l = getMaxButtonsLen();
-  
-  AGUIXFont *font = aguix->getFont( wconfig->getFont( 1 ) );
-  if ( font != NULL ) {
-    l *= font->getCharWidth();
-    return l;
-  }
-  return 0;
+  return bw;
 }
 
 /*
