@@ -1,6 +1,6 @@
 /* worker.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker.h,v 1.41 2005/07/07 18:28:53 ralf Exp $ */
+/* $Id: worker.h,v 1.43 2005/11/27 22:00:06 ralf Exp $ */
 
 #ifndef WORKER_H
 #define WORKER_H
@@ -109,7 +109,7 @@ public:
   void showButtonBank();
   void setPath(int);
   void setPath( WCPath *);
-  void activateShortkey(AGMessage*);
+  int activateShortkey(AGMessage*);
   void activateButton(int,int,int);
   int saveListerState();
   int initListerState();
@@ -168,7 +168,6 @@ public:
   int waitcursorcount;
   
   int getMaxButtonsWidth();
-  int getMaxButtonsLen();
 
   bool restart;
   bool configstarted;
