@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker_commands.cc,v 1.28 2005/03/08 22:53:22 ralf Exp $ */
+/* $Id: worker_commands.cc,v 1.29 2005/05/19 19:54:20 ralf Exp $ */
 
 #include "worker.h"
 #include "worker_commands.h"
@@ -172,6 +172,9 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 48:
       fpr = new GoFTPOp();
       break;
+    case 49:
+      fpr = new InternalViewOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -230,6 +233,7 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( ParentActionOp::name ) == true ) type = 46;
   else if ( fpr->isName( NoOperationOp::name ) == true ) type = 47;
   else if ( fpr->isName( GoFTPOp::name ) == true ) type = 48;
+  else if ( fpr->isName( InternalViewOp::name ) == true ) type = 49;
   return type;
 }
 
