@@ -18,13 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker_locale.cc,v 1.168 2005/07/13 20:20:06 ralf Exp $ */
+/* $Id: worker_locale.cc,v 1.173 2005/12/13 19:37:35 ralf Exp $ */
 
 #include "worker_locale.h"
 #include "wconfig.h"
 #include "worker.h"
 
-#define CATENTRY 648
+#define CATENTRY 665
 #define CATCOMENTRY 50
 #define CATFLAGENTRY 59
 
@@ -95,7 +95,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[37]=dupstring( "selected dir" );
   catalog[38]=dupstring( "unselected file" );
   catalog[39]=dupstring( "selected file" );
-  catalog[40]=dupstring( "Cant' save the config to %s!|Please check the worker installation!" );
+  catalog[40]=dupstring( "Can't save the config to %s!|Please check the worker installation!" );
   catalog[41]=dupstring( "Retry" );
   catalog[42]=dupstring( "A button named %s already uses this shortcut!|Click Okay to remove the reference to this shortcut|from the button and use it here instead" );
   catalog[43]=dupstring( "clockbar" );
@@ -208,7 +208,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[150]=dupstring( "Preserve attributes" );
   catalog[151]=dupstring( "Error while renaming!" );
   catalog[152]=dupstring( "Enter name for directory:" );
-  catalog[153]=dupstring( "Delete active entry when no other are selected" );
+  catalog[153]=dupstring( "Delete active entry if there are no other selected entries" );
   catalog[154]=dupstring( "New Hotkey" );
   catalog[155]=dupstring( "Duplicate Hotkey" );
   catalog[156]=dupstring( "Delete Hotkey" );
@@ -741,7 +741,24 @@ if you have the ssh_askpass tool. Do you really want to continue?" );
   catalog[644]=dupstring( "Select filetype. Its double click action will be executed on the active file." );
   catalog[645]=dupstring( "Start program or apply different action to the current file:" );
   catalog[646]=dupstring( "The action list of the filetype is empty, you can select a different action here:" );
-  catalog[647]=dupstring( "Error while writing command file %s!|Can't execute external programm." );
+  catalog[647]=dupstring( "Error while writing command file %s!|Can't execute external program." );
+  catalog[648]=dupstring( "Search for next entry in reverse order" );
+  catalog[649]=dupstring( "Enable quick search" );
+  catalog[650]=dupstring( "Mouse button configuration" );
+  catalog[651]=dupstring( "Mouse configuration presets:" );
+  catalog[652]=dupstring( "worker style" );
+  catalog[653]=dupstring( "mc style" );
+  catalog[654]=dupstring( "kde style" );
+  catalog[655]=dupstring( "custom" );
+  catalog[656]=dupstring( "Select button:" );
+  catalog[657]=dupstring( "Left mouse button" );
+  catalog[658]=dupstring( "Middle mouse button" );
+  catalog[659]=dupstring( "Right mouse button" );
+  catalog[660]=dupstring( "Activate button:" );
+  catalog[661]=dupstring( "Scroll button:" );
+  catalog[662]=dupstring( "Select method:" );
+  catalog[663]=dupstring( "Normal (click toggles select state)" );
+  catalog[664]=dupstring( "Alternative (click selects element and deselects all other)" );
 
 //  catalog[]=dupstring( "" );
   
