@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: wpucontext.cc,v 1.24 2005/03/21 20:25:41 ralf Exp $ */
+/* $Id: wpucontext.cc,v 1.26 2005/05/19 19:54:55 ralf Exp $ */
 
 #include "wpucontext.h"
 #include "scriptop.h"
@@ -336,8 +336,8 @@ int WPUContext::openWin()
   
   if ( userwin == NULL ) {
     aguix = worker->getAGUIX();
-    userwin = new AWindow( aguix );
-    userwin->create( NULL, 10, 10, 100, 50, 0, catalog.getLocale( 499 ) );
+    userwin = new AWindow( aguix, 10, 10, 100, 50, 0, catalog.getLocale( 499 ) );
+    userwin->create();
     tx = ty = 5;
     nr_of_text = 1;
     texts = new Text*[nr_of_text];
@@ -375,7 +375,6 @@ int WPUContext::openWin()
 int WPUContext::closeWin()
 {
   if ( userwin != NULL ) {
-    userwin->close();
     delete userwin;
     delete [] texts;
     userwin = NULL;
@@ -383,7 +382,7 @@ int WPUContext::closeWin()
   return 0;
 }
 
-char *WPUContext::parse( char *str1, int maxlen, bool quote )
+char *WPUContext::parse( const char *str1, int maxlen, bool quote )
 {
   char *tstr = NULL;
   NormalMode *nm;
